(* ::Package:: *)

(*Set_up_non_Asymptotic*)
(*The derivation of the rules and checks containted in this script have been comemented out*)


(*This a notebook associated to the paper
 The Weak Null Condition in Free-evolution Schemes for Numerical Relativity:
Dual Foliation GHG with Constraint Damping
December 2018.
E. Gasper\[IAcute]n & D. Hilditch*)


(*Definitions and rules. Metric g, frozen metric m,  covariant derivatives and spherical coordinate chart.*)


<<xAct`xTensor`




(*Definition of the Manifold and global rulemakers *)

DefManifold[M4,4,{a,b,c,d,f,p,h,i,j,k,l,n,u,v,w}]
$MixedDers=False;
Off[ToCanonical::noident]
$PrePrint=ScreenDollarIndices;
ApplyRule[expr_]:=MakeRule[Evaluate[List@@expr],MetricOn->All,ContractMetrics->True]
ApplyRuleWithoutMovingIndices[expr_]:=MakeRule[Evaluate[List@@expr]]



DefMetric[{3,1,0},g[-a,-b],CD,{";","\[Del]"}]


DefMetric[-1,m[-a,-b],CDflat,SymbolOfCovD->{"%","\!\(\*OverscriptBox[\(\[Del]\), \(\[FilledSmallCircle]\)]\)"}]



<<xAct`xCoba`


DefChart[Sp,M4,{0,1,2,3},{t[],r[],\[Theta][],\[Phi][]}]


MatrixForm[MinkowskiSp={
{-1,0,0,0},
{0,1,0,0},
{0,0,r[]^2,0},
{0,0,0,r[]^2 Sin[\[Theta][]]^2}
}]


MetricInBasis[m,-Sp,MinkowskiSp]


MetricCompute[m,Sp,All,CVSimplify->Simplify]


MetricCompute[m,Sp,"Riemann"[-1,-1,-1,-1],CVSimplify->Simplify]


Last@TensorValues[RiemannCDflat]


MetricCompute[m,Sp,"Christoffel"[1,-1,-1],CVSimplify->Simplify]


Last@TensorValues[ChristoffelCDflatPDSp]



RecogniseThatMinkowskiIsFlat=RiemannCDflat[-a,-b,-c,d]==0
(*g[-d,b]*RecogniseThatMinkowskiIsFlat[[1]]==g[-d,b]*RecogniseThatMinkowskiIsFlat[[2]]*)
RecogniseThatRicciMinkowskiIsFlat=RicciCDflat[-a,-c]==0


(*Convention and other general checks for the frozen/unfrozen metric*)


(*CD[-a]@g[-b,-c]*)


(*CDflat[-a]@m[-b,-c]*)


(*DefTensor[Vector[-a],M4,PrintAs->"v"]*)


(*MetricsOfVBundle[TangentM4]*)


(*m[a,b]Vector[-a]
ToCanonical[%]
*)


(*g[a,b]Vector[-a]
ToCanonical[%]
*)


(*m[a,b]m[-a,-c]*)


(*g[a,b]g[-a,-c]
ContractMetric[%]
ToCanonical[%]*)


(*Invm[a,b]m[-a,-c]
*)


(*Notation : Observe the syntaxis of these objects in xCoba*)


(*Basis[{3,-Sp},-a]
Basis[{3,Sp},-a]
Basis[{3,-Sp},a]*)


(*Definitions and basic rules for the 3 + 1 split*)


DefTensor[NormalN[-a],M4,PrintAs->"N"]
DefTensor[projector[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[Gamma]"]
DefTensor[Shift[-a],M4,PrintAs->"B"]
DefScalarFunction[Lapse, PrintAs->"A"]
DefTensor[Constraint[-a],M4,PrintAs->"C"]
DefTensor[GenericConstraintAddition[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[ScriptCapitalT]"]
DefTensor[IntermediateBoxg[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(\[EmptySquare]\), \(~\)]\)g"]
DefScalarFunction[gamma2,PrintAs->"\!\(\*SubscriptBox[\(\[Gamma]\), \(2\)]\)"]
DefTensor[SpacetimeReductionConstraint[-a,-b,-c],M4,PrintAs->"C"]
DefTensor[SpaceReductionConstraint[-a,-b,-c],M4,PrintAs->"\[ScriptCapitalC]"]
DefTensor[GaugeSourceFunction[-a],M4,PrintAs->"F"]


AutomaticRules[NormalN,MakeRule[{
NormalN[a]NormalN[-a],-1},MetricOn-> All,ContractMetrics-> True]]


ProjectorDefinition=projector[-a,-b]==g[-a,-b]+NormalN[-a]NormalN[-b]
ProjectorDefinitionDownUp=projector[-a,b]==g[-a,b]+NormalN[-a]NormalN[b]
MetricInTermsOfTheProjector=g[-a,-b]==-(NormalN[-a]*NormalN[-b])+projector[-a,-b]
MetricInTermsOfTheProjectorDownUp=delta[-a,b]==-(NormalN[-a]*NormalN[b])+projector[-a,b]


(*check*)
(*projector[-a,b]projector[a,-c]
%/.ApplyRule@ProjectorDefinition;
Expand[%]
%/.ApplyRule@MetricInTermsOfTheProjectorDownUp*)


AutomaticRules[projector,MakeRule[{
projector[-a,b]projector[a,-c],projector[-c,b]},MetricOn-> All,ContractMetrics-> True]]


AutomaticRules[projector,MakeRule[{
projector[-a,a],3},MetricOn-> All,ContractMetrics-> True]]


AutomaticRules[NormalN,MakeRule[{
projector[-a,-b]NormalN[b],0},MetricOn-> All,ContractMetrics-> True]]


AutomaticRules[NormalN,MakeRule[{
Shift[a]NormalN[-a],0},MetricOn-> All,ContractMetrics-> True]]


(*check*)
(*projector[-a,b]projector[a,-c]
projector[a,f]projector[-d,-f]
projector[-a,-b]projector[a,b]*)


(*Normal in basis rules*)


NormalDownInBasis=NormalN[-a]==-Lapse*Basis[{0,Sp},-a]
(**)
(*Flatten[Solve[NormalDownInBasis,Basis[{0,Sp},-a]]]
%[[1]][[1]]==%[[1]][[2]]*)
BasisTimeToNormal=Basis[-a,{0,Sp}]==-(NormalN[-a]/Lapse)
(**)
(*g[a,b]NormalN[-a]
%/.ApplyRule@NormalDownInBasis;
ContractBasis[%]
g[a,b]NormalN[-a]\[Equal]%
Flatten[Solve[%,g[{0,Sp},b]]];
%[[1]][[1]]\[Equal]%[[1]][[2]];*)
Metric0sptabstractUpToLapseAndNormal=g[{0,Sp},b]==-((g[a,b]*NormalN[-a])/Lapse)
(**)
NormalToTimeAndShift=NormalN[a]==Lapse^(-1)*Basis[{0,-Sp},a]-Lapse^(-1)Shift[a]
(**)
(*Flatten[Solve[NormalToTimeAndShift,Basis[{0,-Sp},a]]];
%[[1]][[1]]==%[[1]][[2]];*)
BasisTimeVectorToNormalandShift=Basis[{0,-Sp},a]==Lapse*NormalN[a]+Shift[a]
(**)
(*Shift[{0,Sp}]
SeparateBasis[AIndex][%]
%/.ApplyRule@BasisTimeToNormal*)
ComponentValue[Shift[{0,Sp}],0]
(**)
ReplaceNormalDerivativeByTimeDerivativeAndShift=NormalN[a]CDflat[-a]@expr_:>Lapse^(-1)*Basis[{0,-Sp},a]CDflat[-a]@expr-Lapse^(-1)Shift[a]CDflat[-a]@expr



(*NormalN[-a]g[a,b];
ContractMetric[%];
NormalN[-a]g[a,b]\[Equal]%*)
RaiseIndexOfN=g[a,b]*NormalN[-a]==NormalN[b]


(*Definitions and key decompositions of the reduction variables*)


DefTensor[PigT[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[Pi]"]
DefTensor[SpacetimeDerivativeg[-c,-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[Phi]"]
DefTensor[SpatialDerivativeg[-c,-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[CapitalPhi]"]


SpatialDerivativegAsProjectedSpacetimeDerivative=SpatialDerivativeg[-c,-a,-b]==projector[-c,d]SpacetimeDerivativeg[-d,-a,-b]
(**)
(*SpatialDerivativegAsProjectedSpacetimeDerivative
Basis[{0, -Sp}, c]*%
% /. ApplyRule[ProjectorDefinitionDownUp]; 
Expand[%]; 
% /. ApplyRuleWithoutMovingIndices[NormalDownInBasis]; 
% /. ApplyRule[NormalToTimeAndShift]; 
ContractBasis[%]*)
SpatialDerivativegTime=SpatialDerivativeg[{0,-Sp},-a,-b]==Shift[d]*SpacetimeDerivativeg[-d,-a,-b]
(**)
(*SpatialDerivativegAsProjectedSpacetimeDerivative
NormalN[c]*%*)
NormalContractedWithSpatialDerivative=NormalN[c]*SpatialDerivativeg[-c,-a,-b]==0


(*NormalContractedWithSpatialDerivative
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%]
%[[1]]-NormalN[c]*CDflat[-h][SpatialDerivativeg[-c,-a,-b]]==%[[2]]-NormalN[c]*CDflat[-h][SpatialDerivativeg[-c,-a,-b]];
Reverse[-%]*)
SubstituteNormalDerivativeSpatialPhi=NormalN[c]*CDflat[-h][SpatialDerivativeg[-c,-a,-b]]==-(SpatialDerivativeg[-c,-a,-b]*CDflat[-h][NormalN[c]])
(**)
(*projector[-f,b]SpatialDerivativeg[-b,-c,-d];
%/.ApplyRule@ProjectorDefinitionDownUp;
ContractMetric[%];
%/.ApplyRule@NormalContractedWithSpatialDerivative;
projector[-f,b]SpatialDerivativeg[-b,-c,-d]\[Equal]%*)
SpatialDerivativegIsSpatialInTheFirstIndex=projector[-f,b]*SpatialDerivativeg[-b,-c,-d]==SpatialDerivativeg[-f,-c,-d]


(*Basis[{1,-Sp},c]SpatialDerivativegAsProjectedSpacetimeDerivative
%/.ApplyRule@ProjectorDefinitionDownUp;
ContractMetric[%];
%/.ApplyRuleWithoutMovingIndices@NormalDownInBasis;
ContractBasis[%]
Reverse[%];*)
SpacetimeDerivative1IsJustSpatialDerivative1=SpacetimeDerivativeg[{1,-Sp},-a,-b]==SpatialDerivativeg[{1,-Sp},-a,-b]
(**)
(*Basis[{2,-Sp},c]SpatialDerivativegAsProjectedSpacetimeDerivative
%/.ApplyRule@ProjectorDefinitionDownUp;
ContractMetric[%];
%/.ApplyRuleWithoutMovingIndices@NormalDownInBasis;
ContractBasis[%]
Reverse[%];*)
SpacetimeDerivative1IsJustSpatialDerivative2=SpacetimeDerivativeg[{2,-Sp},-a,-b]==SpatialDerivativeg[{2,-Sp},-a,-b]
(**)
(*Basis[{3,-Sp},c]SpatialDerivativegAsProjectedSpacetimeDerivative
%/.ApplyRule@ProjectorDefinitionDownUp;
ContractMetric[%];
%/.ApplyRuleWithoutMovingIndices@NormalDownInBasis;
ContractBasis[%]
Reverse[%];*)
SpacetimeDerivative1IsJustSpatialDerivative3=SpacetimeDerivativeg[{3,-Sp},-a,-b]==SpatialDerivativeg[{3,-Sp},-a,-b]
(**)
SpacetimeDerivativeSpatialIsJustSpatialDerivative={SpacetimeDerivative1IsJustSpatialDerivative1,SpacetimeDerivative1IsJustSpatialDerivative2,SpacetimeDerivative1IsJustSpatialDerivative3}
ApplyRuleSpacetimeDerivativeSpatialIsJustSpatialDerivative=Flatten[ApplyRule/@SpacetimeDerivativeSpatialIsJustSpatialDerivative];


TimeReductionVariableEquationAsSource=CDflat[{0,-Sp}]@g[-a,-b]==-Lapse*PigT[-a,-b]+Shift[c]SpatialDerivativeg[-c,-a,-b]
(**)
RuleSpacetimeReductionVariable=CDflat[-a]@g[-b,-c]==SpacetimeDerivativeg[-a,-b,-c]



(*Reverse[RuleSpacetimeReductionVariable]
Basis[{0,-Sp},a]*%;
ContractBasis[%]
%/.ApplyRule@TimeReductionVariableEquationAsSource
SeparateBasis[AIndex][%];
%/.ApplyRule@BasisTimeVectorToNormalandShift;
ContractMetric[%];
%/.ApplyRule@SpatialDerivativegAsProjectedSpacetimeDerivative;
%/.ApplyRule@ProjectorDefinitionDownUp;
ContractMetric[%];
ToCanonical[%];
Simplify[Lapse^(-1)*%]
Flatten[Solve[%PigT[-b,-c]]];
%[[2]];
%[[1]]==%[[2]];
Reverse[-%]*)
RelationPigTandSpacetimeDerivativeg=NormalN[a]*SpacetimeDerivativeg[-a,-b,-c]==-PigT[-b,-c]
(**)
(*SpatialDerivativegAsProjectedSpacetimeDerivative
projector[c,-f]*%
%/.ApplyRule@ProjectorDefinitionDownUp;
ContractMetric[%];
%/.ApplyRule@NormalContractedWithSpatialDerivative
Flatten[Solve[%,SpacetimeDerivativeg[-f,-a,-b]]];
%[[1]][[1]]\[Equal]%[[1]][[2]];
%/.ApplyRule@RelationPigTandSpacetimeDerivativeg*)
DecompositionOfSpacetimeDerivativeg=SpacetimeDerivativeg[-f,-a,-b]==NormalN[-f]*PigT[-a,-b]+SpatialDerivativeg[-f,-a,-b]



(*Derivatives of the lapse, the shift and the normal*)


(*ChristoffelCDflatPDSp[{0, Sp}, -b, -a];
SeparateBasis[Sp][%];
TraceBasisDummy[%];
ToValues[%];
ChristoffelCDflatPDSp[{0, Sp}, -b, -a]\[Equal]%*)
Christoffel0UpAbstractDown=ChristoffelCDflatPDSp[{0,Sp},-b,-a]==0
(**)
 (*ChristoffelCDflatPDSp[b, -a, {0, -Sp}];
SeparateBasis[Sp][%];
TraceBasisDummy[%];
ToValues[%];
ChristoffelCDflatPDSp[b, -a, {0, -Sp}]\[Equal]%*)
ChristoffelAbstractUpAbstractDown0Down=ChristoffelCDflatPDSp[b,-a,{0,-Sp}]==0


(*NormalDownInBasis
CDflat[-b]@%[[1]]==CDflat[-b]@%[[2]]
%/.ApplyRule@BasisTimeToNormal;
%/.ApplyRule@Christoffel0UpAbstractDown;*)
DerivativeOfNormalDown=CDflat[-b][NormalN[-a]]==(NormalN[-a]*CDflat[-b][Lapse])/Lapse
(**)
(*CDflat[-a]@g[{0,Sp},{0,Sp}]
SeparateBasis[AIndex][%];
Expand[%];
ContractBasis[%];
%/.ApplyRule@Christoffel0UpAbstractDown;
CDflat[-a]@g[{0,Sp},{0,Sp}]\[Equal]%*)
DerivativeMetric00upToDown=CDflat[-a][g[{0,Sp},{0,Sp}]]==-(g[{0,Sp},b]*g[{0,Sp},c]*CDflat[-a][g[-b,-c]])
(**)
(*CDflat[-a]@g[{0,Sp},b]
SeparateBasis[AIndex][%];
Expand[%];
ContractBasis[%];
%/.ApplyRule@Christoffel0UpAbstractDown;
CDflat[-a]@g[{0,Sp},b]\[Equal]%*)
DerivativeMetric0AbstractupToDown=CDflat[-a][g[{0,Sp},b]]==-(g[b,d]*g[{0,Sp},c]*CDflat[-a][g[-c,-d]])
(**)
(*g[a,b]NormalN[-a]NormalN[-b]\[Equal]ContractMetric[g[a,b]NormalN[-a]NormalN[-b]]
%/.ApplyRule@NormalDownInBasis;
ContractBasis[%];
Flatten[Solve[%,g[{0,Sp},{0,Sp}]]];
%[[1]][[1]]\[Equal]%[[1]][[2]];
CDflat[-a]@%[[1]]\[Equal]CDflat[-a]@%[[2]]
Flatten[Solve[%,CDflat[-a]@Lapse]];
%[[1]][[1]]\[Equal]%[[1]][[2]]
%/.ApplyRule@DerivativeMetric00upToDown;
%/.ApplyRule@RuleSpacetimeReductionVariable
%/.ApplyRule@DecompositionOfSpacetimeDerivativeg;
%/.ApplyRule@Metric0sptabstractUpToLapseAndNormal*)
SubstituteDerivativesOfTheLapse=CDflat[-a][Lapse]==-(Lapse*NormalN[b]*NormalN[c]*(NormalN[-a]*PigT[-b,-c]+SpatialDerivativeg[-a,-b,-c]))/2
(**)
(*Metric0sptabstractUpToLapseAndNormal
ContractMetric[%]
%/.ApplyRule@NormalToTimeAndShift;
Expand[%];
Flatten[Solve[%,Shift[b]]];
%[[1]][[1]]\[Equal]%[[1]][[2]]
CDflat[-a]@%[[1]]\[Equal]CDflat[-a]@%[[2]];
%/.ApplyRule@ChristoffelAbstractUpAbstractDown0Down;
%/.ApplyRule@DerivativeMetric0AbstractupToDown;
%/.ApplyRule@RuleSpacetimeReductionVariable;
%/.ApplyRule@DecompositionOfSpacetimeDerivativeg;
%/.ApplyRule@Metric0sptabstractUpToLapseAndNormal;
%/.ApplyRule@MetricInTermsOfTheProjector;
%/.ApplyRule@SubstituteDerivativesOfTheLapse;
ContractMetric[%]*)
SubstituteDerivativesOfTheShift=CDflat[-a][Shift[b]]==Lapse*NormalN[-a]*NormalN[c]*PigT[-c,-d]*projector[b,d]+Lapse*NormalN[c]*projector[b,d]*SpatialDerivativeg[-a,-c,-d]
(**)
(*Metric0sptabstractUpToLapseAndNormal;
ContractMetric[%]
Flatten[Solve[%,NormalN[b]]];
%[[1]][[1]]==%[[1]][[2]];
CDflat[-a]@%[[1]]\[Equal]CDflat[-a]@%[[2]];
%/.ApplyRule@DerivativeMetric0AbstractupToDown
%/.ApplyRule@RuleSpacetimeReductionVariable;
%/.ApplyRule@DecompositionOfSpacetimeDerivativeg;
%/.ApplyRule@Metric0sptabstractUpToLapseAndNormal;
%/.ApplyRule@MetricInTermsOfTheProjector;
%/.ApplyRule@SubstituteDerivativesOfTheLapse;
ContractMetric[%]*)
SubstituteDerivativesOfTheNormalUp=CDflat[-a][NormalN[b]]==(NormalN[-a]*NormalN[b]*NormalN[c]*NormalN[d]*PigT[-c,-d])/2-NormalN[-a]*NormalN[c]*PigT[-c,-d]*projector[b,d]+(NormalN[b]*NormalN[c]*NormalN[d]*SpatialDerivativeg[-a,-c,-d])/2-NormalN[c]*projector[b,d]*SpatialDerivativeg[-a,-c,-d]
(**)
(*CDflat[-a][projector[-f,b]]
%/.ApplyRule@ProjectorDefinitionDownUp;
CDflat[-a][projector[-f,b]]\[Equal]%
%/.ApplyRuleWithoutMovingIndices@SubstituteDerivativesOfTheNormalUp;
%/.ApplyRuleWithoutMovingIndices@DerivativeOfNormalDown;
%/.ApplyRule@SubstituteDerivativesOfTheLapse;
ContractMetric[%]*)
DerivativeOfTheProjectorDownUp=CDflat[-a][projector[-f,b]]==-(NormalN[-a]*NormalN[c]*NormalN[-f]*PigT[-c,-d]*projector[b,d])-NormalN[c]*NormalN[-f]*projector[b,d]*SpatialDerivativeg[-a,-c,-d]




(*CDflat[-a]@CDflat[-b]@g[-c,-d]-CDflat[-b]@CDflat[-a]@g[-c,-d]==
SortCovDs[CDflat[-a]@CDflat[-b]@g[-c,-d]-CDflat[-b]@CDflat[-a]@g[-c,-d],CDflat]
%/.ApplyRule@RecogniseThatMinkowskiIsFlat*)
CommuteCovariantDerivativesFlat=CDflat[-a]@CDflat[-b]@g[-c,-d]==CDflat[-b]@CDflat[-a]@g[-c,-d]


RicciCD[-a,-b]
ChangeCurvature[%,CD,CDflat]


RuleConstraintToContractedChristofel=Constraint[c]==g[a,b]ChristoffelCDCDflat[c, -a, -b]+GaugeSourceFunction[c]
(**)
SubsIntermediateboxg=IntermediateBoxg[-a,-b]==g[c,d]CDflat[-c]@CDflat[-d]@g[-a,-b]
(**)
DefinitionOfSpacetimeReductionConstraint=SpacetimeReductionConstraint[-a,-b,-c]==CDflat[-a]@g[-b,-c]-SpacetimeDerivativeg[-a,-b,-c]
(**)
SpaceReductionConstraintToSpacetimeReductionConstraint=SpaceReductionConstraint[-a,-b,-c]==projector[-a,f]SpacetimeReductionConstraint[-f,-b,-c]
(**)
(*SpaceReductionConstraintToSpacetimeReductionConstraint
%/.ApplyRule@DefinitionOfSpacetimeReductionConstraint;
%/.ApplyRule@DecompositionOfSpacetimeDerivativeg;
ContractMetric[%];
%/.ApplyRule@SpatialDerivativegIsSpatialInTheFirstIndex*)
SpaceReductionConstraintAsPhiAndSpatialDerivativesOfTheMetric=SpaceReductionConstraint[-a,-b,-c]==-SpatialDerivativeg[-a,-b,-c]+projector[-a,f]*CDflat[-f][g[-b,-c]]


(***************************** for constraint addition especification *****************************************)



DefTensor[ExtraConstraintAddition[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"W"]
DefConstantSymbol@{\[Lambda]}
DefConstantSymbol@{\[Alpha]}
DefConstantSymbol@{\[Beta]}
DefTensor[ConstraintAdditionDamping[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[ScriptCapitalW]"]
DefConstantSymbol[W0,PrintAs->"\!\(\*SubscriptBox[\(\[Omega]\), \(L\)]\)"]
DefConstantSymbol[W1,PrintAs->"\!\(\*SubscriptBox[\(\[Omega]\), SubscriptBox[\(S\), \(1\)]]\)"]
DefConstantSymbol[W2,PrintAs->"\!\(\*SubscriptBox[\(\[Omega]\), SubscriptBox[\(S\), \(2\)]]\)"]
DefConstantSymbol[W3,PrintAs->"\!\(\*SubscriptBox[\(\[Omega]\), \(\[Diameter]\)]\)"]
DefTensor[L[-a],M4,PrintAs->"L"]
DefTensor[Lbar[-a],M4,PrintAs->"\[CapitalLSlash]"]
DefTensor[Svec1[-a],M4,PrintAs->"\!\(\*SubscriptBox[\(S\), \(1\)]\)"]
DefTensor[Svec2[-a],M4,PrintAs->"\!\(\*SubscriptBox[\(S\), \(2\)]\)"]
DefTensor[Scovec1[-a],M4,PrintAs->"\!\(\*SuperscriptBox[\(S\), \(1\)]\)"]
DefTensor[Scovec2[-a],M4,PrintAs->"\!\(\*SuperscriptBox[\(S\), \(2\)]\)"]
DefConstantSymbol[k0,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(0\)]\)"]
DefConstantSymbol[k1,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(1\)]\)"]
DefConstantSymbol[k2,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(2\)]\)"]
DefConstantSymbol[k3,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(3\)]\)"]
DefConstantSymbol[k4,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(4\)]\)"]
DefConstantSymbol[k5,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(5\)]\)"]
DefConstantSymbol[k6,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(6\)]\)"]
DefConstantSymbol[k7,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(7\)]\)"]
DefConstantSymbol[k8,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(8\)]\)"]
DefConstantSymbol[k9,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(9\)]\)"]
DefScalarFunction[DampingLL,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(LL\)]\)"]
DefScalarFunction[DampingLLbar,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(L\[CapitalLSlash]\)]\)"]
DefScalarFunction[DampingLbarLbar,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(\[CapitalLSlash]\[CapitalLSlash]\)]\)"]
DefScalarFunction[DampingLS1,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(LS1\)]\)"]
DefScalarFunction[DampingLS2,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(LS2\)]\)"]
DefScalarFunction[DampingLbarS1,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(\[CapitalLSlash]S1\)]\)"]
DefScalarFunction[DampingLbarS2,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(\[CapitalLSlash]S2\)]\)"]
DefScalarFunction[DampingS1S2,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(S1S2\)]\)"]
DefScalarFunction[DampingS1S1,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(S1S1\)]\)"]
DefScalarFunction[DampingS2S2,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalW]\), \(S2S2\)]\)"]


UseExtraConstraintAddition=
ExtraConstraintAddition[-a,-b]==((L[-a]*L[-b])*(Lbar[i]Lbar[j]*(Constraint[k]Symmetrize[CDflat[-i]@g[-j,-k],{-i,-j}]-(1/2)*Constraint[k]CDflat[-k]@g[-i,-j])))/4



ConstraintAdditionDamping[-a,-b]==(DampingLbarLbar*L[-b]*L[-a])/4+(DampingLLbar*L[-b]*Lbar[-a])/4+(DampingLLbar*L[-a]*Lbar[-b])/4+(DampingLL*Lbar[-a]*Lbar[-b])/4-(DampingLbarS1*L[-b]*Scovec1[-a])/2-(DampingLS1*Lbar[-b]*Scovec1[-a])/2-(DampingLbarS1*L[-a]*Scovec1[-b])/2-(DampingLS1*Lbar[-a]*Scovec1[-b])/2+DampingS1S1*Scovec1[-a]*Scovec1[-b]-(DampingLbarS2*L[-b]*Scovec2[-a])/2-(DampingLS2*Lbar[-b]*Scovec2[-a])/2+DampingS1S2*Scovec1[-b]*Scovec2[-a]-(DampingLbarS2*L[-a]*Scovec2[-b])/2-(DampingLS2*Lbar[-a]*Scovec2[-b])/2+DampingS1S2*Scovec1[-a]*Scovec2[-b]+DampingS2S2*Scovec2[-a]*Scovec2[-b];


DampingComponents={DampingLL->(1/r[])*W0*L[i]Constraint[-i]+k0*L[i]Constraint[-i]L[j] Constraint[-j],
DampingLS1->(1/r[])*W1*Svec1[i]Constraint[-i]+k1*L[i]Constraint[-i]Svec1[j] Constraint[-j] ,
DampingLS2->(1/r[])*W2*Svec2[i]Constraint[-i]+k2*L[i]Constraint[-i]Svec2[j] Constraint[-j] ,
DampingS1S1->1/2(1/r[])*W3*Lbar[i]Constraint[-i] +(1/2)k3*L[i]Constraint[-i]Lbar[j]Constraint[-j]-(1/2)k4*L[i]Constraint[-i]Lbar[f]Svec1[j]Svec1[k]CDflat[-f][g[-j,-k]] ,
DampingS2S2->1/2(1/r[])*W3*Lbar[i]Constraint[-i]+(1/2)k3*L[i]Constraint[-i]Lbar[j]Constraint[-j]-(1/2)k4*L[i]Constraint[-i]Lbar[f]Svec2[j]Svec2[k]CDflat[-f][g[-j,-k]],
DampingLLbar->-(1/2)k5*L[i]Constraint[-i]Lbar[f]L[j]Lbar[k]CDflat[-f][g[-j,-k]] ,
DampingLbarLbar->(-1/2)k9*L[i]Constraint[-i]Lbar[f]Lbar[j]Lbar[k]CDflat[-f][g[-j,-k]],
DampingLbarS1->-(1/2)k7*L[i]Constraint[-i]Lbar[f]Lbar[j]Svec1[k]CDflat[-f][g[-j,-k]],
DampingLbarS2->-(1/2)k8*L[i]Constraint[-i]Lbar[f]Lbar[j]Svec2[k]CDflat[-f][g[-j,-k]],
DampingS1S2->-(1/2)k6*L[i]Constraint[-i]Lbar[f]Svec1[j]Svec2[k]CDflat[-f][g[-j,-k]]};





(DampingLbarLbar*L[-b]*L[-a])/4+(DampingLLbar*L[-b]*Lbar[-a])/4+(DampingLLbar*L[-a]*Lbar[-b])/4+(DampingLL*Lbar[-a]*Lbar[-b])/4-(DampingLbarS1*L[-b]*Scovec1[-a])/2-(DampingLS1*Lbar[-b]*Scovec1[-a])/2-(DampingLbarS1*L[-a]*Scovec1[-b])/2-(DampingLS1*Lbar[-a]*Scovec1[-b])/2+DampingS1S1*Scovec1[-a]*Scovec1[-b]-(DampingLbarS2*L[-b]*Scovec2[-a])/2-(DampingLS2*Lbar[-b]*Scovec2[-a])/2+DampingS1S2*Scovec1[-b]*Scovec2[-a]-(DampingLbarS2*L[-a]*Scovec2[-b])/2-(DampingLS2*Lbar[-a]*Scovec2[-b])/2+DampingS1S2*Scovec1[-a]*Scovec2[-b]+DampingS2S2*Scovec2[-a]*Scovec2[-b];
%/.DampingComponents;
UseConstraintAdditionDamping=ConstraintAdditionDamping[-a,-b]==(Lbar[-a]*Lbar[-b]*(k0*Constraint[-i]*Constraint[-j]*L[i]*L[j]+(W0*Constraint[-i]*L[i])/r[]))/4-(Lbar[-b]*Scovec1[-a]*((W1*Constraint[-i]*Svec1[i])/r[]+k1*Constraint[-i]*Constraint[-j]*L[i]*Svec1[j]))/2-(Lbar[-a]*Scovec1[-b]*((W1*Constraint[-i]*Svec1[i])/r[]+k1*Constraint[-i]*Constraint[-j]*L[i]*Svec1[j]))/2-(Lbar[-b]*Scovec2[-a]*((W2*Constraint[-i]*Svec2[i])/r[]+k2*Constraint[-i]*Constraint[-j]*L[i]*Svec2[j]))/2-(Lbar[-a]*Scovec2[-b]*((W2*Constraint[-i]*Svec2[i])/r[]+k2*Constraint[-i]*Constraint[-j]*L[i]*Svec2[j]))/2-(k5*Constraint[-i]*L[-b]*L[i]*L[j]*Lbar[-a]*Lbar[f]*Lbar[k]*CDflat[-f][g[-j,-k]])/8-(k5*Constraint[-i]*L[-a]*L[i]*L[j]*Lbar[-b]*Lbar[f]*Lbar[k]*CDflat[-f][g[-j,-k]])/8-(k9*Constraint[-i]*L[-a]*L[-b]*L[i]*Lbar[f]*Lbar[j]*Lbar[k]*CDflat[-f][g[-j,-k]])/8+(k7*Constraint[-i]*L[-b]*L[i]*Lbar[f]*Lbar[j]*Scovec1[-a]*Svec1[k]*CDflat[-f][g[-j,-k]])/4+(k7*Constraint[-i]*L[-a]*L[i]*Lbar[f]*Lbar[j]*Scovec1[-b]*Svec1[k]*CDflat[-f][g[-j,-k]])/4+(k8*Constraint[-i]*L[-b]*L[i]*Lbar[f]*Lbar[j]*Scovec2[-a]*Svec2[k]*CDflat[-f][g[-j,-k]])/4+(k8*Constraint[-i]*L[-a]*L[i]*Lbar[f]*Lbar[j]*Scovec2[-b]*Svec2[k]*CDflat[-f][g[-j,-k]])/4-(k6*Constraint[-i]*L[i]*Lbar[f]*Scovec1[-b]*Scovec2[-a]*Svec1[j]*Svec2[k]*CDflat[-f][g[-j,-k]])/2-(k6*Constraint[-i]*L[i]*Lbar[f]*Scovec1[-a]*Scovec2[-b]*Svec1[j]*Svec2[k]*CDflat[-f][g[-j,-k]])/2+Scovec1[-a]*Scovec1[-b]*((k3*Constraint[-i]*Constraint[-j]*L[i]*Lbar[j])/2+(W3*Constraint[-i]*Lbar[i])/(2*r[])-(k4*Constraint[-i]*L[i]*Lbar[f]*Svec1[j]*Svec1[k]*CDflat[-f][g[-j,-k]])/2)+Scovec2[-a]*Scovec2[-b]*((k3*Constraint[-i]*Constraint[-j]*L[i]*Lbar[j])/2+(W3*Constraint[-i]*Lbar[i])/(2*r[])-(k4*Constraint[-i]*L[i]*Lbar[f]*Svec2[j]*Svec2[k]*CDflat[-f][g[-j,-k]])/2)





ReducedEinsteinEquationShortcut=(-1/2)*g[c,d]CDflat[-c]@CDflat[-d]@g[-a,-b]+g[c,d]g[h,f](CDflat[-h]@g[-c,-a]CDflat[-f]@g[-d,-b]-ChristoffelCDCDflat[-a, -c, -h]ChristoffelCDCDflat[-b, -d, -f])+ 
-Symmetrize[CD[-a][GaugeSourceFunction[-b]],{-a,-b}]+GenericConstraintAddition[-a,-b]==0



(*-\[Beta]*Constraint[c]Symmetrize[CDflat[-a]@g[-b,-c],{-a,-b}]+(1/2)*\[Beta]*Constraint[-a]Constraint[-b]+\[Lambda]*ExtraConstraintAddition[-a,-b]+\[Alpha]*ConstraintAdditionDamping[-a,-b]
%/.ApplyRule@UseConstraintAdditionDamping
%/.ApplyRule@UseExtraConstraintAddition;
%/.ApplyRule@RuleConstraintToContractedChristofel;
ChristoffelToGradMetric[%,g];
ToCanonical[%]//ScreenDollarIndices;*)
(*InputForm[%]*)



(* definitions for eikonal eq*)
DefTensor[xi[-a],M4,PrintAs->"\[Xi]"]
IntegrabilityCondition=CD[-a]@xi[-b]==CD[-b]@xi[-a]




(************************************************ definitions for the Bondi-mass discussion **********************************************)


DefTensor[RadialS[-a],M4,PrintAs->"s"]
DefTensor[projectorq[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"q"]
DefScalarFunction[LengthScalar,PrintAs->"L"]
DefTensor[GradR[-a],M4,PrintAs->"R"]
DefScalarFunction[TraceCDflatR,PrintAs->"q\[Del]R"]


ScreenIndicesProjectedCDflatGradR=projectorq[a,b]*CDflat[-a][GradR[-b]]==TraceCDflatR
ProjectorqDefinition=projectorq[-a,-b]==projector[-a,-b]-RadialS[-a]RadialS[-b]
RadialSsubsitution=RadialS[-a]==LengthScalar*projector[-a,b]GradR[-b]
SubstituteGradR=GradR[-b]==CDflat[-b]@r[]
RadialIsnormalised=RadialS[-a]RadialS[a]==1
RadialAndNormalOrthogonal=RadialS[-a]NormalN[a]==0




projectorq[a,b]RadialS[-a]
%/.ApplyRule@ProjectorqDefinition;
ContractMetric[%];
%/.ApplyRule@RadialIsnormalised;
%/.ApplyRule@ProjectorDefinition;
ContractMetric[%];
%/.ApplyRule@RadialAndNormalOrthogonal
ProjectedqRadialisZero=projectorq[a,b]RadialS[-a]==0
(**)
projectorq[a,b]NormalN[-a]
%/.ApplyRule@ProjectorqDefinition;
ContractMetric[%];
%/.ApplyRule@RadialAndNormalOrthogonal
ProjectedqNormalisZero=projectorq[a,b]NormalN[-a]==0


projectorq[-a,b]projector[-b,c]-projectorq[-a,c]
%/.ApplyRule@ProjectorqDefinition;
%/.ApplyRule@ProjectorDefinition;
ContractMetric[%];
%/.ApplyRule@RadialIsnormalised;
%/.ApplyRule@RadialAndNormalOrthogonal
ProjectedProjectorq=projectorq[-a,b]projector[-b,c]==projectorq[-a,c]


(*LengthScalar^(-1)*RadialSsubsitution
Reverse[%];*)
ReversedRadialSsubsitution=GradR[-b]*projector[-a,b]==RadialS[-a]/LengthScalar


ChristoffelCDflatPDSp[{1, Sp}, -b, -a]
SeparateBasis[Sp][%];
TraceBasisDummy[%];
ToValues[%]
Christoffel1UpAbstractDown=ChristoffelCDflatPDSp[{1,Sp},-b,-a]==-(Basis[-a,{2,Sp}]*Basis[-b,{2,Sp}]*r[])-Basis[-a,{3,Sp}]*Basis[-b,{3,Sp}]*r[]*Sin[\[Theta][]]^2


DefTensor[EndOfSetUpFile[],M4,PrintAs->"END-OF-SET-UP-FILE"]


EndOfSetUpFile[]
