(* ::Package:: *)

(*Set up for asymptotic systems*)

(*This a notebook associated to the paper
 The Weak Null Condition in Free-evolution Schemes for Numerical Relativity:
Dual Foliation GHG with Constraint Damping
December 2018.
E. Gasper\[IAcute]n & D. Hilditch*)



<<xAct`xTensor`


(*Set up: global*)
(*Definition of the Manifold and global rulemakers *)
DefManifold[M4,4,{a,b,c,d,f,p,h,i,j,k,l,n,u,v,w}]
ApplyRule[expr_]:=MakeRule[Evaluate[List@@expr],MetricOn->All,ContractMetrics->True]
ApplyRuleN[expr_]:=MakeRule[Evaluate[List@@expr]]
$MixedDers=False;
Off[ToCanonical::noident]
$PrePrint=ScreenDollarIndices;
ApplyRule[expr_]:=MakeRule[Evaluate[List@@expr],MetricOn->All,ContractMetrics->True]
ApplyRuleWithoutMovingIndices[expr_]:=MakeRule[Evaluate[List@@expr]]


(*Set up: m - metric *)
(*Canonicalisation is done respect to the m metric*)


(*UndefMetric[g]*)


(*UndefMetric[m]*)


DefMetric[-1,m[-a,-b],CDflat,SymbolOfCovD->{"%","\!\(\*OverscriptBox[\(\[Del]\), \(\[FilledSmallCircle]\)]\)"}]


DefMetric[{3,1,0},g[-a,-b],CD,{";","\[Del]"}]


(*Set up: formal split *)
(*Formal split of the metric into background and perturbation*)


DefTensor[testvector[-a],M4,PrintAs->"v"]
DefScalarFunction[RadialCoordinate,PrintAs->"r"]
DefTensor[Perturbationh[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"h"]
DefTensor[PerturbationIntermediateH[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[ScriptCapitalH]"]
DefTensor[PerturbationH[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"H"]
DefTensor[higherOrderTensor[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"o"]
DefTensor[HigherOrderTensorIntermediate[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[Mho]"]
DefTensor[HigherOrderTensor[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[ScriptCapitalO]"]
DefTensor[HigherOrderVector[-a],M4,PrintAs->"\[ScriptCapitalO]"]
(**)
DefConstantSymbol[DeltaCounter,PrintAs->"\[Delta]"]
DefTensor[IntermediateBoxh[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(\[EmptySquare]\), \(~\)]\)h"]


RuleMetricDeltaCounterCovariantSplit=g[-a,-b]==m[-a,-b]+DeltaCounter*Perturbationh[-a,-b]
RuleMetricDeltaCounterContravariantSplit=Invg[a,b]==m[a,b]-DeltaCounter*Perturbationh[a,b]+DeltaCounter^2m[-c,-f]Perturbationh[a,c]Perturbationh[f,b]+DeltaCounter^3*higherOrderTensor[a,b]
ScreenIntermediateBoxOfh=DeltaCounter*Invg[c,d]*CDflat[-d][CDflat[-c][Perturbationh[-a,-b]]]==IntermediateBoxh[-a,-b]


(*Covariant*)


RuleMetricCovariantSplit=g[-a,-b]==m[-a,-b]+Perturbationh[-a,-b]
RulePerturbationhToHIntermediate=Perturbationh[-a,-b]==PerturbationIntermediateH[-a,-b]


(*Contravariant*)


RuleMetricContravariantSplit=Invg[a,b]==m[a,b]-Perturbationh[a,b]+m[-c,-f]Perturbationh[a,c]Perturbationh[f,b]+higherOrderTensor[a,b]
RuleHigherOrderTensorIntermediate= higherOrderTensor[a,b]==HigherOrderTensorIntermediate[a,b]



(*Check*)


g[-a,-b]
%/.ApplyRuleWithoutMovingIndices@RuleMetricCovariantSplit
%/.ApplyRuleWithoutMovingIndices@RulePerturbationhToHIntermediate


(*Shortcut rules*)


CovariantSplitShortcutIntermediate=g[-a,-b]==m[-a,-b]+PerturbationIntermediateH[-a,-b]
ContravariantSplitShortcutIntermediate=Invg[a,b]==HigherOrderTensor[a,b]+m[a,b]-PerturbationIntermediateH[a,b]


(*Sanity check: Checking that  using \[OpenCurlyDoubleQuote]ApplyRuleWithoutMovingIndices\[CloseCurlyDoubleQuote]  is safe. 
Namely that it does not move indices so we can introduce different rules for the split of the covariant and contravariant metric.*)


g[a,b]
%/.ApplyRuleWithoutMovingIndices@RuleMetricCovariantSplit
%/.ApplyRuleWithoutMovingIndices@RulePerturbationhToHIntermediate


Invg[a,b]
%/.ApplyRuleWithoutMovingIndices@RuleMetricCovariantSplit
%/.ApplyRuleWithoutMovingIndices@RulePerturbationhToHIntermediate


(*Set up: asymptotic split*)
(*xCoba is used for the detailed decomposition in the null frame*)


<<xAct`xCoba`


DefChart[Sp,M4,{0,1,2,3},{t[],r[],\[Theta][],\[Phi][]}]


RulexCobaHigherOrderTensorFinal= HigherOrderTensorIntermediate[a,b]==(1/r[])^2HigherOrderTensor[a,b]
RulexCobaPerturbationHIntermediateToFinalH=PerturbationIntermediateH[-a,-b]==(1/r[])*PerturbationH[-a,-b]
RulexCobaCovariantSplitShortcutFinal=g[-a,-b]==m[-a,-b]+(1/r[])*PerturbationH[-a,-b]
RulexCobaContravariantSplitShortcutFinal=Invg[a,b]==(1/r[])^3*HigherOrderTensor[a,b]+m[a,b]-(1/r[])*PerturbationH[a,b]+(1/r[]^2)*m[-c,-f]PerturbationH[a,c]PerturbationH[f,b]



(*Definitions and Rules*)


(*Basic definitions : 
Spherical Coordinates (t, r), Lindblad' s coordinates (q, s), null vectors of Minkowski (L, \[CapitalLSlash])*)


MatrixForm[MinkowskiSp={
{-1,0,0,0},
{0,1,0,0},
{0,0,r[]^2,0},
{0,0,0,r[]^2 Sin[\[Theta][]]^2}
}]


MetricInBasis[m,-Sp,MinkowskiSp]


MetricCompute[m,Sp,All,CVSimplify->Simplify]


MetricCompute[m,Sp,"Riemann"[-1,-1,-1,-1],CVSimplify->Simplify]
Last@TensorValues[RiemannCDflat]


MetricCompute[m,Sp,"Christoffel"[1,-1,-1],CVSimplify->Simplify]
Last@TensorValues[ChristoffelCDflatPDSp]


DefChart[Li,M4,{0,1,2,3},{q[],s[],\[Theta][],\[Phi][]},ChartColor->Orange (*,FormatBasis\[Rule]{"Partials","Differentials"}*)]


(* Jacobian relating the two basis, essential components*)
ComponentValue[Basis[{0,-Sp},{0,Li}],-1]
ComponentValue[Basis[{0,-Sp},{1,Li}],0]
ComponentValue[Basis[{0,-Sp},{2,Li}],0]
ComponentValue[Basis[{0,-Sp},{3,Li}],0]
ComponentValue[Basis[{1,-Sp},{0,Li}],1]
ComponentValue[Basis[{1,-Sp},{1,Li}],1/r[]]
ComponentValue[Basis[{1,-Sp},{2,Li}],0]
ComponentValue[Basis[{1,-Sp},{3,Li}],0]
(* Angular ones*)
ComponentValue[Basis[{2,-Sp},{0,Li}],0]
ComponentValue[Basis[{2,-Sp},{1,Li}],0]
ComponentValue[Basis[{2,-Sp},{2,Li}],1]
ComponentValue[Basis[{2,-Sp},{3,Li}],0]
ComponentValue[Basis[{3,-Sp},{0,Li}],0]
ComponentValue[Basis[{3,-Sp},{1,Li}],0]
ComponentValue[Basis[{3,-Sp},{2,Li}],0]
ComponentValue[Basis[{3,-Sp},{3,Li}],1]


Basis[{0,-Sp},c]testvector[-c]
SeparateBasis[Li][%]
%//TraceBasisDummy;
ContractBasis[%]
ToValues[%]
(**)
Basis[{1,-Sp},c]testvector[-c]
SeparateBasis[Li][%]
%//TraceBasisDummy;
ContractBasis[%]
ToValues[%]


(*The Chain Rule
--passing from directional derivatives in spherical coordinates to Lindblad' s coordinates.*)


ChangeCovariantDerivative0Sp=CDflat[{0,-Sp}]@expr_:>-CDflat[{0,-Li}]@expr
ChangeCovariantDerivative1Sp=CDflat[{1,-Sp}]@expr_:>CDflat[{0,-Li}]@expr+(1/r[])CDflat[{1,-Li}]@expr
(*****************)

ChangeCovariantDerivative0LiToSp=CDflat[{0,-Li}]@expr_:>-CDflat[{0,-Sp}]@expr
ChangeCovariantDerivative1LiToSp=CDflat[{1,-Li}][expr_]:>r[]*(CDflat[{1,-Sp}][expr]+CDflat[{0,-Sp}]@expr)


CommutePartialsToSimplifyExpressionQandS=CDflat[{0,-Li}]@CDflat[{1,-Li}]@expr_:>CDflat[{1,-Li}]@CDflat[{0,-Li}]@expr
CommutePartialsToSimplifyExpressionAngleRed2AndQ=CDflat[{2,-Sp}]@CDflat[{0,-Li}]@expr_:>CDflat[{0,-Li}]@CDflat[{2,-Sp}]@expr
CommutePartialsToSimplifyExpressionAngleRed3AndQ=CDflat[{3,-Sp}]@CDflat[{0,-Li}]@expr_:>CDflat[{0,-Li}]@CDflat[{3,-Sp}]@expr


Basis[{-a,-Sp},{b,Li}]Basis[{c,Sp},{-b,-Li}]
ContractBasis[%]
ComponentArray[%]//MatrixForm
Basis[{-a,-Sp},{b,Li}]Basis[{a,Sp},{-c,-Li}]
ContractBasis[%]
ComponentArray[%]//MatrixForm


ComponentArray[Basis[{-a,-Sp},{b,Li}]]//MatrixForm
ToValues[%]//MatrixForm
Inverse[%]//MatrixForm


ComponentValue[Basis[{0,-Li},{0,Sp}],-1]
ComponentValue[Basis[{0,-Li},{1,Sp}],0]
ComponentValue[Basis[{0,-Li},{2,Sp}],0]
ComponentValue[Basis[{0,-Li},{3,Sp}],0]
ComponentValue[Basis[{1,-Li},{0,Sp}],r[]]
ComponentValue[Basis[{1,-Li},{1,Sp}],r[]]
ComponentValue[Basis[{1,-Li},{2,Sp}],0]
ComponentValue[Basis[{1,-Li},{3,Sp}],0]
(* Angular ones*)
ComponentValue[Basis[{2,-Li},{0,Sp}],0]
ComponentValue[Basis[{2,-Li},{1,Sp}],0]
ComponentValue[Basis[{2,-Li},{2,Sp}],1]
ComponentValue[Basis[{2,-Li},{3,Sp}],0]
ComponentValue[Basis[{3,-Li},{0,Sp}],0]
ComponentValue[Basis[{3,-Li},{1,Sp}],0]
ComponentValue[Basis[{3,-Li},{2,Sp}],0]
ComponentValue[Basis[{3,-Li},{3,Sp}],1]


ComponentArray[Basis[{-a,-Li},{b,Sp}]]//MatrixForm
ToValues[%]//MatrixForm


Basis[{0, -Li}, d]
SeparateBasis[Sp][%];
TraceBasisDummy[%];
ToValues[%]
SubstituteOrange0IndexWithRedZeroIndex=Basis[{0,-Li},d]==-Basis[{0,-Sp},d]


RuleCommuteRed02=CDflat[{0, -Sp}]@CDflat[{2, -Sp}]@expr_:> CDflat[{2, -Sp}]@CDflat[{0, -Sp}]@expr
RuleCommuteRed03=CDflat[{0, -Sp}]@CDflat[{3, -Sp}]@expr_:> CDflat[{3, -Sp}]@CDflat[{0, -Sp}]@expr
RuleCommuteOrange10=CDflat[{0, -Li}]@CDflat[{1, -Li}]@expr_:> CDflat[{1, -Li}]@CDflat[{0, -Li}]@expr



DefTensor[L[-a],M4,PrintAs->"L"]
DefTensor[Lbar[-a],M4,PrintAs->"\[CapitalLSlash]"]
DefTensor[Svec1[-a],M4,PrintAs->"\!\(\*SubscriptBox[\(S\), \(1\)]\)"]
DefTensor[Svec2[-a],M4,PrintAs->"\!\(\*SubscriptBox[\(S\), \(2\)]\)"]
DefTensor[Scovec1[-a],M4,PrintAs->"\!\(\*SuperscriptBox[\(S\), \(1\)]\)"]
DefTensor[Scovec2[-a],M4,PrintAs->"\!\(\*SuperscriptBox[\(S\), \(2\)]\)"]
(**)


DefScalarFunction[HLL,PrintAs->"\!\(\*SubscriptBox[\(H\), \(LL\)]\)"]
DefScalarFunction[HLLbar,PrintAs->"\!\(\*SubscriptBox[\(H\), \(L\[CapitalLSlash]\)]\)"]
DefScalarFunction[HLbarLbar,PrintAs->"\!\(\*SubscriptBox[\(H\), \(\[CapitalLSlash]\[CapitalLSlash]\)]\)"]
DefScalarFunction[HLS1,PrintAs->"\!\(\*SubscriptBox[\(H\), \(LS1\)]\)"]
DefScalarFunction[HLS2,PrintAs->"\!\(\*SubscriptBox[\(H\), \(LS2\)]\)"]
DefScalarFunction[HLbarS1,PrintAs->"\!\(\*SubscriptBox[\(H\), \(\[CapitalLSlash]S1\)]\)"]
DefScalarFunction[HLbarS2,PrintAs->"\!\(\*SubscriptBox[\(H\), \(\[CapitalLSlash]S2\)]\)"]
DefScalarFunction[HS1S2,PrintAs->"\!\(\*SubscriptBox[\(H\), \(S1S2\)]\)"]
DefScalarFunction[HS1S1,PrintAs->"\!\(\*SubscriptBox[\(H\), \(S1S1\)]\)"]
DefScalarFunction[HS2S2,PrintAs->"\!\(\*SubscriptBox[\(H\), \(S2S2\)]\)"]
(**)


DefScalarFunction[nHLL,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(H\), \(~\)], \(LL\)]\)"]
DefScalarFunction[nHLS1,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(H\), \(~\)], \(LS1\)]\)"]
DefScalarFunction[nHLS2,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(H\), \(~\)], \(LS2\)]\)"]
DefScalarFunction[nHtraceonsphere,PrintAs->"\!\(\*SuperscriptBox[OverscriptBox[\(H\), \(~\)], \(\[Diameter]\)]\)"]


(*Notation : Observe the difference in the interpretation of these two objects in xCoba*)


Basis[{3,-Sp},-a]
Basis[{3,Sp},-a]


FlatNullInTermsOfBasisSp={L[a]==Basis[{0,-Sp},a]+Basis[{1,-Sp},a], Lbar[a]==Basis[{0,-Sp},a]-Basis[{1,-Sp},a],L[-a]==-Basis[{0,Sp},-a]+Basis[{1,Sp},-a], Lbar[-a]==-Basis[{0,Sp},-a]-Basis[{1,Sp},-a]}
OrthoNormalAngularFrameBasisSP={Svec1[a]==(1/r[])Basis[{2,-Sp},a],Svec2[a]==(1/r[])(1/Sin[\[Theta][]])*Basis[{3,-Sp},a],Scovec1[-a]==r[]Basis[{2,Sp},-a],Scovec2[-a]==r[]Sin[\[Theta][]]Basis[{3,Sp},-a]}
BasisSpToFlatNull={Basis[{0,-Sp},a]==(1/2)(L[a]+Lbar[a]),Basis[{1,-Sp},a]==(1/2)(L[a]-Lbar[a]),Basis[{0,Sp},-a]==-(1/2)(L[-a]+Lbar[-a]),Basis[{1,Sp},-a]==(1/2)(L[-a]-Lbar[-a])}
BasisSpToS1S2={Basis[{2,-Sp},a]==r[]*Svec1[a],Basis[{3,-Sp},a]==r[]*Sin[\[Theta][]]*Svec2[a],Basis[{2,Sp},-a]==(1/r[])Scovec1[-a],Basis[{3,Sp},-a]==(1/r[])*(1/Sin[\[Theta][]])*Scovec2[-a]}


ApplyRuleFlatNullInTermsOfBasisSp=Flatten[ApplyRuleWithoutMovingIndices/@FlatNullInTermsOfBasisSp];
ApplyRuleBasisSpToFlatNull=Flatten[ApplyRuleWithoutMovingIndices/@BasisSpToFlatNull];
ApplyRuleBasisSpToS1S2=Flatten[ApplyRuleWithoutMovingIndices/@BasisSpToS1S2];
ApplyRuleOrthoNormalAngularFrameBasisSP=Flatten[ApplyRuleWithoutMovingIndices/@OrthoNormalAngularFrameBasisSP];



(*Warning : if OrthoNormalAngularFrameBasisSP is applied in the main calculation this will kill all the angular components due to the 1/r factor.
   One wants to kill angular derivatives  but not the angular components.*)


(*The following rules are made for killing angular derivatives but not angular components*)


Svec1[a]CDflat[-a]@expr
%/.ApplyRuleOrthoNormalAngularFrameBasisSP
(**)
Scovec1[a]CDflat[-a]@expr
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
DummyToBasis[Sp][%];
TraceBasisDummy[%];
ToValues[%];
SeparateBasis[AIndex][%]
(**)
Svec2[a]CDflat[-a]@expr
%/.ApplyRuleOrthoNormalAngularFrameBasisSP
(**)
Scovec2[a]CDflat[-a]@expr
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
DummyToBasis[Sp][%];
TraceBasisDummy[%];
ToValues[%];
SeparateBasis[AIndex][%]
(**)


RecogniseThatMinkowskiIsFlat=RiemannCDflat[-a,-b,-c,d]==0


CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]
SortCovDs[%,CDflat]
%/.ApplyRule@RecogniseThatMinkowskiIsFlat


(* angular derivative rules*)
RuleAngularDerivativesSvec1CarryAoneOverRfactor= Module[{a},Svec1[a]CDflat[-a]@expr_:>(1/r[])Basis[{2,-Sp},a]CDflat[-a]@expr]
RuleAngularDerivativesScovec1CarryAoneOverRfactor= Module[{a},Scovec1[a]CDflat[-a]@expr_:>(1/r[])Basis[{2,-Sp},a]CDflat[-a]@expr]
RuleAngularDerivativesSvec2CarryAoneOverRfactor= Module[{a},Svec2[a]CDflat[-a]@expr_:>(1/r[])(Csc[\[Theta][]])Basis[{3,-Sp},a]CDflat[-a]@expr]
RuleAngularDerivativesScovec2CarryAoneOverRfactor= Module[{a},Scovec2[a]CDflat[-a]@expr_:>(1/r[])(Csc[\[Theta][]])Basis[{3,-Sp},a]CDflat[-a]@expr]


Svec1[a]CDflat[-b]@CDflat[-a]@expr
%/.ApplyRuleOrthoNormalAngularFrameBasisSP



(*check *)


Svec1[a]Scovec1[-a]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%]
(**)
Svec1[a]Svec1[b]m[-a,-b]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]


AutomaticRules[Svec1,MakeRule[{
Svec1[a]Scovec1[-a],1},MetricOn-> All,ContractMetrics-> True]]
AutomaticRules[Svec1,MakeRule[{
Svec1[a]Scovec2[-a],0},MetricOn-> All,ContractMetrics-> True]]
AutomaticRules[Scovec1,MakeRule[{
Scovec1[-a]Svec2[a],0},MetricOn-> All,ContractMetrics-> True]]
AutomaticRules[Svec2,MakeRule[{
Svec2[a]Scovec2[-a],1},MetricOn-> All,ContractMetrics-> True]]


(*Checks and automatisation of contractions*)


(*(L, \[CapitalLSlash], Subscript[S, 1], Subscript[S, 2] ) -frame*)


m[-a,-b]L[a]L[b]
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
ToValues[%]
(**)
m[-a,-b]L[a]Lbar[b]
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
ToValues[%]
(**)
m[-a,-b]Lbar[a]Lbar[b]
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
ToValues[%]


(* ::Input:: *)
(*m[a,b]L[-a]L[-b]*)
(*ContractMetric[%];*)
(*%/.ApplyRuleFlatNullInTermsOfBasisSp;*)
(*ContractBasis[%];*)
(*ToValues[%]*)
(*(**)*)
(*m[a,b]L[-a]Lbar[-b]*)
(*ContractMetric[%];*)
(*%/.ApplyRuleFlatNullInTermsOfBasisSp;*)
(*ContractBasis[%];*)
(*ToValues[%]*)
(*(**)*)
(*m[a,b]Lbar[-a]Lbar[-b]*)
(*ContractMetric[%];*)
(*%/.ApplyRuleFlatNullInTermsOfBasisSp;*)
(*ContractBasis[%];*)
(*ToValues[%]*)


(* ::Input:: *)
(**)


AutomaticRules[L,MakeRule[{
L[-a]L[a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Lbar,MakeRule[{
Lbar[-a]Lbar[a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[L,MakeRule[{
L[-a]Lbar[a],-2},MetricOn-> All,ContractMetrics-> True]]
(**)
(**)
AutomaticRules[L,MakeRule[{
m[-a,-b]L[a]L[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Lbar,MakeRule[{
m[-a,-b]Lbar[a]Lbar[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[L,MakeRule[{
m[-a,-b]L[a]Lbar[b],-2},MetricOn-> All,ContractMetrics-> True]]


(* inner product between vectors*)


m[-a,-b]L[a]Svec1[b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[-a,-b]Lbar[a]Svec1[b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[-a,-b]L[a]Svec2[b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[-a,-b]Lbar[a]Svec2[b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[-a,-b]Svec1[a]Svec2[b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[-a,-b]Svec1[a]Svec1[b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[-a,-b]Svec2[a]Svec2[b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)


AutomaticRules[Svec1,MakeRule[{
L[-a]Svec1[a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec1,MakeRule[{
Lbar[-a]Svec1[a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec2,MakeRule[{
L[-a]Svec2[a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec2,MakeRule[{
Lbar[-a]Svec2[a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec1,MakeRule[{
Svec1[-a]Svec2[a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec1,MakeRule[{
Svec1[-a]Svec1[a],1},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec2,MakeRule[{
Svec2[-a]Svec2[a],1},MetricOn-> All,ContractMetrics-> True]]
(**)
(**)
AutomaticRules[Svec1,MakeRule[{
m[-a,-b]L[a]Svec1[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec1,MakeRule[{
m[-a,-b]Lbar[a]Svec1[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec2,MakeRule[{
m[-a,-b]L[a]Svec2[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec2,MakeRule[{
m[-a,-b]Lbar[a]Svec2[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec1,MakeRule[{
m[-a,-b]Svec1[a]Svec2[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec1,MakeRule[{
m[-a,-b]Svec1[a]Svec1[b],1},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Svec2,MakeRule[{
m[-a,-b]Svec2[a]Svec2[b],1},MetricOn-> All,ContractMetrics-> True]]


(* inner product between covectors*)
m[a,b]L[-a]Scovec1[-b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[a,b]Lbar[-a]Scovec1[-b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[a,b]L[-a]Scovec2[-b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[a,b]Lbar[-a]Scovec2[-b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[a,b]Scovec1[-a]Scovec2[-b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[a,b]Scovec1[-a]Scovec1[-b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]
(**)
m[a,b]Scovec2[-a]Scovec2[-b]
(*ContractMetric[%];*)
%/.ApplyRuleFlatNullInTermsOfBasisSp;
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractMetric[%];
ToValues[%]


AutomaticRules[Scovec1,MakeRule[{
L[a]Scovec1[-a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec1,MakeRule[{
Lbar[a]Scovec1[-a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec2,MakeRule[{
L[a]Scovec2[-a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec2,MakeRule[{
Lbar[a]Scovec2[-a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec1,MakeRule[{
Scovec1[a]Scovec2[-a],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec1,MakeRule[{
Scovec1[a]Scovec1[-a],1},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec2,MakeRule[{
Scovec2[a]Scovec2[-a],1},MetricOn-> All,ContractMetrics-> True]]
(**)
(**)
AutomaticRules[Scovec1,MakeRule[{
m[-a,-b]L[a]Scovec1[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec1,MakeRule[{
m[-a,-b]Lbar[a]Scovec1[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec2,MakeRule[{
m[-a,-b]L[a]Scovec2[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec2,MakeRule[{
m[-a,-b]Lbar[a]Scovec2[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec1,MakeRule[{
m[-a,-b]Scovec1[a]Scovec2[b],0},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec1,MakeRule[{
m[-a,-b]Scovec1[a]Scovec1[b],1},MetricOn-> All,ContractMetrics-> True]]
(**)
AutomaticRules[Scovec2,MakeRule[{
m[-a,-b]Scovec2[a]Scovec2[b],1},MetricOn-> All,ContractMetrics-> True]]


(* inner prodcut between vector and covectors*)
Svec1[a]Scovec1[-a]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%]
Svec1[a]Scovec2[-a]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%]
Svec2[a]Scovec2[-a]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%]



(*Expression of the contravariant Minkowski metric in terms of the basis vectors
This definition is, strictly speaking, not necessary given the xCoba commands, nevertheless is convenient to short certain calculations.
On should be careful to only apply this rule using  ApplyRuleWithoutMovingIndices*)


RuleMinkowskiMetricToLLbarSContravariant=m[a,b]==-Symmetrize[L[a]Lbar[b]]+(Svec1[a]Svec1[b]+Svec2[a]Svec2[b])



ApplyRuleRuleMinkowskiMetricToLLbarSContravariant=ApplyRuleWithoutMovingIndices@RuleMinkowskiMetricToLLbarSContravariant;



(*Expressing (a symmetric two tensor)   Subscript[H, ab]  in terms of the basis*)



RulePerturbationHToLLbarAndS=PerturbationH[-a,-b]==(1/4)(HLbarLbar)L[-a]L[-b]+(1/4)(HLL)Lbar[-a]Lbar[-b]+ (1/2)(HLLbar)Symmetrize[L[-a]Lbar[-b]]+-(HLbarS1)Symmetrize[L[-a]Scovec1[-b]]-(HLbarS2)Symmetrize[L[-a]Scovec2[-b]]-(HLS1)Symmetrize[Lbar[-a]Scovec1[-b]]+-(HLS2)Symmetrize[Lbar[-a]Scovec2[-b]]+2*(HS1S2)Symmetrize[Scovec1[-a]Scovec2[-b]]+(HS1S1)Scovec1[-a]Scovec1[-b]+(HS2S2)*Scovec2[-a]Scovec2[-b];


PerturbationH[-a,-b];
%/.ApplyRule@RulePerturbationHToLLbarAndS;
PerturbationH[-a,-b]==%
InputForm[%];
RulePerturbationHToLLbarAndSCovariant=PerturbationH[-a,-b]==(HLbarLbar*L[-a]*L[-b])/4+(HLLbar*L[-b]*Lbar[-a])/4+(HLLbar*L[-a]*Lbar[-b])/4+(HLL*Lbar[-a]*Lbar[-b])/4-(HLbarS1*L[-b]*Scovec1[-a])/2-(HLS1*Lbar[-b]*Scovec1[-a])/2-(HLbarS1*L[-a]*Scovec1[-b])/2-(HLS1*Lbar[-a]*Scovec1[-b])/2+HS1S1*Scovec1[-a]*Scovec1[-b]-(HLbarS2*L[-b]*Scovec2[-a])/2-(HLS2*Lbar[-b]*Scovec2[-a])/2+HS1S2*Scovec1[-b]*Scovec2[-a]-(HLbarS2*L[-a]*Scovec2[-b])/2-(HLS2*Lbar[-a]*Scovec2[-b])/2+HS1S2*Scovec1[-a]*Scovec2[-b]+HS2S2*Scovec2[-a]*Scovec2[-b];
ApplyRuleRulePerturbationHToLLbarAndSCovariant=ApplyRuleWithoutMovingIndices@RulePerturbationHToLLbarAndSCovariant;


(**)
PerturbationH[a,b];
%/.ApplyRule@RulePerturbationHToLLbarAndS;
PerturbationH[a,b]==%
InputForm[%];
RulePerturbationHToLLbarAndSContravariant=PerturbationH[a,b]==(HLbarLbar*L[a]*L[b])/4+(HLLbar*L[b]*Lbar[a])/4+(HLLbar*L[a]*Lbar[b])/4+(HLL*Lbar[a]*Lbar[b])/4-(HLbarS1*L[b]*Scovec1[a])/2-(HLS1*Lbar[b]*Scovec1[a])/2-(HLbarS1*L[a]*Scovec1[b])/2-(HLS1*Lbar[a]*Scovec1[b])/2+HS1S1*Scovec1[a]*Scovec1[b]-(HLbarS2*L[b]*Scovec2[a])/2-(HLS2*Lbar[b]*Scovec2[a])/2+HS1S2*Scovec1[b]*Scovec2[a]-(HLbarS2*L[a]*Scovec2[b])/2-(HLS2*Lbar[a]*Scovec2[b])/2+HS1S2*Scovec1[a]*Scovec2[b]+HS2S2*Scovec2[a]*Scovec2[b];
ApplyRuleRulePerturbationHToLLbarAndSContravariant=ApplyRuleWithoutMovingIndices@RulePerturbationHToLLbarAndSContravariant;


(*Derivatives of the basis vectors (L, \[CapitalLSlash], Subscript[S, 1], Subscript[S, 2] ) *)


Basis[{-f,-Sp},c]Basis[{-h,-Sp},a]CDflat[-c][L[-a]]
%/.ApplyRuleFlatNullInTermsOfBasisSp;
SeparateBasis[Sp][%];
ContractBasis[%];
TraceBasisDummy[%];
ToValues[%]
InputForm[%];
CompsDerL=ChristoffelCDflatPDSp[{0,Sp},{-f,-Sp},{-h,-Sp}]-ChristoffelCDflatPDSp[{1,Sp},{-f,-Sp},{-h,-Sp}]
ComponentArray[%];
ToValues[%]


Basis[{-f,-Sp},c]Basis[{-h,-Sp},a]CDflat[-c][Lbar[-a]]
%/.ApplyRuleFlatNullInTermsOfBasisSp;
SeparateBasis[Sp][%];
ContractBasis[%];
TraceBasisDummy[%];
ToValues[%]
InputForm[%];
CompsDerLbar=ChristoffelCDflatPDSp[{0,Sp},{-f,-Sp},{-h,-Sp}]+ChristoffelCDflatPDSp[{1,Sp},{-f,-Sp},{-h,-Sp}]
ComponentArray[%];
ToValues[%]


Basis[{-f,-Sp},c]Basis[{-h,-Sp},a]CDflat[-c][Scovec1[-a]]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
SeparateBasis[Sp][%];
ContractBasis[%];
TraceBasisDummy[%];
ToValues[%]
InputForm[%];
CompsDerScovec1=Basis[{-f,-Sp},{1,Sp}]*Basis[{-h,-Sp},{2,Sp}]-ChristoffelCDflatPDSp[{2,Sp},{-f,-Sp},{-h,-Sp}]*r[]
ComponentArray[%];
ToValues[%]


Basis[{-f,-Sp},c]Basis[{-h,-Sp},a]CDflat[-c][Scovec2[-a]]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
SeparateBasis[Sp][%];
ContractBasis[%];
TraceBasisDummy[%];
ToValues[%]
InputForm[%];
CompsDerScovec2=Basis[{-f,-Sp},{2,Li}]*Basis[{-h,-Sp},{3,Sp}]*Cos[\[Theta][]]*r[]+Basis[{-f,-Sp},{1,Sp}]*Basis[{-h,-Sp},{3,Sp}]*Sin[\[Theta][]]-ChristoffelCDflatPDSp[{3,Sp},{-f,-Sp},{-h,-Sp}]*r[]*Sin[\[Theta][]]
ComponentArray[%];
ToValues[%]


CompsDerL*Basis[{f,Sp},-a]Basis[{h,Sp},-b];
TraceBasisDummy[%];
ToValues[%];
%/.ApplyRuleBasisSpToS1S2;
CDflat[-a]@L[-b]==%
InputForm[%];
RuleDerLInLLbarS1S2=CDflat[-a]@L[-b]==(Scovec1[-a]*Scovec1[-b])/r[]+(Scovec2[-a]*Scovec2[-b])/r[]


CompsDerLbar*Basis[{f,Sp},-a]Basis[{h,Sp},-b];
TraceBasisDummy[%];
ToValues[%];
%/.ApplyRuleBasisSpToS1S2;
CDflat[-a]@Lbar[-b]==%
InputForm[%];
RuleDerLbarInLLbarS1S2=CDflat[-a][Lbar[-b]]==-((Scovec1[-a]*Scovec1[-b])/r[])-(Scovec2[-a]*Scovec2[-b])/r[]


CompsDerScovec1*Basis[{f,Sp},-a]Basis[{h,Sp},-b];
TraceBasisDummy[%];
ToValues[%];
%/.ApplyRuleBasisSpToS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ToCanonical[%];
CDflat[-a]@Scovec1[-b]==%
InputForm[%];
RuleDerScovec1InLLbarS1S2=CDflat[-a][Scovec1[-b]]==-(L[-b]*Scovec1[-a])/(2*r[])+(Lbar[-b]*Scovec1[-a])/(2*r[])+(Cot[\[Theta][]]*Scovec2[-a]*Scovec2[-b])/r[]


CompsDerScovec2*Basis[{f,Sp},-a]Basis[{h,Sp},-b];
TraceBasisDummy[%];
ToValues[%];
%/.ApplyRuleBasisSpToS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ToCanonical[%];
CDflat[-a]@Scovec2[-b]==%
InputForm[%];
RuleDerScovec2InLLbarS1S2=CDflat[-a][Scovec2[-b]]==-(L[-b]*Scovec2[-a])/(2*r[])+(Lbar[-b]*Scovec2[-a])/(2*r[])-(Cot[\[Theta][]]*Scovec1[-b]*Scovec2[-a])/r[]


DerivativeOfBasisLLbarS1S2={RuleDerLInLLbarS1S2,RuleDerLbarInLLbarS1S2,RuleDerScovec1InLLbarS1S2,RuleDerScovec2InLLbarS1S2}


ApplyRuleDerivativeOfBasisLLbarS1S2=Flatten[ApplyRule/@DerivativeOfBasisLLbarS1S2];



Basis[{-f,-Sp},c]Basis[{h,Sp},-a]CDflat[-c][L[a]]
%/.ApplyRuleFlatNullInTermsOfBasisSp;
SeparateBasis[Sp][%];
ContractBasis[%];
TraceBasisDummy[%];
ToValues[%]
InputForm[%];
CompsDerLup=ChristoffelCDflatPDSp[{h,Sp},{-f,-Sp},{0,-Sp}]+ChristoffelCDflatPDSp[{h,Sp},{-f,-Sp},{1,-Sp}]
ComponentArray[%];
ToValues[%]


Basis[{-f,-Sp},c]Basis[{h,Sp},-a]CDflat[-c][Lbar[a]]
%/.ApplyRuleFlatNullInTermsOfBasisSp;
SeparateBasis[Sp][%];
ContractBasis[%];
TraceBasisDummy[%];
ToValues[%]
InputForm[%];
CompsDerLbarup=ChristoffelCDflatPDSp[{h,Sp},{-f,-Sp},{0,-Sp}]-ChristoffelCDflatPDSp[{h,Sp},{-f,-Sp},{1,-Sp}]
ComponentArray[%];
ToValues[%]


Basis[{-f,-Sp},c]Basis[{h,Sp},-a]CDflat[-c][Svec1[a]]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
SeparateBasis[Sp][%];
ContractBasis[%];
TraceBasisDummy[%];
ToValues[%]
InputForm[%];
CompsDerSvec1=-((Basis[{2,-Sp},{h,Sp}]*Basis[{-f,-Sp},{1,Sp}])/r[]^2)+ChristoffelCDflatPDSp[{h,Sp},{-f,-Sp},{2,-Sp}]/r[]
ComponentArray[%];
ToValues[%]


Basis[{-f,-Sp},c]Basis[{h,Sp},-a]CDflat[-c][Svec2[a]]
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
SeparateBasis[Sp][%];
ContractBasis[%];
TraceBasisDummy[%];
ToValues[%]
InputForm[%];
CompsDerSvec2=-((Basis[{3,-Sp},{h,Sp}]*Basis[{-f,-Sp},{1,Sp}]*Csc[\[Theta][]])/r[]^2)+(ChristoffelCDflatPDSp[{h,Sp},{-f,-Sp},{3,-Sp}]*Csc[\[Theta][]])/r[]-(Basis[{3,-Sp},{h,Sp}]*Basis[{-f,-Sp},{2,Li}]*Cot[\[Theta][]]*Csc[\[Theta][]])/r[]
ComponentArray[%];
ToValues[%]


CompsDerLup*Basis[{f,Sp},-a]Basis[{-h,-Sp},b];
TraceBasisDummy[%];
ToValues[%];
%/.ApplyRuleBasisSpToS1S2;
CDflat[-a]@L[b]==%
InputForm[%];
RuleDerLvecInLLbarS1S2=CDflat[-a][L[b]]==(Scovec1[-a]*Svec1[b])/r[]+(Scovec2[-a]*Svec2[b])/r[]


CompsDerLbarup*Basis[{f,Sp},-a]Basis[{-h,-Sp},b];
TraceBasisDummy[%];
ToValues[%];
%/.ApplyRuleBasisSpToS1S2;
CDflat[-a]@Lbar[b]==%
InputForm[%];
RuleDerLbarvecInLLbarS1S2=CDflat[-a][Lbar[b]]==-((Scovec1[-a]*Svec1[b])/r[])-(Scovec2[-a]*Svec2[b])/r[]


CompsDerSvec1*Basis[{f,Sp},-a]Basis[{-h,-Sp},b];
TraceBasisDummy[%];
ToValues[%];
%/.ApplyRuleBasisSpToS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ToCanonical[%];
CDflat[-a]@Svec1[b]==%
InputForm[%];
RuleDerSvec1InLLbarS1S2=CDflat[-a][Svec1[b]]==-(L[b]*Scovec1[-a])/(2*r[])+(Lbar[b]*Scovec1[-a])/(2*r[])+(Cot[\[Theta][]]*Scovec2[-a]*Svec2[b])/r[]


CompsDerSvec2*Basis[{f,Sp},-a]Basis[{-h,-Sp},b];
TraceBasisDummy[%];
ToValues[%];
%/.ApplyRuleBasisSpToS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ToCanonical[%];
CDflat[-a]@Svec2[b]==%
InputForm[%];
RuleDerSvec2InLLbarS1S2=CDflat[-a][Svec2[b]]==-(L[b]*Scovec2[-a])/(2*r[])+(Lbar[b]*Scovec2[-a])/(2*r[])-(Cot[\[Theta][]]*Scovec2[-a]*Svec1[b])/r[]


DerivativeOfBasisUPLLbarS1S2={RuleDerLvecInLLbarS1S2,RuleDerLbarvecInLLbarS1S2,RuleDerSvec1InLLbarS1S2,RuleDerSvec2InLLbarS1S2}


ApplyRuleDerivativeOfBasisUPLLbarS1S2=Flatten[ApplyRule/@DerivativeOfBasisUPLLbarS1S2];



(*Observation : 
Identify the good derivative.  Namely,  the directional derivative in which one gains a 1/r factor when expressed in  Lindblad\[CloseCurlyQuote]s coordinates (q,s)*)



L[c]CDflat[-c][PerturbationH[-a,-b]]
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]CDflat[-c][PerturbationH[-a,-b]]==%
InputForm[%];
RuleGoodDerivative=L[c]*CDflat[-c][PerturbationH[-a,-b]]==(CDflat[{1,-Li}][PerturbationH[-a,-b]])/r[]


(**)
Lbar[c]CDflat[-c][PerturbationH[-a,-b]]
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]CDflat[-c][PerturbationH[-a,-b]]==%
InputForm[%];
RuleNotSoGoodDerivative=Lbar[c]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][PerturbationH[-a,-b]]-(CDflat[{1,-Li}][PerturbationH[-a,-b]])/r[]


Lbar[c] (CDflat[-c][PerturbationH[-a, -b]])


Lbar[c] (CDflat[-c][PerturbationH[-a, -b]])==-2 (CDflat[{0, -Li}][PerturbationH[-a, -b]])-((CDflat[{1, -Li}][PerturbationH[-a, -b]]))/r[]



Scovec1[a]
SeparateMetric[m,AIndex][%];
%/.ApplyRuleRuleMinkowskiMetricToLLbarSContravariant;
ContractMetric[%];
Scovec1[a]==%;




Scovec2[a]
SeparateMetric[m,AIndex][%];
%/.ApplyRuleRuleMinkowskiMetricToLLbarSContravariant;
ContractMetric[%];
Scovec2[a]==%





CanonicalisedScovecToSvec={Scovec1[a]==Svec1[a],Scovec2[a]==Svec2[a]}


ApplyRuleCanonicalisedScovecToSvec=Flatten[ApplyRule/@CanonicalisedScovecToSvec];



CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
Expand[%];
CDflat[-c][PerturbationH[-a, -b]]==%;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
Expand[%];
RuleDerivativeGeneralExpansion=CDflat[-c][PerturbationH[-a,-b]]==(HLbarS1*L[-a]*L[-b]*Scovec1[-c])/(2*r[])-(HLbarS1*L[-b]*Lbar[-a]*Scovec1[-c])/(4*r[])+(HLS1*L[-b]*Lbar[-a]*Scovec1[-c])/(4*r[])-(HLbarS1*L[-a]*Lbar[-b]*Scovec1[-c])/(4*r[])+(HLS1*L[-a]*Lbar[-b]*Scovec1[-c])/(4*r[])-(HLS1*Lbar[-a]*Lbar[-b]*Scovec1[-c])/(2*r[])+(HLbarLbar*L[-b]*Scovec1[-a]*Scovec1[-c])/(4*r[])-(HLLbar*L[-b]*Scovec1[-a]*Scovec1[-c])/(4*r[])-(HS1S1*L[-b]*Scovec1[-a]*Scovec1[-c])/(2*r[])-(HLL*Lbar[-b]*Scovec1[-a]*Scovec1[-c])/(4*r[])+(HLLbar*Lbar[-b]*Scovec1[-a]*Scovec1[-c])/(4*r[])+(HS1S1*Lbar[-b]*Scovec1[-a]*Scovec1[-c])/(2*r[])+(HLbarLbar*L[-a]*Scovec1[-b]*Scovec1[-c])/(4*r[])-(HLLbar*L[-a]*Scovec1[-b]*Scovec1[-c])/(4*r[])-(HS1S1*L[-a]*Scovec1[-b]*Scovec1[-c])/(2*r[])-(HLL*Lbar[-a]*Scovec1[-b]*Scovec1[-c])/(4*r[])+(HLLbar*Lbar[-a]*Scovec1[-b]*Scovec1[-c])/(4*r[])+(HS1S1*Lbar[-a]*Scovec1[-b]*Scovec1[-c])/(2*r[])-(HLbarS1*Scovec1[-a]*Scovec1[-b]*Scovec1[-c])/r[]+(HLS1*Scovec1[-a]*Scovec1[-b]*Scovec1[-c])/r[]-(HS1S2*L[-b]*Scovec1[-c]*Scovec2[-a])/(2*r[])+(HS1S2*Lbar[-b]*Scovec1[-c]*Scovec2[-a])/(2*r[])-(HLbarS2*Scovec1[-b]*Scovec1[-c]*Scovec2[-a])/(2*r[])+(HLS2*Scovec1[-b]*Scovec1[-c]*Scovec2[-a])/(2*r[])-(HS1S2*L[-a]*Scovec1[-c]*Scovec2[-b])/(2*r[])+(HS1S2*Lbar[-a]*Scovec1[-c]*Scovec2[-b])/(2*r[])-(HLbarS2*Scovec1[-a]*Scovec1[-c]*Scovec2[-b])/(2*r[])+(HLS2*Scovec1[-a]*Scovec1[-c]*Scovec2[-b])/(2*r[])+(HLbarS2*L[-a]*L[-b]*Scovec2[-c])/(2*r[])-(HLbarS2*L[-b]*Lbar[-a]*Scovec2[-c])/(4*r[])+(HLS2*L[-b]*Lbar[-a]*Scovec2[-c])/(4*r[])-(HLbarS2*L[-a]*Lbar[-b]*Scovec2[-c])/(4*r[])+(HLS2*L[-a]*Lbar[-b]*Scovec2[-c])/(4*r[])-(HLS2*Lbar[-a]*Lbar[-b]*Scovec2[-c])/(2*r[])-(HS1S2*L[-b]*Scovec1[-a]*Scovec2[-c])/(2*r[])+(HLbarS2*Cot[\[Theta][]]*L[-b]*Scovec1[-a]*Scovec2[-c])/(2*r[])+(HS1S2*Lbar[-b]*Scovec1[-a]*Scovec2[-c])/(2*r[])+(HLS2*Cot[\[Theta][]]*Lbar[-b]*Scovec1[-a]*Scovec2[-c])/(2*r[])-(HS1S2*L[-a]*Scovec1[-b]*Scovec2[-c])/(2*r[])+(HLbarS2*Cot[\[Theta][]]*L[-a]*Scovec1[-b]*Scovec2[-c])/(2*r[])+(HS1S2*Lbar[-a]*Scovec1[-b]*Scovec2[-c])/(2*r[])+(HLS2*Cot[\[Theta][]]*Lbar[-a]*Scovec1[-b]*Scovec2[-c])/(2*r[])-(2*HS1S2*Cot[\[Theta][]]*Scovec1[-a]*Scovec1[-b]*Scovec2[-c])/r[]+(HLbarLbar*L[-b]*Scovec2[-a]*Scovec2[-c])/(4*r[])-(HLLbar*L[-b]*Scovec2[-a]*Scovec2[-c])/(4*r[])-(HS2S2*L[-b]*Scovec2[-a]*Scovec2[-c])/(2*r[])-(HLbarS1*Cot[\[Theta][]]*L[-b]*Scovec2[-a]*Scovec2[-c])/(2*r[])-(HLL*Lbar[-b]*Scovec2[-a]*Scovec2[-c])/(4*r[])+(HLLbar*Lbar[-b]*Scovec2[-a]*Scovec2[-c])/(4*r[])+(HS2S2*Lbar[-b]*Scovec2[-a]*Scovec2[-c])/(2*r[])-(HLS1*Cot[\[Theta][]]*Lbar[-b]*Scovec2[-a]*Scovec2[-c])/(2*r[])-(HLbarS1*Scovec1[-b]*Scovec2[-a]*Scovec2[-c])/(2*r[])+(HLS1*Scovec1[-b]*Scovec2[-a]*Scovec2[-c])/(2*r[])+(HS1S1*Cot[\[Theta][]]*Scovec1[-b]*Scovec2[-a]*Scovec2[-c])/r[]-(HS2S2*Cot[\[Theta][]]*Scovec1[-b]*Scovec2[-a]*Scovec2[-c])/r[]+(HLbarLbar*L[-a]*Scovec2[-b]*Scovec2[-c])/(4*r[])-(HLLbar*L[-a]*Scovec2[-b]*Scovec2[-c])/(4*r[])-(HS2S2*L[-a]*Scovec2[-b]*Scovec2[-c])/(2*r[])-(HLbarS1*Cot[\[Theta][]]*L[-a]*Scovec2[-b]*Scovec2[-c])/(2*r[])-(HLL*Lbar[-a]*Scovec2[-b]*Scovec2[-c])/(4*r[])+(HLLbar*Lbar[-a]*Scovec2[-b]*Scovec2[-c])/(4*r[])+(HS2S2*Lbar[-a]*Scovec2[-b]*Scovec2[-c])/(2*r[])-(HLS1*Cot[\[Theta][]]*Lbar[-a]*Scovec2[-b]*Scovec2[-c])/(2*r[])-(HLbarS1*Scovec1[-a]*Scovec2[-b]*Scovec2[-c])/(2*r[])+(HLS1*Scovec1[-a]*Scovec2[-b]*Scovec2[-c])/(2*r[])+(HS1S1*Cot[\[Theta][]]*Scovec1[-a]*Scovec2[-b]*Scovec2[-c])/r[]-(HS2S2*Cot[\[Theta][]]*Scovec1[-a]*Scovec2[-b]*Scovec2[-c])/r[]-(HLbarS2*Scovec2[-a]*Scovec2[-b]*Scovec2[-c])/r[]+(HLS2*Scovec2[-a]*Scovec2[-b]*Scovec2[-c])/r[]+(2*HS1S2*Cot[\[Theta][]]*Scovec2[-a]*Scovec2[-b]*Scovec2[-c])/r[]+(L[-a]*L[-b]*CDflat[-c][HLbarLbar])/4-(L[-b]*Scovec1[-a]*CDflat[-c][HLbarS1])/2-(L[-a]*Scovec1[-b]*CDflat[-c][HLbarS1])/2-(L[-b]*Scovec2[-a]*CDflat[-c][HLbarS2])/2-(L[-a]*Scovec2[-b]*CDflat[-c][HLbarS2])/2+(Lbar[-a]*Lbar[-b]*CDflat[-c][HLL])/4+(L[-b]*Lbar[-a]*CDflat[-c][HLLbar])/4+(L[-a]*Lbar[-b]*CDflat[-c][HLLbar])/4-(Lbar[-b]*Scovec1[-a]*CDflat[-c][HLS1])/2-(Lbar[-a]*Scovec1[-b]*CDflat[-c][HLS1])/2-(Lbar[-b]*Scovec2[-a]*CDflat[-c][HLS2])/2-(Lbar[-a]*Scovec2[-b]*CDflat[-c][HLS2])/2+Scovec1[-a]*Scovec1[-b]*CDflat[-c][HS1S1]+Scovec1[-b]*Scovec2[-a]*CDflat[-c][HS1S2]+Scovec1[-a]*Scovec2[-b]*CDflat[-c][HS1S2]+Scovec2[-a]*Scovec2[-b]*CDflat[-c][HS2S2]


L[c]L[a]L[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]L[a]L[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleLLDerH=L[a]*L[b]*L[c]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HLL]/r[]



Lbar[c]L[a]L[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]L[a]L[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleLLDerH=L[a]*L[b]*Lbar[c]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HLL]-CDflat[{1,-Li}][HLL]/r[]


Svec1[c]L[a]L[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]L[a]L[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S1RuleLLDerH=L[a]*L[b]*Svec1[c]*CDflat[-c][PerturbationH[-a,-b]]==(-2*HLS1)/r[]+CDflat[{2,-Sp}][HLL]/r[]


Svec2[c]L[a]L[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]L[a]L[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleLLDerH=L[a]*L[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==(-2*HLS2)/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HLL])/r[]



(*****)


L[c]L[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]L[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleLLbarDerH=L[a]*L[c]*Lbar[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HLLbar]/r[]


Lbar[c]L[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]L[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleLLbarDerH=L[a]*Lbar[b]*Lbar[c]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HLLbar]-CDflat[{1,-Li}][HLLbar]/r[]


Svec1[c]L[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]L[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]==%
S1RuleLLbarDerH=L[a]*Lbar[b]*Svec1[c]*CDflat[-c][PerturbationH[-a,-b]]==-(HLbarS1/r[])+HLS1/r[]+CDflat[{2,-Sp}][HLLbar]/r[]


Svec2[c]L[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]L[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleLLbarDerH=L[a]*Lbar[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==-(HLbarS2/r[])+HLS2/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HLLbar])/r[]



(*************)


L[c]L[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]L[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleLS1DerH=L[a]*L[c]*Svec1[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HLS1]/r[]


Lbar[c]L[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]L[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleLS1DerH=L[a]*Lbar[c]*Svec1[b]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HLS1]-CDflat[{1,-Li}][HLS1]/r[]



Svec1[c]L[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]L[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S1RuleLS1DerH=L[a]*Svec1[b]*Svec1[c]*CDflat[-c][PerturbationH[-a,-b]]==HLL/(2*r[])-HLLbar/(2*r[])-HS1S1/r[]+CDflat[{2,-Sp}][HLS1]/r[]


Svec2[c]L[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]L[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleLS1DerH=L[a]*Svec1[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==-(HS1S2/r[])-(HLS2*Cot[\[Theta][]])/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HLS1])/r[]



(***************)


L[c]L[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]L[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleLS2DerH=L[a]*L[c]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HLS2]/r[]




Lbar[c]L[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]L[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleLS2DerH=L[a]*Lbar[c]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HLS2]-CDflat[{1,-Li}][HLS2]/r[]


Svec1[c]L[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]L[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S1RuleLS2DerH=L[a]*Svec1[c]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==-(HS1S2/r[])+CDflat[{2,-Sp}][HLS2]/r[]


Svec2[c]L[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]L[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleLS2DerH=L[a]*Svec2[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==HLL/(2*r[])-HLLbar/(2*r[])-HS2S2/r[]+(HLS1*Cot[\[Theta][]])/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HLS2])/r[]



(************)


L[c]Lbar[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]Lbar[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleLbarLbarDerH=L[c]*Lbar[a]*Lbar[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HLbarLbar]/r[]


Lbar[c]Lbar[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]Lbar[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleLbarLbarDerH=Lbar[a]*Lbar[b]*Lbar[c]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HLbarLbar]-CDflat[{1,-Li}][HLbarLbar]/r[]


Svec1[c]Lbar[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]Lbar[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]==%
S1RuleLbarLbarDerH=Lbar[a]*Lbar[b]*Svec1[c]*CDflat[-c][PerturbationH[-a,-b]]==(2*HLbarS1)/r[]+CDflat[{2,-Sp}][HLbarLbar]/r[]


Svec2[c]Lbar[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]Lbar[a]Lbar[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleLbarLbarDerH=Lbar[a]*Lbar[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==(2*HLbarS2)/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HLbarLbar])/r[]



(************************************************************)






L[c]Lbar[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]Lbar[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleLbarS1DerH=L[c]*Lbar[a]*Svec1[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HLbarS1]/r[]


Lbar[c]Lbar[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]Lbar[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleLbarS1DerH=Lbar[a]*Lbar[c]*Svec1[b]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HLbarS1]-CDflat[{1,-Li}][HLbarS1]/r[]



Svec1[c]Lbar[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]Lbar[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S1RuleLbarS1DerH=
Lbar[a]*Svec1[b]*Svec1[c]*CDflat[-c][PerturbationH[-a,-b]]==-HLbarLbar/(2*r[])+HLLbar/(2*r[])+HS1S1/r[]+CDflat[{2,-Sp}][HLbarS1]/r[]


Svec2[c]Lbar[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]Lbar[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleLbarS1DerH=Lbar[a]*Svec1[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==HS1S2/r[]-(HLbarS2*Cot[\[Theta][]])/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HLbarS1])/r[]



(**********************)


L[c]Lbar[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]Lbar[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleLbarS2DerH=L[c]*Lbar[a]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HLbarS2]/r[]


Lbar[c]Lbar[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]Lbar[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleLbarS2DerH=Lbar[a]*Lbar[c]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HLbarS2]-CDflat[{1,-Li}][HLbarS2]/r[]




Svec1[c]Lbar[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]Lbar[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S1RuleLbarS2DerH=Lbar[a]*Svec1[c]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==HS1S2/r[]+CDflat[{2,-Sp}][HLbarS2]/r[]



Svec2[c]Lbar[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]Lbar[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleLbarS2DerH=Lbar[a]*Svec2[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==-HLbarLbar/(2*r[])+HLLbar/(2*r[])+HS2S2/r[]+(HLbarS1*Cot[\[Theta][]])/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HLbarS2])/r[]



(*******************)


L[c]Svec1[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]Svec1[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleS1S1DerH=L[c]*Svec1[a]*Svec1[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HS1S1]/r[]


Lbar[c]Svec1[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]Svec1[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleS1S1DerH=Lbar[c]*Svec1[a]*Svec1[b]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HS1S1]-CDflat[{1,-Li}][HS1S1]/r[]


Svec1[c]Svec1[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]Svec1[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S1RuleS1S1DerH=Svec1[a]*Svec1[b]*Svec1[c]*CDflat[-c][PerturbationH[-a,-b]]==-(HLbarS1/r[])+HLS1/r[]+CDflat[{2,-Sp}][HS1S1]/r[]


Svec2[c]Svec1[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]Svec1[a]Svec1[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleS1S1DerH=Svec1[a]*Svec1[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==(-2*HS1S2*Cot[\[Theta][]])/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HS1S1])/r[]



(*******************)


L[c]Svec1[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]Svec1[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleS1S2DerH=L[c]*Svec1[a]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HS1S2]/r[]


Lbar[c]Svec1[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]Svec1[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleS1S2DerH = Lbar[c]*Svec1[a]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HS1S2]-CDflat[{1,-Li}][HS1S2]/r[]


Svec1[c]Svec1[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]Svec1[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S1RuleS1S2DerH =
Svec1[a]*Svec1[c]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==-HLbarS2/(2*r[])+HLS2/(2*r[])+CDflat[{2,-Sp}][HS1S2]/r[]


Svec2[c]Svec1[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]Svec1[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleS1S2DerH = Svec1[a]*Svec2[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==-HLbarS1/(2*r[])+HLS1/(2*r[])+(HS1S1*Cot[\[Theta][]])/r[]-(HS2S2*Cot[\[Theta][]])/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HS1S2])/r[]



(*********************)


L[c]Svec2[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
L[c]Svec2[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LRuleS2S2DerH=L[c]*Svec2[a]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{1,-Li}][HS2S2]/r[]



Lbar[c]Svec2[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[%];
%/.ChangeCovariantDerivative0Sp;
%/.ChangeCovariantDerivative1Sp;
Lbar[c]Svec2[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
LbarRuleS2S2DerH=Lbar[c]*Svec2[a]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==-2*CDflat[{0,-Li}][HS2S2]-CDflat[{1,-Li}][HS2S2]/r[]



Svec1[c]Svec2[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec1[c]Svec2[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S1RuleS2S2DerH=Svec1[c]*Svec2[a]*Svec2[b]*CDflat[-c][PerturbationH[-a,-b]]==CDflat[{2,-Sp}][HS2S2]/r[]



Svec2[c]Svec2[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]
%/.ApplyRule@RuleDerivativeGeneralExpansion;
ContractMetric[%];
%/.ApplyRuleOrthoNormalAngularFrameBasisSP;
ContractBasis[%];
Svec2[c]Svec2[a]Svec2[b]CDflat[-c][PerturbationH[-a, -b]]==%
InputForm[%];
S2RuleS2S2DerH=Svec2[a]*Svec2[b]*Svec2[c]*CDflat[-c][PerturbationH[-a,-b]]==-(HLbarS2/r[])+HLS2/r[]+(2*HS1S2*Cot[\[Theta][]])/r[]+(Csc[\[Theta][]]*CDflat[{3,-Sp}][HS2S2])/r[]





RuleShortcutBasisAndOneDerivativeOfHcomplete={LRuleLLDerH,LbarRuleLLDerH,S1RuleLLDerH,S2RuleLLDerH,LRuleLLbarDerH,LbarRuleLLbarDerH,S1RuleLLbarDerH,S2RuleLLbarDerH,LRuleLS1DerH,LbarRuleLS1DerH,S1RuleLS1DerH,S2RuleLS1DerH,LRuleLS2DerH, LbarRuleLS2DerH,S1RuleLS2DerH,S2RuleLS2DerH,LRuleLbarLbarDerH,LbarRuleLbarLbarDerH,S1RuleLbarLbarDerH,S2RuleLbarLbarDerH,LRuleLbarS1DerH,LbarRuleLbarS1DerH,S1RuleLbarS1DerH,S2RuleLbarS1DerH,LRuleLbarS2DerH,LbarRuleLbarS2DerH,S1RuleLbarS2DerH, S2RuleLbarS2DerH,LRuleS1S1DerH,LbarRuleS1S1DerH,S1RuleS1S1DerH,S2RuleS1S1DerH,LRuleS1S2DerH,LbarRuleS1S2DerH,S1RuleS1S2DerH,S2RuleS1S2DerH,LRuleS2S2DerH,LbarRuleS2S2DerH,S1RuleS2S2DerH,S2RuleS2S2DerH}


ApplyRuleRuleShortcutBasisAndOneDerivativeOfHcomplete=Flatten[ApplyRule/@RuleShortcutBasisAndOneDerivativeOfHcomplete];









(*Shortcut for one derivative of H partially contracted with the basis *)
(* essentially the basis passes through the derivative to leading order *)



L[c]L[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLLPassesThroughOneDerivative=L[c]L[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
L[c]Lbar[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLLbarPassesThroughOneDerivative=L[c]Lbar[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
L[c]Svec1[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLS1PassesThroughOneDerivative=L[c]Svec1[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
L[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLS2PassesThroughOneDerivative=L[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Lbar[c]Lbar[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLbarLbarPassesThroughOneDerivative=Lbar[c]Lbar[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Lbar[c]Svec1[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLbarS1PassesThroughOneDerivative=Lbar[c]Svec1[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Lbar[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLbarS2PassesThroughOneDerivative=Lbar[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Svec1[c]Svec1[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleS1S1PassesThroughOneDerivative=Svec1[c]Svec1[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Svec1[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleS1S2PassesThroughOneDerivative=Svec1[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Svec2[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleS2S2PassesThroughOneDerivative=Svec2[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d]==%


L[c]Scovec1[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLScovec1PassesThroughOneDerivative=L[c]Scovec1[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
L[c]Scovec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLScovec2PassesThroughOneDerivative=L[c]Scovec2[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Lbar[c]Scovec1[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLbarScovec1PassesThroughOneDerivative=Lbar[c]Scovec1[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Lbar[c]Scovec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleLbarScovec2PassesThroughOneDerivative=Lbar[c]Scovec2[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Scovec1[c]Scovec1[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleScovec1Scovec1PassesThroughOneDerivative=Scovec1[c]Scovec1[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Scovec1[c]Scovec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleScovec1Scovec2PassesThroughOneDerivative=Scovec1[c]Scovec2[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Scovec2[c]Scovec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleScovec2Scovec2PassesThroughOneDerivative=Scovec2[c]Scovec2[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Scovec1[c]Svec1[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleScovec1Svec1PassesThroughOneDerivative=Scovec1[c]Svec1[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Scovec1[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleScovec1Svec2PassesThroughOneDerivative=Scovec1[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d]==%
(**)
Scovec2[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
Normal[%]+(1/r[])HigherOrderVector[-a];
RuleScovec2Svec2PassesThroughOneDerivative=Scovec2[c]Svec2[d]CDflat[-a]@PerturbationH[-c,-d]==%


RuleShortcutBasisAndOneDerivativeOfH={L[c]*L[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLL],L[c]*Lbar[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLLbar],L[c]*Svec1[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLS1],L[c]*Svec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLS2],Lbar[c]*Lbar[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarLbar],Lbar[c]*Svec1[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarS1],Lbar[c]*Svec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarS2],Svec1[c]*Svec1[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S1],Svec1[c]*Svec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S2],Svec2[c]*Svec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS2S2],L[c]*Scovec1[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLS1],L[c]*Scovec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLS2],Lbar[c]*Scovec1[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarS1],Lbar[c]*Scovec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarS2],Scovec1[c]*Scovec1[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S1],Scovec1[c]*Scovec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S2],Scovec2[c]*Scovec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS2S2],Scovec1[c]*Svec1[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S1],Scovec1[c]*Svec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S2],Scovec2[c]*Svec2[d]*CDflat[-a][PerturbationH[-c,-d]]==HigherOrderVector[-a]/r[]+CDflat[-a][HS2S2]}


{L[c] L[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLL],L[c] Lbar[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLLbar],L[c] Svec1[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLS1],L[c] Svec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLS2],Lbar[c] Lbar[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarLbar],Lbar[c] Svec1[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarS1],Lbar[c] Svec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarS2],Svec1[c] Svec1[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S1],Svec1[c] Svec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S2],Svec2[c] Svec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS2S2],L[c] Scovec1[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLS1],L[c] Scovec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLS2],Lbar[c] Scovec1[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarS1],Lbar[c] Scovec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HLbarS2],Scovec1[c] Scovec1[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S1],Scovec1[c] Scovec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S2],Scovec2[c] Scovec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS2S2],Scovec1[c] Svec1[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S1],Scovec1[c] Svec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS1S2],Scovec2[c] Svec2[d] (CDflat[-a][PerturbationH[-c, -d]])==HigherOrderVector[-a]/r[]+CDflat[-a][HS2S2]}


ApplyRuleRuleShortcutBasisAndOneDerivativeOfH=Flatten[ApplyRule/@RuleShortcutBasisAndOneDerivativeOfH];



(*****now with two derivatives ********)


L[c]L[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleLLPassesThrough=L[c]L[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HLL]]},0,1,1]
(**)
L[c]Lbar[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleLLbarPassesThrough=L[c]Lbar[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HLLbar]]},0,1,1]
(**)
L[c]Svec1[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleLS1PassesThrough=L[c]Svec1[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HLS1]]},0,1,1]
(**)
L[c]Svec2[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleLS2PassesThrough=L[c]Svec2[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HLS2]]},0,1,1]
(**)
Lbar[c]Lbar[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleLbarLbarPassesThrough=Lbar[c]Lbar[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HLbarLbar]]},0,1,1]
(**)
Lbar[c]Svec1[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleLbarS1PassesThrough=Lbar[c]Svec1[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HLbarS1]]},0,1,1]
(**)
Lbar[c]Svec2[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleLbarS2PassesThrough=Lbar[c]Svec2[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HLbarS2]]},0,1,1]
(**)
Svec1[c]Svec1[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleS1S1PassesThrough=Svec1[c]Svec1[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HS1S1]]},0,1,1]
(**)
Svec1[c]Svec2[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleS1S2PassesThrough=Svec1[c]Svec2[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HS1S2]]},0,1,1]
(**)
Svec2[c]Svec2[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d];
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Series[%,{r[],Infinity,0}];
InputForm[%];
RuleS2S2PassesThrough=Svec2[c]Svec2[d]CDflat[-a]@CDflat[-b]@PerturbationH[-c,-d]==SeriesData[r[],Infinity,{CDflat[-a][CDflat[-b][HS2S2]]},0,1,1]




(* We have identical rules holding in the Li basis *)
(** derived in the comented out section **)


(*Basis[{-f,-Li},a]RuleLLPassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleLLbarPassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleLS1PassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleLS2PassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleLbarLbarPassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleLbarS1PassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleLbarS2PassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleS1S1PassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleS1S2PassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]
(**)
Basis[{-f,-Li},a]RuleS2S2PassesThroughOneDerivative;
ContractBasis[%];
CDflat[-h]@%[[1]]==CDflat[-h]@%[[2]];
Expand[%];
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
%/.ApplyRuleDerivativeOfBasisUPLLbarS1S2;
Expand[%];
Basis[{-p,-Li},h]*%;
Expand[%];
ContractBasis[%];
Series[%,{r[],Infinity,0}]*)



RuleLetLLbarS1andS2PassThrough={
ReplaceIndex[Evaluate[Normal[RuleLLPassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLLbarPassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLS1PassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLS2PassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarLbarPassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarS1PassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarS2PassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS1S1PassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS1S2PassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS2S2PassesThrough],{-a->{0,-Li},-b->{0,-Li}}]],
(**)
ReplaceIndex[Evaluate[Normal[RuleLLPassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLLbarPassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLS1PassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLS2PassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarLbarPassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarS1PassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarS2PassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS1S1PassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS1S2PassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS2S2PassesThrough],{-a->{0,-Li},-b->{1,-Li}}]],
(**)
ReplaceIndex[Evaluate[Normal[RuleLLPassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLLbarPassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLS1PassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLS2PassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarLbarPassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarS1PassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleLbarS2PassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS1S1PassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS1S2PassesThrough],{-a->{1,-Li},-b->{0,-Li}}]],
ReplaceIndex[Evaluate[Normal[RuleS2S2PassesThrough],{-a->{1,-Li},-b->{0,-Li}}]]}

ApplyRuleRuleLetLLbarS1andS2PassThrough=Flatten[ApplyRule/@RuleLetLLbarS1andS2PassThrough];



(*** extra definitions required ***)





DefTensor[Radial[],M4,PrintAs->"r"]


DefTensor[PerturbationHtrace[],M4,PrintAs->"H"]
RuleTraceOfPerturbationH=PerturbationH[-a,a]==PerturbationHtrace[]
DefTensor[PerturbationHOneIndexFreeandOtherL[-a],M4,PrintAs->"\!\(\*SubscriptBox[\(H\), \(L\)]\)"]
DefScalarFunction[HPlus, PrintAs->"\!\(\*SuperscriptBox[\"H\", StyleBox[\"+\",FontSize->14]]\)"]
DefScalarFunction[Htraceonsphere,PrintAs->"\!\(\*SuperscriptBox[\(H\), \(\[Diameter]\)]\)"]
DefScalarFunction[Hcross, PrintAs->"\!\(\*SuperscriptBox[\(H\), \(\[Times]\)]\)"]
HS1S1HS2S2ToTracesOnSphere={HS1S1==(1/2)*Htraceonsphere+HPlus,
HS2S2==(1/2)*Htraceonsphere-HPlus}
HS1S2ToHcross={HS1S2== Hcross}
ApplyRuleHS1S1HS2S2ToTracesOnSphere=Flatten[ApplyRule/@HS1S1HS2S2ToTracesOnSphere];
ApplyRuleHS1S2ToHcorss=Flatten[ApplyRule/@HS1S2ToHcross];
RulePerturbationHOneIndexFreeandOtherL=PerturbationHOneIndexFreeandOtherL[c]==PerturbationH[c,-b]L[b]


(** definitions for Eikonal **)
DefTensor[xi[-a],M4,PrintAs->"\[Xi]"]
DefTensor[xiflat[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(\[Xi]\), \(\[FilledSmallCircle]\)]\)"]
DefTensor[xiPert[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(\[Xi]\), \(\[Vee]\)]\)"]
DefScalarFunction[xiPertL,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Xi]\), \(\[Or]\)], \(L\)]\)"]
DefScalarFunction[xiPertLbar,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Xi]\), \(\[Or]\)], \(\[CapitalLSlash]\)]\)"]
DefScalarFunction[xiPertS1,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Xi]\), \(\[Or]\)], \(S1\)]\)"]
DefScalarFunction[xiPertS2,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Xi]\), \(\[Or]\)], \(S2\)]\)"]
(** one of these two should be zero **)
DefScalarFunction[xiflatL,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Xi]\), \(\[FilledSmallCircle]\)], \(L\)]\)"]
DefScalarFunction[xiflatLbar,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Xi]\), \(\[FilledSmallCircle]\)], \(\[CapitalLSlash]\)]\)"]


IntegrabilityConditionFlat=CDflat[a]@xiflat[b]==CDflat[b]@xiflat[a];
XiSplit=xi[a]==xiflat[a]+(1/r[])*xiPert[a];


RulexiPertToLLbarAndScovec=xiPert[a]==-(xiPertLbar*L[a])/2-(xiPertL*Lbar[a])/2+xiPertS1*Scovec1[a]+xiPertS2*Scovec2[a];
RulexiPertToLLbarAndSvec=xiPert[a]==-(xiPertLbar*L[a])/2-(xiPertL*Lbar[a])/2+xiPertS1*Svec1[a]+xiPertS2*Svec2[a];
RulexiFlatToLLbarAndS=xiflat[a]==-(xiflatLbar*L[a])/2-(xiflatL*Lbar[a])/2;











(*********************************************************************************************************************************************)



(******* Definitions and rules required for SOGHG.nb ************)




DefTensor[ScreenedHDerHTerm[-a,-b],M4,PrintAs->"[H\!\(\*OverscriptBox[\(\[Del]\), \(\[FilledSmallCircle]\)]\)\!\(\*OverscriptBox[\(\[Del]\), \(\[FilledSmallCircle]\)]\)H]"]

DefTensor[ScreenedHDerHTermExtra[-a,-b],M4,PrintAs->"[H\!\(\*OverscriptBox[\(\[Del]\), \(\[FilledSmallCircle]\)]\)\!\(\*OverscriptBox[\(\[Del]\), \(\[FilledSmallCircle]\)]\)H]"]
DefTensor[ScreenedHDerHTerm1[-a,-b],M4,PrintAs->"[H\!\(\*OverscriptBox[\(\[Del]\), \(\[FilledSmallCircle]\)]\)H]"]



DefTensor[RHSEFEGHG[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[ScriptCapitalE]"]




DefScalarFunction[ELL,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(LL\)]\)"]
DefScalarFunction[ELLbar,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(L\[CapitalLSlash]\)]\)"]
DefScalarFunction[ELbarLbar,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(\[CapitalLSlash]\[CapitalLSlash]\)]\)"]
DefScalarFunction[ELS1,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(LS1\)]\)"]
DefScalarFunction[ELS2,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(LS2\)]\)"]
DefScalarFunction[ELbarS1,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(\[CapitalLSlash]S1\)]\)"]
DefScalarFunction[ELbarS2,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(\[CapitalLSlash]S2\)]\)"]
DefScalarFunction[ES1S2,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(S1S2\)]\)"]
DefScalarFunction[ES1S1,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(S1S1\)]\)"]
DefScalarFunction[ES2S2,PrintAs->"\!\(\*SubscriptBox[\(\[ScriptCapitalE]\), \(S2S2\)]\)"]







ReducedEFEGHGWithConstraintAddition=GenericConstraintAddition[-a,-b]+(GaugeSourceFunction[c]*CDflat[-a][g[-b,-c]])/2-CDflat[-a][GaugeSourceFunction[-b]]/2+(GaugeSourceFunction[c]*CDflat[-b][g[-a,-c]])/2-(Invg[c,d]*Invg[f,h]*CDflat[-a][g[-c,-f]]*CDflat[-b][g[-d,-h]])/4-CDflat[-b][GaugeSourceFunction[-a]]/2-(GaugeSourceFunction[c]*CDflat[-c][g[-a,-b]])/2-(Invg[c,d]*CDflat[-d][CDflat[-c][g[-a,-b]]])/2+(Invg[c,d]*Invg[f,h]*CDflat[-b][g[-d,-h]]*CDflat[-f][g[-a,-c]])/2-(Invg[c,d]*Invg[f,h]*CDflat[-d][g[-b,-h]]*CDflat[-f][g[-a,-c]])/2+(Invg[c,d]*Invg[f,h]*CDflat[-a][g[-d,-h]]*CDflat[-f][g[-b,-c]])/2+(Invg[c,d]*Invg[f,h]*CDflat[-f][g[-a,-c]]*CDflat[-h][g[-b,-d]])/2==0;








RuleScreeHDerHTerm=PerturbationH[a,b]*CDflat[-a][CDflat[-b][PerturbationH[-c,-d]]]==ScreenedHDerHTerm[-c,-d]



RightHandSideEFEGHGAsymptoticGeneral=((ELbarLbar*L[-b]*L[-a])/4+(ELLbar*L[-b]*Lbar[-a])/4+(ELLbar*L[-a]*Lbar[-b])/4+(ELL*Lbar[-a]*Lbar[-b])/4-(ELbarS1*L[-b]*Scovec1[-a])/2-(ELS1*Lbar[-b]*Scovec1[-a])/2-(ELbarS1*L[-a]*Scovec1[-b])/2-(ELS1*Lbar[-a]*Scovec1[-b])/2+ES1S1*Scovec1[-a]*Scovec1[-b]-(ELbarS2*L[-b]*Scovec2[-a])/2-(ELS2*Lbar[-b]*Scovec2[-a])/2+ES1S2*Scovec1[-b]*Scovec2[-a]-(ELbarS2*L[-a]*Scovec2[-b])/2-(ELS2*Lbar[-a]*Scovec2[-b])/2+ES1S2*Scovec1[-a]*Scovec2[-b]+ES2S2*Scovec2[-a]*Scovec2[-b])*Basis[{-c,-Sp},a]*Basis[{-d,-Sp},b]

RightHandSideEFEGHGAsymptoticGeneralAbstract=((ELbarLbar*L[-a]*L[-b])/4 + (ELLbar*L[-b]*Lbar[-a])/4 + (ELLbar*L[-a]*Lbar[-b])/4 + 
  (ELL*Lbar[-a]*Lbar[-b])/4 - (ELbarS1*L[-b]*Scovec1[-a])/2 - (ELS1*Lbar[-b]*Scovec1[-a])/2 - (ELbarS1*L[-a]*Scovec1[-b])/2 - 
  (ELS1*Lbar[-a]*Scovec1[-b])/2 + ES1S1*Scovec1[-a]*Scovec1[-b] - (ELbarS2*L[-b]*Scovec2[-a])/2 - (ELS2*Lbar[-b]*Scovec2[-a])/2 + 
  ES1S2*Scovec1[-b]*Scovec2[-a] - (ELbarS2*L[-a]*Scovec2[-b])/2 - (ELS2*Lbar[-a]*Scovec2[-b])/2 + ES1S2*Scovec1[-a]*Scovec2[-b] + 
  ES2S2*Scovec2[-a]*Scovec2[-b])


CDflat[{0,-Li}][PerturbationH[-a,-b]]
SeparateBasis[AIndex][%]
RuleSeparateLiBasis0DerH=CDflat[{0,-Li}][PerturbationH[-a,-b]]==Basis[{0,-Li},c]*CDflat[-c][PerturbationH[-a,-b]];






m[a,b]PerturbationH[-a,-b]
%/.ApplyRuleRulePerturbationHToLLbarAndSCovariant;
%/.ApplyRuleRuleMinkowskiMetricToLLbarSContravariant;
ContractMetric[%];
TraceHInComponents=PerturbationHtrace[]==-HLLbar+HS1S1+HS2S2


(*********************************************************************************************************************************************)


(******* Definitions and rules required for FOGHG.nb ************)




(* the total constraint addition is *)
(*-\[Beta]*Constraint[c]Symmetrize[CDflat[-a]@g[-b,-c],{-a,-b}]+(1/2)*\[Beta]*Constraint[-a]Constraint[-b]+\[Lambda]*ExtraConstraintAddition[-a,-b]+\[Alpha]*ConstraintAdditionDamping[-a,-b]*)


(* general switches (on/off) for the constraint addition *)
(* \[Beta] -> constraint addition associated to Lindblad's hyperbolic reduction, \[Lambda]\[Rule] the asymptotic system cleaner, \[Alpha] \[Rule] Constraint damping*)
DefConstantSymbol@{\[Beta]}
DefConstantSymbol@{\[Lambda]}
DefConstantSymbol@{\[Alpha]}


(** setting all the switches on **)


\[Beta]=1;
\[Alpha]=1;
\[Lambda]=1;



(* parameters in the constraint addition *)
DefConstantSymbol[W0,PrintAs->"\!\(\*SubscriptBox[\(\[Omega]\), \(L\)]\)"]
DefConstantSymbol[W1,PrintAs->"\!\(\*SubscriptBox[\(\[Omega]\), SubscriptBox[\(S\), \(1\)]]\)"]
DefConstantSymbol[W2,PrintAs->"\!\(\*SubscriptBox[\(\[Omega]\), SubscriptBox[\(S\), \(2\)]]\)"]
DefConstantSymbol[W3,PrintAs->"\!\(\*SubscriptBox[\(\[Omega]\), \(\[Diameter]\)]\)"]
DefConstantSymbol[k0,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(0\)]\)"]
DefConstantSymbol[k1,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(1\)]\)"]
DefConstantSymbol[k2,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(2\)]\)"]
DefConstantSymbol[k3,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(3\)]\)"]
DefConstantSymbol[k4,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(4\)]\)"]
DefConstantSymbol[k5,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(5\)]\)"]
DefConstantSymbol[k6,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(6\)]\)"]
DefConstantSymbol[k7,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(7\)]\)"]
DefConstantSymbol[k8,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(8\)]\)"]
DefConstantSymbol[k9,PrintAs->"\!\(\*SubscriptBox[\(\[Kappa]\), \(9\)]\)"]






DefTensor[GenericConstraintAddition[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[ScriptCapitalT]"]
DefTensor[RescaledGenericConstraintAddition[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"T"]
DefTensor[Constraint[-a],M4,PrintAs->"C"]
DefTensor[GaugeSourceFunction[-a],M4,PrintAs->"F"]


DefTensor[NormalN[-a],M4,PrintAs->"N"]
DefScalarFunction[Lapse, PrintAs->"A"]
DefTensor[PigT[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[Pi]"]
DefTensor[SpatialDerivativeg[-c,-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[CapitalPhi]"]
DefScalarFunction[gamma2,PrintAs->"\!\(\*SubscriptBox[\(\[Gamma]\), \(2\)]\)"]
DefTensor[projector[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\[Gamma]"]
(**)
DefTensor[PigTbackground[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(\[Pi]\), \(\[FilledSmallCircle]\)]\)"]
DefTensor[NormalNbackround[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(N\), \(\[FilledSmallCircle]\)]\)"]
DefTensor[NormalNpert[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(N\), \(\[Breve]\)]\)"]
DefTensor[SpatialDerivativegbackground[-c,-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(\[CapitalPhi]\), \(\[FilledSmallCircle]\)]\)"]
DefTensor[PigTpert[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(\[Pi]\), \(\[Breve]\)]\)"]
DefTensor[SpatialDerivativegpert[-c,-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(\[CapitalPhi]\), \(\[Breve]\)]\)"]
DefTensor[projectorbackround[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(\[Gamma]\), \(\[FilledSmallCircle]\)]\)"]
DefTensor[projectorpert[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(\[Gamma]\), \(\[Breve]\)]\)"]
DefTensor[higherOrderTensor3indices[-c,-a,-b],M4,PrintAs->"o"]
DefTensor[higherOrderTensor2indices[-a,-b],M4,PrintAs->"o"]
DefTensor[higherOrderTensor1index[-a],M4,PrintAs->"o"]
(**)
DefTensor[SpaceReductionConstraint[-a,-b,-c],M4,PrintAs->"\[ScriptCapitalC]"]


DefScalarFunction[RescaledDelLphiLL,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(LL\)]\)"]
DefScalarFunction[RescaledDelLphiLLbar,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(L\[CapitalLSlash]\)]\)"]
DefScalarFunction[RescaledDelLphiLbarLbar,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(\[CapitalLSlash]\[CapitalLSlash]\)]\)"]
DefScalarFunction[RescaledDelLphiLS1,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(LS1\)]\)"]
DefScalarFunction[RescaledDelLphiLS2,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(LS2\)]\)"]
DefScalarFunction[RescaledDelLphiLbarS1,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(\[CapitalLSlash]S1\)]\)"]
DefScalarFunction[RescaledDelLphiLbarS2,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(\[CapitalLSlash]S2\)]\)"]
DefScalarFunction[RescaledDelLphiS1S2,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(S1S2\)]\)"]
DefScalarFunction[RescaledDelLphiS1S1,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(S1S1\)]\)"]
DefScalarFunction[RescaledDelLphiS2S2,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)\), \(S2S2\)]\)"]
(**)
DefScalarFunction[RescaledDelLbarphiLL,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(LL\)]\)"]
DefScalarFunction[RescaledDelLbarphiLLbar,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(L\[CapitalLSlash]\)]\)"]
DefScalarFunction[RescaledDelLbarphiLbarLbar,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(\[CapitalLSlash]\[CapitalLSlash]\)]\)"]
DefScalarFunction[RescaledDelLbarphiLS1,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(LS1\)]\)"]
DefScalarFunction[RescaledDelLbarphiLS2,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(LS2\)]\)"]
DefScalarFunction[RescaledDelLbarphiLbarS1,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(\[CapitalLSlash]S1\)]\)"]
DefScalarFunction[RescaledDelLbarphiLbarS2,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(\[CapitalLSlash]S2\)]\)"]
DefScalarFunction[RescaledDelLbarphiS1S2,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(S1S2\)]\)"]
DefScalarFunction[RescaledDelLbarphiS1S1,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(S1S1\)]\)"]
DefScalarFunction[RescaledDelLbarphiS2S2,PrintAs->"\!\(\*SubscriptBox[\(\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)\), \(S2S2\)]\)"]


(*********parametrised constraint addition totally expanded********************)
(\[Beta]*GaugeSourceFunction[-a]*GaugeSourceFunction[-b])/2+(k0*\[Alpha]*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*L[-d]*Lbar[-a]*Lbar[-b])/4+(W0*\[Alpha]*GaugeSourceFunction[c]*L[-c]*Lbar[-a]*Lbar[-b])/(4*r[])+(k3*\[Alpha]*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-d]*Scovec1[-a]*Scovec1[-b])/2+(W3*\[Alpha]*GaugeSourceFunction[c]*Lbar[-c]*Scovec1[-a]*Scovec1[-b])/(2*r[])+(k3*\[Alpha]*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-d]*Scovec2[-a]*Scovec2[-b])/2+(W3*\[Alpha]*GaugeSourceFunction[c]*Lbar[-c]*Scovec2[-a]*Scovec2[-b])/(2*r[])-(W1*\[Alpha]*GaugeSourceFunction[c]*Lbar[-b]*Scovec1[-a]*Svec1[-c])/(2*r[])-(W1*\[Alpha]*GaugeSourceFunction[c]*Lbar[-a]*Scovec1[-b]*Svec1[-c])/(2*r[])-(k1*\[Alpha]*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-b]*Scovec1[-a]*Svec1[-d])/2-(k1*\[Alpha]*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-a]*Scovec1[-b]*Svec1[-d])/2-(W2*\[Alpha]*GaugeSourceFunction[c]*Lbar[-b]*Scovec2[-a]*Svec2[-c])/(2*r[])-(W2*\[Alpha]*GaugeSourceFunction[c]*Lbar[-a]*Scovec2[-b]*Svec2[-c])/(2*r[])-(k2*\[Alpha]*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-b]*Scovec2[-a]*Svec2[-d])/2-(k2*\[Alpha]*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-a]*Scovec2[-b]*Svec2[-d])/2-(\[Beta]*GaugeSourceFunction[c]*CDflat[-a][g[-b,-c]])/2-(\[Beta]*g[c,d]*GaugeSourceFunction[-b]*CDflat[-a][g[-c,-d]])/4-(\[Beta]*GaugeSourceFunction[c]*CDflat[-b][g[-a,-c]])/2-(\[Beta]*g[c,d]*GaugeSourceFunction[-a]*CDflat[-b][g[-c,-d]])/4+(\[Beta]*g[c,d]*g[f,h]*CDflat[-a][g[-c,-d]]*CDflat[-b][g[-f,-h]])/8-(\[Lambda]*GaugeSourceFunction[c]*L[-a]*L[-b]*Lbar[d]*Lbar[f]*CDflat[-c][g[-d,-f]])/8-(W0*\[Alpha]*g[d,f]*L[c]*Lbar[-a]*Lbar[-b]*CDflat[-c][g[-d,-f]])/(8*r[])-(W3*\[Alpha]*g[d,f]*Lbar[c]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][g[-d,-f]])/(4*r[])-(W3*\[Alpha]*g[d,f]*Lbar[c]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][g[-d,-f]])/(4*r[])+(W1*\[Alpha]*g[d,f]*Lbar[-b]*Scovec1[-a]*Svec1[c]*CDflat[-c][g[-d,-f]])/(4*r[])+(W1*\[Alpha]*g[d,f]*Lbar[-a]*Scovec1[-b]*Svec1[c]*CDflat[-c][g[-d,-f]])/(4*r[])+(W2*\[Alpha]*g[d,f]*Lbar[-b]*Scovec2[-a]*Svec2[c]*CDflat[-c][g[-d,-f]])/(4*r[])+(W2*\[Alpha]*g[d,f]*Lbar[-a]*Scovec2[-b]*Svec2[c]*CDflat[-c][g[-d,-f]])/(4*r[])+(\[Beta]*g[c,d]*GaugeSourceFunction[-b]*CDflat[-d][g[-a,-c]])/2-(\[Beta]*g[c,d]*g[f,h]*CDflat[-b][g[-f,-h]]*CDflat[-d][g[-a,-c]])/4+(\[Beta]*g[c,d]*GaugeSourceFunction[-a]*CDflat[-d][g[-b,-c]])/2-(\[Beta]*g[c,d]*g[f,h]*CDflat[-a][g[-f,-h]]*CDflat[-d][g[-b,-c]])/4-(k0*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-d][g[-f,-h]])/4-(k3*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-c]*Scovec1[-a]*Scovec1[-b]*CDflat[-d][g[-f,-h]])/4-(k3*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-d][g[-f,-h]])/4-(k3*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-c]*Scovec2[-a]*Scovec2[-b]*CDflat[-d][g[-f,-h]])/4-(k3*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-d][g[-f,-h]])/4+(k1*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-b]*Scovec1[-a]*Svec1[-c]*CDflat[-d][g[-f,-h]])/4+(k1*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-a]*Scovec1[-b]*Svec1[-c]*CDflat[-d][g[-f,-h]])/4+(k1*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-d][g[-f,-h]])/4+(k1*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-d][g[-f,-h]])/4-(k4*\[Alpha]*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-d][g[-f,-h]])/2+(k2*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-b]*Scovec2[-a]*Svec2[-c]*CDflat[-d][g[-f,-h]])/4+(k2*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-a]*Scovec2[-b]*Svec2[-c]*CDflat[-d][g[-f,-h]])/4+(k2*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-d][g[-f,-h]])/4+(k2*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-d][g[-f,-h]])/4-(k6*\[Alpha]*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-d][g[-f,-h]])/2-(k6*\[Alpha]*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-d][g[-f,-h]])/2-(k4*\[Alpha]*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-d][g[-f,-h]])/2+(\[Beta]*g[c,d]*g[f,h]*CDflat[-a][g[-b,-c]]*CDflat[-d][g[-f,-h]])/4+(\[Beta]*g[c,d]*g[f,h]*CDflat[-b][g[-a,-c]]*CDflat[-d][g[-f,-h]])/4+(k4*\[Alpha]*g[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-c][g[-i,-j]]*CDflat[-d][g[-f,-h]])/4+(k6*\[Alpha]*g[i,j]*L[c]*Lbar[d]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-d][g[-f,-h]])/4+(k6*\[Alpha]*g[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-d][g[-f,-h]])/4+(k4*\[Alpha]*g[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-d][g[-f,-h]])/4+(k0*\[Alpha]*g[f,h]*g[i,j]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/16+(k3*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8+(k3*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8-(k1*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8-(k1*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8-(k2*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8-(k2*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8+(\[Lambda]*GaugeSourceFunction[c]*L[-a]*L[-b]*Lbar[d]*Lbar[f]*CDflat[-f][g[-c,-d]])/4+(W0*\[Alpha]*g[d,f]*L[c]*Lbar[-a]*Lbar[-b]*CDflat[-f][g[-c,-d]])/(4*r[])+(W3*\[Alpha]*g[d,f]*Lbar[c]*Scovec1[-a]*Scovec1[-b]*CDflat[-f][g[-c,-d]])/(2*r[])+(W3*\[Alpha]*g[d,f]*Lbar[c]*Scovec2[-a]*Scovec2[-b]*CDflat[-f][g[-c,-d]])/(2*r[])-(W1*\[Alpha]*g[d,f]*Lbar[-b]*Scovec1[-a]*Svec1[c]*CDflat[-f][g[-c,-d]])/(2*r[])-(W1*\[Alpha]*g[d,f]*Lbar[-a]*Scovec1[-b]*Svec1[c]*CDflat[-f][g[-c,-d]])/(2*r[])-(W2*\[Alpha]*g[d,f]*Lbar[-b]*Scovec2[-a]*Svec2[c]*CDflat[-f][g[-c,-d]])/(2*r[])-(W2*\[Alpha]*g[d,f]*Lbar[-a]*Scovec2[-b]*Svec2[c]*CDflat[-f][g[-c,-d]])/(2*r[])+(k7*\[Alpha]*GaugeSourceFunction[c]*L[-b]*L[-c]*Lbar[d]*Lbar[f]*Scovec1[-a]*Svec1[h]*CDflat[-f][g[-d,-h]])/4+(k7*\[Alpha]*GaugeSourceFunction[c]*L[-a]*L[-c]*Lbar[d]*Lbar[f]*Scovec1[-b]*Svec1[h]*CDflat[-f][g[-d,-h]])/4+(k8*\[Alpha]*GaugeSourceFunction[c]*L[-b]*L[-c]*Lbar[d]*Lbar[f]*Scovec2[-a]*Svec2[h]*CDflat[-f][g[-d,-h]])/4+(k8*\[Alpha]*GaugeSourceFunction[c]*L[-a]*L[-c]*Lbar[d]*Lbar[f]*Scovec2[-b]*Svec2[h]*CDflat[-f][g[-d,-h]])/4-(k7*\[Alpha]*g[i,j]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Scovec1[-a]*Svec1[h]*CDflat[-c][g[-i,-j]]*CDflat[-f][g[-d,-h]])/8-(k7*\[Alpha]*g[i,j]*L[-a]*L[c]*Lbar[d]*Lbar[f]*Scovec1[-b]*Svec1[h]*CDflat[-c][g[-i,-j]]*CDflat[-f][g[-d,-h]])/8-(k8*\[Alpha]*g[i,j]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Scovec2[-a]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-f][g[-d,-h]])/8-(k8*\[Alpha]*g[i,j]*L[-a]*L[c]*Lbar[d]*Lbar[f]*Scovec2[-b]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-f][g[-d,-h]])/8+(\[Beta]*g[c,d]*g[f,h]*CDflat[-d][g[-a,-c]]*CDflat[-h][g[-b,-f]])/2-(k0*\[Alpha]*g[f,h]*g[i,j]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k5*\[Alpha]*g[i,j]*L[-b]*L[c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/16+(k5*\[Alpha]*g[i,j]*L[-a]*L[c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/16-(k3*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4-(k3*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k1*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k1*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k2*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k2*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k0*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-h][g[-d,-f]])/2-(k5*\[Alpha]*GaugeSourceFunction[c]*L[-b]*L[-c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*CDflat[-h][g[-d,-f]])/8-(k5*\[Alpha]*GaugeSourceFunction[c]*L[-a]*L[-c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*CDflat[-h][g[-d,-f]])/8-(k9*\[Alpha]*GaugeSourceFunction[c]*L[-a]*L[-b]*L[-c]*Lbar[d]*Lbar[f]*Lbar[h]*CDflat[-h][g[-d,-f]])/8+(k3*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-c]*Scovec1[-a]*Scovec1[-b]*CDflat[-h][g[-d,-f]])/2+(k3*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-h][g[-d,-f]])/2+(k3*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-c]*Scovec2[-a]*Scovec2[-b]*CDflat[-h][g[-d,-f]])/2+(k3*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-h][g[-d,-f]])/2-(k1*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-b]*Scovec1[-a]*Svec1[-c]*CDflat[-h][g[-d,-f]])/2-(k1*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-a]*Scovec1[-b]*Svec1[-c]*CDflat[-h][g[-d,-f]])/2-(k1*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-h][g[-d,-f]])/2-(k1*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-h][g[-d,-f]])/2-(k2*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-b]*Scovec2[-a]*Svec2[-c]*CDflat[-h][g[-d,-f]])/2-(k2*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[d]*Lbar[-a]*Scovec2[-b]*Svec2[-c]*CDflat[-h][g[-d,-f]])/2-(k2*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-h][g[-d,-f]])/2-(k2*\[Alpha]*g[f,h]*GaugeSourceFunction[c]*L[-c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-h][g[-d,-f]])/2-(\[Beta]*g[c,d]*g[f,h]*CDflat[-a][g[-b,-c]]*CDflat[-h][g[-d,-f]])/2-(\[Beta]*g[c,d]*g[f,h]*CDflat[-b][g[-a,-c]]*CDflat[-h][g[-d,-f]])/2+(k9*\[Alpha]*g[i,j]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/16-(k3*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4-(k3*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4+(k1*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4+(k1*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4+(k2*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4+(k2*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4-(\[Lambda]*g[f,h]*g[i,j]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*CDflat[-d][g[-c,-f]]*CDflat[-h][g[-i,-j]])/8+(\[Lambda]*g[f,h]*g[i,j]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*CDflat[-f][g[-c,-d]]*CDflat[-h][g[-i,-j]])/16-(k4*\[Alpha]*g[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-d][g[-f,-h]]*CDflat[-j][g[-c,-i]])/2-(k6*\[Alpha]*g[i,j]*L[c]*Lbar[d]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-d][g[-f,-h]]*CDflat[-j][g[-c,-i]])/2-(k6*\[Alpha]*g[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-d][g[-f,-h]]*CDflat[-j][g[-c,-i]])/2-(k4*\[Alpha]*g[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-d][g[-f,-h]]*CDflat[-j][g[-c,-i]])/2+(k7*\[Alpha]*g[i,j]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Scovec1[-a]*Svec1[h]*CDflat[-f][g[-d,-h]]*CDflat[-j][g[-c,-i]])/4+(k7*\[Alpha]*g[i,j]*L[-a]*L[c]*Lbar[d]*Lbar[f]*Scovec1[-b]*Svec1[h]*CDflat[-f][g[-d,-h]]*CDflat[-j][g[-c,-i]])/4+(k8*\[Alpha]*g[i,j]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Scovec2[-a]*Svec2[h]*CDflat[-f][g[-d,-h]]*CDflat[-j][g[-c,-i]])/4+(k8*\[Alpha]*g[i,j]*L[-a]*L[c]*Lbar[d]*Lbar[f]*Scovec2[-b]*Svec2[h]*CDflat[-f][g[-d,-h]]*CDflat[-j][g[-c,-i]])/4-(k9*\[Alpha]*g[i,j]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*CDflat[-h][g[-d,-f]]*CDflat[-j][g[-c,-i]])/8+(k0*\[Alpha]*g[f,h]*g[i,j]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/4-(k5*\[Alpha]*g[i,j]*L[-b]*L[c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/8-(k5*\[Alpha]*g[i,j]*L[-a]*L[c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/8+(k3*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2+(k3*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2-(k1*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2-(k1*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2-(k2*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2-(k2*\[Alpha]*g[f,h]*g[i,j]*L[c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2+(\[Lambda]*g[f,h]*g[i,j]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*CDflat[-d][g[-c,-f]]*CDflat[-j][g[-h,-i]])/4-(\[Lambda]*g[f,h]*g[i,j]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*CDflat[-f][g[-c,-d]]*CDflat[-j][g[-h,-i]])/8;
%/.ApplyRuleWithoutMovingIndices[g[a,b]==Invg[a,b]];
InputForm[%]


ParametrisedConstraintAddition=GenericConstraintAddition[-a,-b]==(GaugeSourceFunction[-a]*GaugeSourceFunction[-b])/2+(k0*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*L[-d]*Lbar[-a]*Lbar[-b])/4+(W0*GaugeSourceFunction[c]*L[-c]*Lbar[-a]*Lbar[-b])/(4*r[])+(k3*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-d]*Scovec1[-a]*Scovec1[-b])/2+(W3*GaugeSourceFunction[c]*Lbar[-c]*Scovec1[-a]*Scovec1[-b])/(2*r[])+(k3*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-d]*Scovec2[-a]*Scovec2[-b])/2+(W3*GaugeSourceFunction[c]*Lbar[-c]*Scovec2[-a]*Scovec2[-b])/(2*r[])-(W1*GaugeSourceFunction[c]*Lbar[-b]*Scovec1[-a]*Svec1[-c])/(2*r[])-(W1*GaugeSourceFunction[c]*Lbar[-a]*Scovec1[-b]*Svec1[-c])/(2*r[])-(k1*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-b]*Scovec1[-a]*Svec1[-d])/2-(k1*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-a]*Scovec1[-b]*Svec1[-d])/2-(W2*GaugeSourceFunction[c]*Lbar[-b]*Scovec2[-a]*Svec2[-c])/(2*r[])-(W2*GaugeSourceFunction[c]*Lbar[-a]*Scovec2[-b]*Svec2[-c])/(2*r[])-(k2*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-b]*Scovec2[-a]*Svec2[-d])/2-(k2*GaugeSourceFunction[c]*GaugeSourceFunction[d]*L[-c]*Lbar[-a]*Scovec2[-b]*Svec2[-d])/2-(GaugeSourceFunction[c]*CDflat[-a][g[-b,-c]])/2-(GaugeSourceFunction[-b]*Invg[c,d]*CDflat[-a][g[-c,-d]])/4-(GaugeSourceFunction[c]*CDflat[-b][g[-a,-c]])/2-(GaugeSourceFunction[-a]*Invg[c,d]*CDflat[-b][g[-c,-d]])/4+(Invg[c,d]*Invg[f,h]*CDflat[-a][g[-c,-d]]*CDflat[-b][g[-f,-h]])/8-(GaugeSourceFunction[c]*L[-a]*L[-b]*Lbar[d]*Lbar[f]*CDflat[-c][g[-d,-f]])/8-(W0*Invg[d,f]*L[c]*Lbar[-a]*Lbar[-b]*CDflat[-c][g[-d,-f]])/(8*r[])-(W3*Invg[d,f]*Lbar[c]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][g[-d,-f]])/(4*r[])-(W3*Invg[d,f]*Lbar[c]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][g[-d,-f]])/(4*r[])+(W1*Invg[d,f]*Lbar[-b]*Scovec1[-a]*Svec1[c]*CDflat[-c][g[-d,-f]])/(4*r[])+(W1*Invg[d,f]*Lbar[-a]*Scovec1[-b]*Svec1[c]*CDflat[-c][g[-d,-f]])/(4*r[])+(W2*Invg[d,f]*Lbar[-b]*Scovec2[-a]*Svec2[c]*CDflat[-c][g[-d,-f]])/(4*r[])+(W2*Invg[d,f]*Lbar[-a]*Scovec2[-b]*Svec2[c]*CDflat[-c][g[-d,-f]])/(4*r[])+(GaugeSourceFunction[-b]*Invg[c,d]*CDflat[-d][g[-a,-c]])/2-(Invg[c,d]*Invg[f,h]*CDflat[-b][g[-f,-h]]*CDflat[-d][g[-a,-c]])/4+(GaugeSourceFunction[-a]*Invg[c,d]*CDflat[-d][g[-b,-c]])/2-(Invg[c,d]*Invg[f,h]*CDflat[-a][g[-f,-h]]*CDflat[-d][g[-b,-c]])/4-(k0*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-d][g[-f,-h]])/4-(k3*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-c]*Scovec1[-a]*Scovec1[-b]*CDflat[-d][g[-f,-h]])/4-(k3*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-d][g[-f,-h]])/4-(k3*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-c]*Scovec2[-a]*Scovec2[-b]*CDflat[-d][g[-f,-h]])/4-(k3*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-d][g[-f,-h]])/4+(k1*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-b]*Scovec1[-a]*Svec1[-c]*CDflat[-d][g[-f,-h]])/4+(k1*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-a]*Scovec1[-b]*Svec1[-c]*CDflat[-d][g[-f,-h]])/4+(k1*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-d][g[-f,-h]])/4+(k1*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-d][g[-f,-h]])/4-(k4*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-d][g[-f,-h]])/2+(k2*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-b]*Scovec2[-a]*Svec2[-c]*CDflat[-d][g[-f,-h]])/4+(k2*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-a]*Scovec2[-b]*Svec2[-c]*CDflat[-d][g[-f,-h]])/4+(k2*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-d][g[-f,-h]])/4+(k2*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-d][g[-f,-h]])/4-(k6*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-d][g[-f,-h]])/2-(k6*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-d][g[-f,-h]])/2-(k4*GaugeSourceFunction[c]*L[-c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-d][g[-f,-h]])/2+(Invg[c,d]*Invg[f,h]*CDflat[-a][g[-b,-c]]*CDflat[-d][g[-f,-h]])/4+(Invg[c,d]*Invg[f,h]*CDflat[-b][g[-a,-c]]*CDflat[-d][g[-f,-h]])/4+(k4*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-c][g[-i,-j]]*CDflat[-d][g[-f,-h]])/4+(k6*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-d][g[-f,-h]])/4+(k6*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-d][g[-f,-h]])/4+(k4*Invg[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-d][g[-f,-h]])/4+(k0*Invg[f,h]*Invg[i,j]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/16+(k3*Invg[f,h]*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8+(k3*Invg[f,h]*Invg[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8-(k1*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8-(k1*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8-(k2*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8-(k2*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-c][g[-f,-h]]*CDflat[-d][g[-i,-j]])/8+(GaugeSourceFunction[c]*L[-a]*L[-b]*Lbar[d]*Lbar[f]*CDflat[-f][g[-c,-d]])/4+(W0*Invg[d,f]*L[c]*Lbar[-a]*Lbar[-b]*CDflat[-f][g[-c,-d]])/(4*r[])+(W3*Invg[d,f]*Lbar[c]*Scovec1[-a]*Scovec1[-b]*CDflat[-f][g[-c,-d]])/(2*r[])+(W3*Invg[d,f]*Lbar[c]*Scovec2[-a]*Scovec2[-b]*CDflat[-f][g[-c,-d]])/(2*r[])-(W1*Invg[d,f]*Lbar[-b]*Scovec1[-a]*Svec1[c]*CDflat[-f][g[-c,-d]])/(2*r[])-(W1*Invg[d,f]*Lbar[-a]*Scovec1[-b]*Svec1[c]*CDflat[-f][g[-c,-d]])/(2*r[])-(W2*Invg[d,f]*Lbar[-b]*Scovec2[-a]*Svec2[c]*CDflat[-f][g[-c,-d]])/(2*r[])-(W2*Invg[d,f]*Lbar[-a]*Scovec2[-b]*Svec2[c]*CDflat[-f][g[-c,-d]])/(2*r[])+(k7*GaugeSourceFunction[c]*L[-b]*L[-c]*Lbar[d]*Lbar[f]*Scovec1[-a]*Svec1[h]*CDflat[-f][g[-d,-h]])/4+(k7*GaugeSourceFunction[c]*L[-a]*L[-c]*Lbar[d]*Lbar[f]*Scovec1[-b]*Svec1[h]*CDflat[-f][g[-d,-h]])/4+(k8*GaugeSourceFunction[c]*L[-b]*L[-c]*Lbar[d]*Lbar[f]*Scovec2[-a]*Svec2[h]*CDflat[-f][g[-d,-h]])/4+(k8*GaugeSourceFunction[c]*L[-a]*L[-c]*Lbar[d]*Lbar[f]*Scovec2[-b]*Svec2[h]*CDflat[-f][g[-d,-h]])/4-(k7*Invg[i,j]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Scovec1[-a]*Svec1[h]*CDflat[-c][g[-i,-j]]*CDflat[-f][g[-d,-h]])/8-(k7*Invg[i,j]*L[-a]*L[c]*Lbar[d]*Lbar[f]*Scovec1[-b]*Svec1[h]*CDflat[-c][g[-i,-j]]*CDflat[-f][g[-d,-h]])/8-(k8*Invg[i,j]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Scovec2[-a]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-f][g[-d,-h]])/8-(k8*Invg[i,j]*L[-a]*L[c]*Lbar[d]*Lbar[f]*Scovec2[-b]*Svec2[h]*CDflat[-c][g[-i,-j]]*CDflat[-f][g[-d,-h]])/8+(Invg[c,d]*Invg[f,h]*CDflat[-d][g[-a,-c]]*CDflat[-h][g[-b,-f]])/2-(k0*Invg[f,h]*Invg[i,j]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k5*Invg[i,j]*L[-b]*L[c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/16+(k5*Invg[i,j]*L[-a]*L[c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/16-(k3*Invg[f,h]*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4-(k3*Invg[f,h]*Invg[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k1*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k1*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k2*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k2*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-d][g[-i,-j]]*CDflat[-h][g[-c,-f]])/4+(k0*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-h][g[-d,-f]])/2-(k5*GaugeSourceFunction[c]*L[-b]*L[-c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*CDflat[-h][g[-d,-f]])/8-(k5*GaugeSourceFunction[c]*L[-a]*L[-c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*CDflat[-h][g[-d,-f]])/8-(k9*GaugeSourceFunction[c]*L[-a]*L[-b]*L[-c]*Lbar[d]*Lbar[f]*Lbar[h]*CDflat[-h][g[-d,-f]])/8+(k3*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-c]*Scovec1[-a]*Scovec1[-b]*CDflat[-h][g[-d,-f]])/2+(k3*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-h][g[-d,-f]])/2+(k3*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-c]*Scovec2[-a]*Scovec2[-b]*CDflat[-h][g[-d,-f]])/2+(k3*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-h][g[-d,-f]])/2-(k1*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-b]*Scovec1[-a]*Svec1[-c]*CDflat[-h][g[-d,-f]])/2-(k1*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-a]*Scovec1[-b]*Svec1[-c]*CDflat[-h][g[-d,-f]])/2-(k1*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-h][g[-d,-f]])/2-(k1*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-h][g[-d,-f]])/2-(k2*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-b]*Scovec2[-a]*Svec2[-c]*CDflat[-h][g[-d,-f]])/2-(k2*GaugeSourceFunction[c]*Invg[f,h]*L[d]*Lbar[-a]*Scovec2[-b]*Svec2[-c]*CDflat[-h][g[-d,-f]])/2-(k2*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-h][g[-d,-f]])/2-(k2*GaugeSourceFunction[c]*Invg[f,h]*L[-c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-h][g[-d,-f]])/2-(Invg[c,d]*Invg[f,h]*CDflat[-a][g[-b,-c]]*CDflat[-h][g[-d,-f]])/2-(Invg[c,d]*Invg[f,h]*CDflat[-b][g[-a,-c]]*CDflat[-h][g[-d,-f]])/2+(k9*Invg[i,j]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/16-(k3*Invg[f,h]*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4-(k3*Invg[f,h]*Invg[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4+(k1*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4+(k1*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4+(k2*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4+(k2*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-c][g[-i,-j]]*CDflat[-h][g[-d,-f]])/4-(Invg[f,h]*Invg[i,j]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*CDflat[-d][g[-c,-f]]*CDflat[-h][g[-i,-j]])/8+(Invg[f,h]*Invg[i,j]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*CDflat[-f][g[-c,-d]]*CDflat[-h][g[-i,-j]])/16-(k4*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-d][g[-f,-h]]*CDflat[-j][g[-c,-i]])/2-(k6*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-d][g[-f,-h]]*CDflat[-j][g[-c,-i]])/2-(k6*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-d][g[-f,-h]]*CDflat[-j][g[-c,-i]])/2-(k4*Invg[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-d][g[-f,-h]]*CDflat[-j][g[-c,-i]])/2+(k7*Invg[i,j]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Scovec1[-a]*Svec1[h]*CDflat[-f][g[-d,-h]]*CDflat[-j][g[-c,-i]])/4+(k7*Invg[i,j]*L[-a]*L[c]*Lbar[d]*Lbar[f]*Scovec1[-b]*Svec1[h]*CDflat[-f][g[-d,-h]]*CDflat[-j][g[-c,-i]])/4+(k8*Invg[i,j]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Scovec2[-a]*Svec2[h]*CDflat[-f][g[-d,-h]]*CDflat[-j][g[-c,-i]])/4+(k8*Invg[i,j]*L[-a]*L[c]*Lbar[d]*Lbar[f]*Scovec2[-b]*Svec2[h]*CDflat[-f][g[-d,-h]]*CDflat[-j][g[-c,-i]])/4-(k9*Invg[i,j]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*CDflat[-h][g[-d,-f]]*CDflat[-j][g[-c,-i]])/8+(k0*Invg[f,h]*Invg[i,j]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/4-(k5*Invg[i,j]*L[-b]*L[c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/8-(k5*Invg[i,j]*L[-a]*L[c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/8+(k3*Invg[f,h]*Invg[i,j]*L[c]*Lbar[d]*Scovec1[-a]*Scovec1[-b]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2+(k3*Invg[f,h]*Invg[i,j]*L[c]*Lbar[d]*Scovec2[-a]*Scovec2[-b]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2-(k1*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-b]*Scovec1[-a]*Svec1[d]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2-(k1*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-a]*Scovec1[-b]*Svec1[d]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2-(k2*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-b]*Scovec2[-a]*Svec2[d]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2-(k2*Invg[f,h]*Invg[i,j]*L[c]*Lbar[-a]*Scovec2[-b]*Svec2[d]*CDflat[-h][g[-c,-f]]*CDflat[-j][g[-d,-i]])/2+(Invg[f,h]*Invg[i,j]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*CDflat[-d][g[-c,-f]]*CDflat[-j][g[-h,-i]])/4-(Invg[f,h]*Invg[i,j]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*CDflat[-f][g[-c,-d]]*CDflat[-j][g[-h,-i]])/8;



(**************************** Definitions for the 3+1 split ********************************)
(************ warning these expressions have been expanded ONLY to second order ************)


EquationForTheMetric=NormalN[a]*CDflat[-a][g[-b,-c]]==-PigT[-b,-c];



EquationForPhi=NormalN[a]*projector[-f,b]*CDflat[-a][SpatialDerivativeg[-b,-c,-d]]==(NormalN[a]*NormalN[b]*PigT[-c,-d]*SpatialDerivativeg[-f,-a,-b])/2+NormalN[b]*projector[a,h]*SpatialDerivativeg[-a,-c,-d]*SpatialDerivativeg[-f,-b,-h]+gamma2*(-SpatialDerivativeg[-f,-c,-d]+projector[-f,a]*CDflat[-a][g[-c,-d]])-projector[-f,b]*CDflat[-b][PigT[-c,-d]];



EquationForPi=NormalN[c]*CDflat[-c][PigT[-a,-b]]==2*GenericConstraintAddition[-a,-b]-(Invg[c,d]*Invg[h,f]*NormalN[-f]*NormalN[-h]*PigT[-a,-c]*PigT[-b,-d])/2-(Invg[c,d]*Invg[h,f]*NormalN[-c]*NormalN[-f]*PigT[-a,-h]*PigT[-b,-d])/2-(Invg[c,d]*Invg[h,f]*NormalN[-d]*NormalN[-h]*PigT[-a,-c]*PigT[-b,-f])/2-(Invg[c,d]*Invg[h,f]*NormalN[-c]*NormalN[-d]*PigT[-a,-h]*PigT[-b,-f])/2-(NormalN[c]*NormalN[d]*PigT[-a,-b]*PigT[-c,-d])/2+(Invg[c,d]*Invg[h,f]*NormalN[-a]*NormalN[-f]*PigT[-b,-d]*PigT[-c,-h])/2+(Invg[c,d]*Invg[h,f]*NormalN[-a]*NormalN[-d]*PigT[-b,-f]*PigT[-c,-h])/2-2*Invg[c,d]*PigT[-c,-a]*PigT[-d,-b]+(Invg[c,d]*Invg[h,f]*NormalN[-b]*NormalN[-h]*PigT[-a,-c]*PigT[-d,-f])/2+(Invg[c,d]*Invg[h,f]*NormalN[-b]*NormalN[-c]*PigT[-a,-h]*PigT[-d,-f])/2-(Invg[c,d]*Invg[h,f]*NormalN[-a]*NormalN[-b]*PigT[-c,-h]*PigT[-d,-f])/2+(Invg[c,d]*Invg[h,f]*NormalN[-f]*PigT[-b,-d]*SpatialDerivativeg[-a,-c,-h])/2+(Invg[c,d]*Invg[h,f]*NormalN[-d]*PigT[-b,-f]*SpatialDerivativeg[-a,-c,-h])/2-(Invg[c,d]*Invg[h,f]*NormalN[-b]*PigT[-d,-f]*SpatialDerivativeg[-a,-c,-h])/2+(Invg[c,d]*Invg[h,f]*NormalN[-h]*PigT[-a,-c]*SpatialDerivativeg[-b,-d,-f])/2+(Invg[c,d]*Invg[h,f]*NormalN[-c]*PigT[-a,-h]*SpatialDerivativeg[-b,-d,-f])/2-(Invg[c,d]*Invg[h,f]*NormalN[-a]*PigT[-c,-h]*SpatialDerivativeg[-b,-d,-f])/2-(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-a,-c,-h]*SpatialDerivativeg[-b,-d,-f])/2-NormalN[d]*PigT[-d,-f]*projector[c,f]*SpatialDerivativeg[-c,-a,-b]-(Invg[c,d]*Invg[h,f]*NormalN[-f]*PigT[-b,-d]*SpatialDerivativeg[-c,-a,-h])/2-(Invg[c,d]*Invg[h,f]*NormalN[-d]*PigT[-b,-f]*SpatialDerivativeg[-c,-a,-h])/2+(Invg[c,d]*Invg[h,f]*NormalN[-b]*PigT[-d,-f]*SpatialDerivativeg[-c,-a,-h])/2+(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-b,-d,-f]*SpatialDerivativeg[-c,-a,-h])/2-(Invg[c,d]*Invg[h,f]*NormalN[-h]*PigT[-a,-c]*SpatialDerivativeg[-d,-b,-f])/2-(Invg[c,d]*Invg[h,f]*NormalN[-c]*PigT[-a,-h]*SpatialDerivativeg[-d,-b,-f])/2+(Invg[c,d]*Invg[h,f]*NormalN[-a]*PigT[-c,-h]*SpatialDerivativeg[-d,-b,-f])/2+(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-a,-c,-h]*SpatialDerivativeg[-d,-b,-f])/2-(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-c,-a,-h]*SpatialDerivativeg[-d,-b,-f])/2-(Invg[c,d]*Invg[h,f]*NormalN[-h]*PigT[-a,-c]*SpatialDerivativeg[-f,-b,-d])/2-(Invg[c,d]*Invg[h,f]*NormalN[-c]*PigT[-a,-h]*SpatialDerivativeg[-f,-b,-d])/2+(Invg[c,d]*Invg[h,f]*NormalN[-a]*PigT[-c,-h]*SpatialDerivativeg[-f,-b,-d])/2+(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-a,-c,-h]*SpatialDerivativeg[-f,-b,-d])/2-(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-c,-a,-h]*SpatialDerivativeg[-f,-b,-d])/2-(Invg[c,d]*Invg[h,f]*NormalN[-f]*PigT[-b,-d]*SpatialDerivativeg[-h,-a,-c])/2-(Invg[c,d]*Invg[h,f]*NormalN[-d]*PigT[-b,-f]*SpatialDerivativeg[-h,-a,-c])/2+(Invg[c,d]*Invg[h,f]*NormalN[-b]*PigT[-d,-f]*SpatialDerivativeg[-h,-a,-c])/2+(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-b,-d,-f]*SpatialDerivativeg[-h,-a,-c])/2-(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-d,-b,-f]*SpatialDerivativeg[-h,-a,-c])/2-(Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-f,-b,-d]*SpatialDerivativeg[-h,-a,-c])/2+2*Invg[c,d]*Invg[h,f]*SpatialDerivativeg[-f,-d,-b]*SpatialDerivativeg[-h,-c,-a]-CD[-a][GaugeSourceFunction[-b]]-CD[-b][GaugeSourceFunction[-a]]-projector[c,d]*CDflat[-c][SpatialDerivativeg[-d,-a,-b]];



(*Derivation of the expressions for the split for the Lapse, Normal Vector and Projector*)


(*Basis[-a,{0,Sp}]*Basis[-b,{0,Sp}]*g[a,b]\[Equal]-Lapse^(-2)
(*this rule is because now the frozen metric is g, so the contravariant g is written as Invg *)
%/.ApplyRuleWithoutMovingIndices[g[a,b]==Invg[a,b]];
%/.ApplyRuleWithoutMovingIndices@RuleMetricDeltaCounterContravariantSplit;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Flatten[Solve[%,Lapse]];
%[[2]][[1]]==%[[2]][[2]];
ToCanonical[%];
Series[%,{DeltaCounter,0,1}]
InputForm[%]*)


LapseToOrderDelta=Lapse==SeriesData[DeltaCounter,0,{1,(-L[a]*L[b]*Perturbationh[-a,-b]-2*L[a]*Lbar[b]*Perturbationh[-a,-b]-Lbar[a]*Lbar[b]*Perturbationh[-a,-b])/8},0,2,1]


NormalN[-a]==-(Lapse*Basis[-a,{0,Sp}])
(*this rule is because now the frozen metric is g, so the contravariant g is written as Invg *)
%/.ApplyRuleWithoutMovingIndices[g[a,b]==Invg[a,b]];
%/.ApplyRuleBasisSpToFlatNull;
NormalDownToLapseAndFlatNull=NormalN[-a]==-(Lapse*(L[-a]+Lbar[-a]))/2


(*Split of the Normal covector *)


NormalDownToLapseAndFlatNull;
%/.ApplyRule@Normal[LapseToOrderDelta];
Series[%,{DeltaCounter,0,1}]


NormalDownSplit=NormalN[-a]==NormalNbackround[-a]+DeltaCounter*NormalNpert[-a]+DeltaCounter^2*higherOrderTensor1index[-a]


NormalN[-a]==DeltaCounter^2 higherOrderTensor1index[-a]+NormalNbackround[-a]+DeltaCounter NormalNpert[-a]


SubstituteNormalbackground=NormalNbackround[-a]==-(1/2)(L[-a]+Lbar[-a])
SubstituteNormalpertRawExpression=NormalNpert[-a]==((L[-a]+Lbar[-a])*(L[b]*L[c]*Perturbationh[-b,-c]+2*L[b]*Lbar[c]*Perturbationh[-b,-c]+Lbar[b]*Lbar[c]*Perturbationh[-b,-c]))/16


(*observe that *)
SubstituteNormalbackground
%/.ApplyRuleFlatNullInTermsOfBasisSp;
Expand[%]


(*For completness lets define *)
DefTensor[RadialCovector[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(R\), \(\[FilledSmallCircle]\)]\)"]


RadialCovector[-a]==Basis[{1,Sp},-a]
RadialCovectorbackgroundToSp1=RadialCovector[-a]==Basis[-a,{1,Sp}];
%/.ApplyRuleBasisSpToFlatNull;
SubstituteRadialCovectorbackground=RadialCovector[-a]==(L[-a]-Lbar[-a])/2


(*Flatten[Solve[{SubstituteNormalbackground,SubstituteRadialCovectorbackground},{L[-a],Lbar[-a]}]];
%[[1]][[1]]==%[[1]][[2]];*)
LtoNandR=L[-a]==-NormalNbackround[-a]+RadialCovector[-a]
(**)
(*Flatten[Solve[{SubstituteNormalbackground,SubstituteRadialCovectorbackground},{L[-a],Lbar[-a]}]];
%[[2]][[1]]==%[[2]][[2]];*)
LbartoNandR=Lbar[-a]==-NormalNbackround[-a]-RadialCovector[-a]


RadialCovector[a]
%/.ApplyRule@SubstituteRadialCovectorbackground;
%/.ApplyRuleFlatNullInTermsOfBasisSp;
Expand[%]


SubstituteNormalpertRawExpression
%/.ApplyRule@LtoNandR;
%/.ApplyRule@LbartoNandR;
ToCanonical[%];
SubstituteNormalpert=NormalNpert[-a]==-(NormalNbackround[-a]*NormalNbackround[b]*NormalNbackround[c]*Perturbationh[-b,-c])/2


(* Split of the Normal vector as a consequence of the split of the Normal covector*)


(*NormalN[b]\[Equal]Invg[a,b]NormalN[-a]
%/.ApplyRuleWithoutMovingIndices@NormalDownSplit;
%/.ApplyRuleWithoutMovingIndices@RuleMetricDeltaCounterContravariantSplit;
Expand[%];
Series[%,{DeltaCounter,0,1}]
%[[1]]==Normal[%[[2]]]+DeltaCounter^2*higherOrderTensor2indices[b];*)
NormalUpSplit=NormalN[b]==DeltaCounter^2*higherOrderTensor2indices[b]+m[a,b]*NormalNbackround[-a]+DeltaCounter*(m[a,b]*NormalNpert[-a]-NormalNbackround[-a]*Perturbationh[a,b])


RuleCovariantSplitPi=PigT[-a,-b]==PigTbackground[-a,-b]+DeltaCounter*PigTpert[-a,-b]


RuleCovariantSplitPhi=SpatialDerivativeg[-c,-a,-b]==SpatialDerivativegbackground[-c,-a,-b]+DeltaCounter*SpatialDerivativegpert[-c,-a,-b]


CDflat[-a][g[-b,-c]]
%/.ApplyRule@RuleMetricDeltaCounterCovariantSplit


SubstitutePiBackground=PigTbackground[-a,-b]==0
SubstitutePhiBackground=SpatialDerivativegbackground[-c,-a,-b]==0


projector[-a,-b]==g[-a,-b]+NormalN[-a]*NormalN[-b]
%/.ApplyRuleWithoutMovingIndices@RuleMetricDeltaCounterCovariantSplit
%/.ApplyRuleWithoutMovingIndices@NormalDownSplit
Series[%,{DeltaCounter,0,1}]


ProjectorSplitDown=projector[-a,-b]==projectorbackround[-a,-b]+DeltaCounter*projectorpert[-a,-b]+DeltaCounter^2*higherOrderTensor2indices[-a,-b]


Substituteprojectorbackround=projectorbackround[-a,-b]==m[-a,-b]+NormalNbackround[-a]NormalNbackround[-b]


Substituteprojectorpert=projectorpert[-a,-b]==NormalNbackround[-b]*NormalNpert[-a]+NormalNbackround[-a]*NormalNpert[-b]+Perturbationh[-a,-b]


(* projector[-a,b]\[Equal]Invg[c,b]projector[-a,-c]
%/.ApplyRuleWithoutMovingIndices@ProjectorSplitDown;
%/.ApplyRuleWithoutMovingIndices@RuleMetricDeltaCounterContravariantSplit;
Expand[%];
Series[%,{DeltaCounter,0,1}]
%[[1]]==Normal[%[[2]]]+DeltaCounter^2*higherOrderTensor2indices[-a,b];*)
ProjectorDownUpSplit=projector[-a,b]==DeltaCounter^2*higherOrderTensor2indices[-a,b]+m[c,b]*projectorbackround[-a,-c]+DeltaCounter*(-(Perturbationh[c,b]*projectorbackround[-a,-c])+m[c,b]*projectorpert[-a,-c])


(*projector[a,b]\[Equal]Invg[c,a]Invg[d,b]projector[-c,-d]
%/.ApplyRuleWithoutMovingIndices@ProjectorSplitDown;
%/.ApplyRuleWithoutMovingIndices@RuleMetricDeltaCounterContravariantSplit;
Expand[%];
Series[%,{DeltaCounter,0,1}]
%[[1]]==Normal[%[[2]]]+DeltaCounter^2*higherOrderTensor2indices[a,b];*)
ProjectorUpUpSplit=projector[a,b]==DeltaCounter^2*higherOrderTensor2indices[a,b]+m[c,a]*m[d,b]*projectorbackround[-c,-d]+DeltaCounter*(-(m[d,b]*Perturbationh[c,a]*projectorbackround[-c,-d])-m[c,a]*Perturbationh[d,b]*projectorbackround[-c,-d]+m[c,a]*m[d,b]*projectorpert[-c,-d])


(*Summary of the split*)


RuleMetricDeltaCounterCovariantSplit
NormalDownSplit
ProjectorSplitDown
(**)
RuleMetricDeltaCounterContravariantSplit
NormalUpSplit
ProjectorDownUpSplit
ProjectorUpUpSplit


RuleCovariantSplitPi
RuleCovariantSplitPhi


(**)
Substituteprojectorbackround
Substituteprojectorpert
SubstituteNormalbackground
SubstituteNormalpert
SubstitutePiBackground
SubstitutePhiBackground


(*Some extra rules for canonicalisation of the desired index position *)


RuleToRaiseOnlyIndicesOfTheBackroundNormal=m[a,c]*NormalNbackround[-a]==NormalNbackround[c];
RuleToCanonicaliseIndexPositionPerturbationhDownUp=Perturbationh[-a,b]==m[c,b]*Perturbationh[-a,-c];
RuleToCanonicaliseIndexPositionPerturbationhUpUp=Perturbationh[a,b]==m[a,d]*m[b,c]*Perturbationh[-d,-c];
RulesToCanonicaliseIndices={RuleToRaiseOnlyIndicesOfTheBackroundNormal,RuleToCanonicaliseIndexPositionPerturbationhDownUp,RuleToCanonicaliseIndexPositionPerturbationhUpUp}
ApplyRulesToCanonicaliseIndices=Flatten[ApplyRuleWithoutMovingIndices/@
RulesToCanonicaliseIndices];


NormalN[a]SpatialDerivativeg[-a,-b,-c]==0
%/.ApplyRuleWithoutMovingIndices@NormalUpSplit;
%/.ApplyRuleWithoutMovingIndices@RuleCovariantSplitPhi;
%/.ApplyRuleWithoutMovingIndices@SubstitutePhiBackground;
ExpandAll[%];
Series[%,{DeltaCounter,0,1}]
%/.ApplyRuleWithoutMovingIndices@RuleToRaiseOnlyIndicesOfTheBackroundNormal;
Normal[(DeltaCounter^(-1))*%];
RulePhiPertIsSpatialInTheFirstIndex=NormalNbackround[a]*SpatialDerivativegpert[-a,-b,-c]==0


SeriesData[DeltaCounter, 0, {m[d, a] NormalNbackround[-d] SpatialDerivativegpert[-a, -b, -c]}, 1, 2, 1]==0


(*RulePhiPertIsSpatialInTheFirstIndex
CDflat[-f]@%[[1]]==CDflat[-f]@%[[2]]
%/.ApplyRule@SubstituteNormalbackground;
%/.ApplyRuleDerivativeOfBasisLLbarS1S2;
ContractMetric[%];
%/.ApplyRule@LtoNandR;
%/.ApplyRule@LbartoNandR;
ToCanonical[%];*)
RulePhiPertIsSpatialInTheFirstIndexDer=NormalNbackround[a]*CDflat[-f][SpatialDerivativegpert[-a,-b,-c]]==0


NormalNbackround[-a]NormalNbackround[a];
%/.ApplyRule@SubstituteNormalbackground;
ContractMetric[%];
RuleNormalNbackroundIsNormalised=NormalNbackround[-a]*NormalNbackround[a]==-1


(****** decomposition of the perturbation equations ***************)


DefTensor[SpatialDerivativegpertRadial[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[CapitalPhi]\), \(\[Breve]\)], \(R\)]\)"]
DefTensor[SpatialDerivativegpertS1[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[CapitalPhi]\), \(\[Breve]\)], \(S1\)]\)"]
DefTensor[SpatialDerivativegpertS2[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[CapitalPhi]\), \(\[Breve]\)], \(S2\)]\)"]
DefTensor[SpaceReductionConstraintpert[-a,-b,-c],M4,PrintAs->"\!\(\*OverscriptBox[\(\[ScriptCapitalC]\), \(\[Breve]\)]\)"]
DefTensor[SpaceReductionConstraintbackground[-a,-b,-c],M4,PrintAs->"\!\(\*OverscriptBox[\(\[ScriptCapitalC]\), \(\[FilledSmallCircle]\)]\)"]
DefTensor[SpaceReductionConstraintpertRadial[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[ScriptCapitalC]\), \(\[Breve]\)], \(R\)]\)"]
DefTensor[SpaceReductionConstraintpertS1[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[ScriptCapitalC]\), \(\[Breve]\)], \(S1\)]\)"]
DefTensor[SpaceReductionConstraintpertS2[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[ScriptCapitalC]\), \(\[Breve]\)], \(S2\)]\)"]


SpatialDerivativegpertS1S2Def={SpatialDerivativegpert[-a,-c,-d]*Svec1[a]==SpatialDerivativegpertS1[-c,-d],SpatialDerivativegpert[-a,-c,-d]*Svec2[a]==SpatialDerivativegpertS2[-c,-d]}
ApplyRuleSpatialDerivativegpertS1S2Def=Flatten[ApplyRuleWithoutMovingIndices/@SpatialDerivativegpertS1S2Def];
SpatialDerivativegpertSpToRS1S2={ContractBasis[SpatialDerivativegpert[-a,-c,-d]*Basis[{1,-Sp},a]]==SpatialDerivativegpertRadial[-c,-d],SpatialDerivativegpert[{2,-Sp},-c,-d]==r[]*SpatialDerivativegpertS1[-c,-d],SpatialDerivativegpert[{3,-Sp},-c,-d]==r[]*Sin[\[Theta][]]*SpatialDerivativegpertS2[-c,-d]}
ApplyRuleSpatialDerivativegpertSpToRS1S2=Flatten[ApplyRuleWithoutMovingIndices/@SpatialDerivativegpertSpToRS1S2];


SpaceReductionConstraint[-a,-b,-c]==-SpatialDerivativeg[-a,-b,-c]+projector[-a,f]*CDflat[-f][g[-b,-c]]


SpaceReductionConstraintSplit=SpaceReductionConstraint[-a,-b,-c]==SpaceReductionConstraintbackground[-a,-b,-c]+DeltaCounter*SpaceReductionConstraintpert[-a,-b,-c]
SubstituteSpaceReductionConstraintbackground=SpaceReductionConstraintbackground[-a,-b,-c]==0


SpaceReductionConstraintpertS1S2Def={SpaceReductionConstraintpert[-a,-c,-d]*Svec1[a]==SpaceReductionConstraintpertS1[-c,-d],SpaceReductionConstraintpert[-a,-c,-d]*Svec2[a]==SpaceReductionConstraintpertS2[-c,-d]}
ApplyRuleSpaceReductionConstraintpertS1S2Def=Flatten[ApplyRuleWithoutMovingIndices/@SpaceReductionConstraintpertS1S2Def];
SpaceReductionConstraintpertSpToRS1S2={SpaceReductionConstraintpert[{1,-Sp},-c,-d]==SpaceReductionConstraintpertRadial[-c,-d],SpaceReductionConstraintpert[{2,-Sp},-c,-d]==r[]*SpaceReductionConstraintpertS1[-c,-d],SpaceReductionConstraintpert[{3,-Sp},-c,-d]==r[]*Sin[\[Theta][]]*SpaceReductionConstraintpertS2[-c,-d]}
ApplyRuleSpaceReductionConstraintpertSpToRS1S2=Flatten[ApplyRuleWithoutMovingIndices/@SpaceReductionConstraintpertSpToRS1S2];


SpaceReductionConstraint[{1, -Sp}, -b, -c] == -SpatialDerivativeg[{1, -Sp}, -b, -c] + CDflat[{1, -Sp}][g[-b, -c]];
SeparateBasis[AIndex][%];
%/.ApplyRule@RuleCovariantSplitPhi;
%/.ApplyRule@SubstitutePhiBackground;
%/.ApplyRule@RuleMetricDeltaCounterCovariantSplit;
%/.ApplyRule@SpaceReductionConstraintSplit;
%/.ApplyRule@SubstituteSpaceReductionConstraintbackground;
ContractBasis[DeltaCounter^(-1)*%];
%/.ApplyRuleSpaceReductionConstraintpertSpToRS1S2;
%/.ApplyRuleSpatialDerivativegpertSpToRS1S2;
SubstituteSpaceReductionConstraintRadialpert=SpaceReductionConstraintpertRadial[-b,-c]==-SpatialDerivativegpertRadial[-b,-c]+CDflat[{1,-Sp}][Perturbationh[-b,-c]]


SpaceReductionConstraint[{2, -Sp}, -b, -c] == -SpatialDerivativeg[{2, -Sp}, -b, -c] + CDflat[{2, -Sp}][g[-b, -c]];
SeparateBasis[AIndex][%];
%/.ApplyRuleBasisSpToS1S2;
%/.ApplyRule@RuleCovariantSplitPhi;
%/.ApplyRule@SubstitutePhiBackground;
%/.ApplyRule@RuleMetricDeltaCounterCovariantSplit;
%/.ApplyRule@SpaceReductionConstraintSplit;
%/.ApplyRule@SubstituteSpaceReductionConstraintbackground;
ContractBasis[(r[]*DeltaCounter)^(-1)*%];
%/.ApplyRuleSpaceReductionConstraintpertS1S2Def;
%/.ApplyRuleSpatialDerivativegpertS1S2Def;
SubstituteSpaceReductionConstraintS1pert=SpaceReductionConstraintpertS1[-b,-c]==-SpatialDerivativegpertS1[-b,-c]+Svec1[a]*CDflat[-a][Perturbationh[-b,-c]]


SpaceReductionConstraint[{3, -Sp}, -b, -c] == -SpatialDerivativeg[{3, -Sp}, -b, -c] + CDflat[{3, -Sp}][g[-b, -c]];
SeparateBasis[AIndex][%];
%/.ApplyRuleBasisSpToS1S2;
%/.ApplyRule@RuleCovariantSplitPhi;
%/.ApplyRule@SubstitutePhiBackground;
%/.ApplyRule@RuleMetricDeltaCounterCovariantSplit;
%/.ApplyRule@SpaceReductionConstraintSplit;
%/.ApplyRule@SubstituteSpaceReductionConstraintbackground;
ContractBasis[(r[]*Sin[\[Theta][]]*DeltaCounter)^(-1)*%];
%/.ApplyRuleSpaceReductionConstraintpertS1S2Def;
%/.ApplyRuleSpatialDerivativegpertS1S2Def;
SubstituteSpaceReductionConstraintS2pert=SpaceReductionConstraintpertS2[-b,-c]==-SpatialDerivativegpertS2[-b,-c]+Svec2[a]*CDflat[-a][Perturbationh[-b,-c]]


(*SubstituteSpaceReductionConstraintRadialpert;
Flatten[Solve[%,SpatialDerivativegpertRadial[-b, -c]]];
%[[1]][[1]]==%[[1]][[2]];*)
SubstituteReductionVariableWithConstraintR=SpatialDerivativegpertRadial[-b,-c]==-SpaceReductionConstraintpertRadial[-b,-c]+CDflat[{1,-Sp}][Perturbationh[-b,-c]]


SpatialDerivativegpertRadial[-b, -c]==-SpaceReductionConstraintpertRadial[-b, -c]+CDflat[{1, -Sp}][Perturbationh[-b, -c]]


(*SubstituteSpaceReductionConstraintS1pert;
Flatten[Solve[%,SpatialDerivativegpertS1[-b, -c]]];
%[[1]][[1]]==%[[1]][[2]];*)
SubstituteReductionVariableWithConstraintS1=SpatialDerivativegpertS1[-b,-c]==-SpaceReductionConstraintpertS1[-b,-c]+Svec1[a]*CDflat[-a][Perturbationh[-b,-c]]


SpatialDerivativegpertS1[-b, -c]==-SpaceReductionConstraintpertS1[-b, -c]+Svec1[a] (CDflat[-a][Perturbationh[-b, -c]])


(*SubstituteSpaceReductionConstraintS2pert;
Flatten[Solve[%,SpatialDerivativegpertS2[-b, -c]]];
%[[1]][[1]]==%[[1]][[2]];*)
SubstituteReductionVariableWithConstraintS2=SpatialDerivativegpertS2[-b,-c]==-SpaceReductionConstraintpertS2[-b,-c]+Svec2[a]*CDflat[-a][Perturbationh[-b,-c]]


SpatialDerivativegpertS2[-b, -c]==-SpaceReductionConstraintpertS2[-b, -c]+Svec2[a] (CDflat[-a][Perturbationh[-b, -c]])


SubstituteReductionVariableWithConstraintAllComponents={SubstituteReductionVariableWithConstraintR,SubstituteReductionVariableWithConstraintS1,SubstituteReductionVariableWithConstraintS2}


{SpatialDerivativegpertRadial[-b, -c]==-SpaceReductionConstraintpertRadial[-b, -c]+CDflat[{1, -Sp}][Perturbationh[-b, -c]],SpatialDerivativegpertS1[-b, -c]==-SpaceReductionConstraintpertS1[-b, -c]+Svec1[a] (CDflat[-a][Perturbationh[-b, -c]]),SpatialDerivativegpertS2[-b, -c]==-SpaceReductionConstraintpertS2[-b, -c]+Svec2[a] (CDflat[-a][Perturbationh[-b, -c]])}


ApplyRuleSubstituteReductionVariableWithConstraintAllComponents=Flatten[ApplyRule/@SubstituteReductionVariableWithConstraintAllComponents];


NormalNAndRadialCovectorAndS1S2AreOrthogonal={NormalNbackround[a]*Svec1[-a] == 0,
NormalNbackround[a]*Scovec1[-a] == 0,
NormalNbackround[a]*Svec2[-a] == 0,
NormalNbackround[a]*Scovec2[-a] == 0,
RadialCovector[a]*Svec1[-a] == 0,
RadialCovector[a]*Scovec1[-a] == 0,
RadialCovector[a]*Svec2[-a] == 0,
RadialCovector[a]*Scovec2[-a] == 0}
ApplyRuleNormalNAndRadialCovectorAndS1S2AreOrthogonal=Flatten[ApplyRule/@NormalNAndRadialCovectorAndS1S2AreOrthogonal];


ReversedRuleAngularDerivativesSvec1CarryAoneOverRfactor=Module[{a},CDflat[{2,-Sp}][expr_]:> r[]*Svec1[a]*CDflat[-a][expr]]
ReversedRuleAngularDerivativesScovec1CarryAoneOverRfactor=Module[{a},CDflat[{2,-Sp}][expr_]:> r[]*Scovec1[a]*CDflat[-a][expr]]
ReversedRuleAngularDerivativesSvec2CarryAoneOverRfactor=Module[{a},CDflat[{3,-Sp}][expr_]:> r[]*Sin[\[Theta][]]*Svec2[a]*CDflat[-a][expr]]
ReversedRuleAngularDerivativesScovec2CarryAoneOverRfactor=Module[{a},CDflat[{3,-Sp}][expr_]:> r[]*Sin[\[Theta][]]*Scovec2[a]*CDflat[-a][expr]]


RulePhiPertIsSpatialInTheFirstIndex
%/.ApplyRule@SubstituteNormalbackground;
%/.ApplyRuleFlatNullInTermsOfBasisSp;
ContractBasis[-%];
RulePhiPertIsSpatialInTheFirstIndexSp=SpatialDerivativegpert[{0,-Sp},-b,-c]==0


RadialCovector[-a]RadialCovector[a];
%/.ApplyRule@SubstituteRadialCovectorbackground;
ContractMetric[%];
RuleRadialCovectorbackroundIsNormalised=RadialCovector[-a]RadialCovector[a]==1


NormalNbackround[a]RadialCovector[-a];
%/.ApplyRule@SubstituteNormalbackground;
%/.ApplyRule@SubstituteRadialCovectorbackground;
ContractMetric[%];
RuleRadialCovectorAndNormalbackroundArePerpendicular=NormalNbackround[a]RadialCovector[-a]==0


SpatialDerivativegpert[-a,-c,-d];
SeparateBasis[Sp][%,-a];
TraceBasisDummy[%];
%/.ApplyRule@RulePhiPertIsSpatialInTheFirstIndexSp;
%/.ApplyRuleSpatialDerivativegpertSpToRS1S2;
%/.ApplyRuleBasisSpToFlatNull;
%/.ApplyRuleBasisSpToS1S2;
%/.ApplyRule@LtoNandR;
%/.ApplyRule@LbartoNandR;
DecompSpatialDerivativegpertToLS1S2=SpatialDerivativegpert[-a,-c,-d]==((L[-a]-Lbar[-a])*SpatialDerivativegpertRadial[-c,-d])/2+Scovec1[-a]*SpatialDerivativegpertS1[-c,-d]+Scovec2[-a]*SpatialDerivativegpertS2[-c,-d]


DecompSpatialDerivativegpertToLS1S2;
%/.ApplyRule@LtoNandR;
%/.ApplyRule@LbartoNandR;
DecompSpatialDerivativegpertToRS1S2=SpatialDerivativegpert[-a,-c,-d]==RadialCovector[-a]*SpatialDerivativegpertRadial[-c,-d]+Scovec1[-a]*SpatialDerivativegpertS1[-c,-d]+Scovec2[-a]*SpatialDerivativegpertS2[-c,-d]


NormalbackgroundDerivativesToRedIndex0=Module[{a},NormalNbackround[a]*CDflat[-a][expr_]:>Evaluate[NormalNbackround[a]*CDflat[-a][expr]//.ApplyRule@SubstituteNormalbackground//.ApplyRuleFlatNullInTermsOfBasisSp//ContractBasis]]
RadialDerivativesDerivativesToRedIndex1=Module[{a},RadialCovector[a]*CDflat[-a][expr_]:>Evaluate[RadialCovector[a]*CDflat[-a][expr]//.ApplyRule@SubstituteRadialCovectorbackground//.ApplyRuleFlatNullInTermsOfBasisSp//ContractBasis]]


(*m[a,b]
SeparateBasis[Sp][%];
TraceBasisDummy[%];
%/.ApplyRuleBasisSpToFlatNull;
%/.ApplyRuleBasisSpToS1S2;
ToValues[%];
ToCanonical[%]
%/.ApplyRule@LtoNandR;
%/.ApplyRule@LbartoNandR;
ToCanonical[%]
m[a,b]\[Equal]%;*)
MinkowskiMetricUpUpToNRS1S2=m[a,b]==-(NormalNbackround[a]*NormalNbackround[b])+RadialCovector[a]*RadialCovector[b]+Svec1[a]*Svec1[b]+Svec2[a]*Svec2[b]


m[a,b]CDflat[-a]@\[Phi]
%/.ApplyRule@MinkowskiMetricUpUpToNRS1S2;
ContractMetric[%]


ExpandGradientIndexUpToDerivativesNRS1S2=Module[{a},m[a,b]CDflat[-a]@expr_:>Evaluate[m[a,b]CDflat[-a]@expr//.ApplyRule@MinkowskiMetricUpUpToNRS1S2//ContractMetric]]


m[f,d]CDflat[-d]@\[Phi]
%/.ApplyRule@ExpandGradientIndexUpToDerivativesNRS1S2


(********** change of variables and rescaling *********)


DefTensor[delLphi[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SuperscriptBox[\(\[Xi]\), \(+\)]\)"]
DefTensor[delLbarphi[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SuperscriptBox[\(\[Xi]\), \(-\)]\)"]

DefTensor[RescaledDelLphi[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)"]
DefTensor[RescaledDelLbarphi[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)"]
DefTensor[RescaledPhiS1[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[\(\[Psi]\), \(S1\)]\)"]
DefTensor[RescaledPhiS2[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[\(\[Psi]\), \(S2\)]\)"]


DefinitionOfCharacteristicVariables={delLphi[-a,-b]==SpatialDerivativegpertRadial[-a,-b]+PigTpert[-a,-b],
delLbarphi[-a,-b]==-SpatialDerivativegpertRadial[-a,-b]+PigTpert[-a,-b]}
ExpressCharacteristicVariablesInNormalVariables={DefinitionOfCharacteristicVariables[[1]][[1]]==DefinitionOfCharacteristicVariables[[1]][[2]],
DefinitionOfCharacteristicVariables[[2]][[1]]==DefinitionOfCharacteristicVariables[[2]][[2]]};
ApplyRuleExpressCharacteristicVariablesInNormalVariables=Flatten[ApplyRule/@ExpressCharacteristicVariablesInNormalVariables];


UsualVariablesInCharacteristicVariables=Flatten[Solve[DefinitionOfCharacteristicVariables,{PigTpert[-a,-b],SpatialDerivativegpertRadial[-a,-b]}]];
ExpressVariablesInCharacteristicVariables={UsualVariablesInCharacteristicVariables[[1]][[1]]==UsualVariablesInCharacteristicVariables[[1]][[2]],
UsualVariablesInCharacteristicVariables[[2]][[1]]==UsualVariablesInCharacteristicVariables[[2]][[2]]}
ApplyRuleNormalVariablesToCharacteristicVariables=Flatten[ApplyRule/@ExpressVariablesInCharacteristicVariables];


RescaledCharacteristicVariables={delLphi[-a,-b]==(1/r[]^2)*RescaledDelLphi[-a,-b],
delLbarphi[-a,-b]==(1/r[])*RescaledDelLbarphi[-a,-b],
SpatialDerivativegpertS1[-a,-b]==(1/r[]^2)*RescaledPhiS1[-a,-b],
SpatialDerivativegpertS2[-a,-b]==(1/r[]^2)*RescaledPhiS2[-a,-b],
Perturbationh[-a,-b]==(1/r[])*PerturbationH[-a,-b]}
ApplyRuleRescaledCharacteristicVariables=Flatten[ApplyRule/@RescaledCharacteristicVariables];


GenericConstraintAdditionToRescaledGenericConstraintAddition=GenericConstraintAddition[-a,-b]==RescaledGenericConstraintAddition[-a,-b]/r[]^2;


GaugeSourceFunctionDecayingSufficientlyFast=GaugeSourceFunction[-a]==higherOrderTensor1index[-a](1/r[]^3);
GaugeSourceFunctionDecayingEvenFaster=GaugeSourceFunction[-a]==higherOrderTensor1index[-a]/r[]^4;


HcontractedWithLLbarS1S2WithoutExpandingDerivatives={L[a]L[b]*PerturbationH[-a,-b]==HLL,
L[a]Lbar[b]*PerturbationH[-a,-b]==HLLbar,
L[a]Svec1[b]*PerturbationH[-a,-b]==HLS1,
L[a]Svec2[b]*PerturbationH[-a,-b]==HLS2,
(**)
Lbar[a]Lbar[b]*PerturbationH[-a,-b]==HLbarLbar,
Lbar[a]Svec1[b]*PerturbationH[-a,-b]==HLbarS1,
Lbar[a]Svec2[b]*PerturbationH[-a,-b]==HLbarS2,
(**)
Svec1[a]Svec1[b]*PerturbationH[-a,-b]==HS1S1,
Svec1[a]Svec2[b]*PerturbationH[-a,-b]==HS1S2,
(**)
Svec2[a]Svec2[b]*PerturbationH[-a,-b]==HS2S2}
ApplyRuleHcontractedWithLLbarS1S2WithoutExpandingDerivatives=Flatten[ApplyRule/@HcontractedWithLLbarS1S2WithoutExpandingDerivatives];


SigmaPluscontractedWithLLbarS1S2WithoutExpandingDerivatives={L[a]L[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiLL,
L[a]Lbar[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiLLbar,
L[a]Svec1[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiLS1,
L[a]Svec2[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiLS2,
(**)
Lbar[a]Lbar[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiLbarLbar,
Lbar[a]Svec1[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiLbarS1,
Lbar[a]Svec2[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiLbarS2,
(**)
Svec1[a]Svec1[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiS1S1,
Svec1[a]Svec2[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiS1S2,
(**)
Svec2[a]Svec2[b]*RescaledDelLphi[-a,-b]==RescaledDelLphiS2S2}
ApplyRuleSigmaPluscontractedWithLLbarS1S2WithoutExpandingDerivatives=Flatten[ApplyRule/@SigmaPluscontractedWithLLbarS1S2WithoutExpandingDerivatives];


SigmaMinuscontractedWithLLbarS1S2WithoutExpandingDerivatives={L[a]L[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiLL,
L[a]Lbar[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiLLbar,
L[a]Svec1[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiLS1,
L[a]Svec2[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiLS2,
(**)
Lbar[a]Lbar[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiLbarLbar,
Lbar[a]Svec1[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiLbarS1,
Lbar[a]Svec2[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiLbarS2,
(**)
Svec1[a]Svec1[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiS1S1,
Svec1[a]Svec2[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiS1S2,
(**)
Svec2[a]Svec2[b]*RescaledDelLbarphi[-a,-b]==RescaledDelLbarphiS2S2}
ApplyRuleSigmaMinuscontractedWithLLbarS1S2WithoutExpandingDerivatives=Flatten[ApplyRule/@SigmaMinuscontractedWithLLbarS1S2WithoutExpandingDerivatives];


(*m[a,b]RescaledDelLbarphi[-c,-a];
ContractMetric[%];
m[a,b]RescaledDelLbarphi[-c,-a]\[Equal]%;
Reverse[%];*)
CanonicaliseIndicesRescaledDelLbarphiDownUp=RescaledDelLbarphi[-c,b]==m[a,b]*RescaledDelLbarphi[-c,-a]
(**)
(*m[a,b]m[c,d]RescaledDelLbarphi[-a,-c];
ContractMetric[%];
m[a,b]m[c,d]RescaledDelLbarphi[-a,-c]\[Equal]%;
Reverse[%]*)
CanonicaliseIndicesRescaledDelLbarphiUpUp=RescaledDelLbarphi[b,d]==m[a,b]*m[c,d]*RescaledDelLbarphi[-a,-c]


(************)
RuleShortcutBasisAndOneDerivativeOfHOrange=ContractBasis[Basis[{0,-Li},a]RuleShortcutBasisAndOneDerivativeOfH];
ApplyRuleRuleShortcutBasisAndOneDerivativeOfHOrangeFlatten=Flatten[ApplyRule/@RuleShortcutBasisAndOneDerivativeOfHOrange];


DefTensor[RescaledSpaceReductionConstraintpertRadial[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[DoubleStruckCapitalC]\), \(\[Breve]\)], \(R\)]\)"]
DefTensor[RescaledSpaceReductionConstraintpertS1[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[DoubleStruckCapitalC]\), \(\[Breve]\)], \(S1\)]\)"]
DefTensor[RescaledSpaceReductionConstraintpertS2[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[DoubleStruckCapitalC]\), \(\[Breve]\)], \(S2\)]\)"]


ReductionConstraintToRescaledReductionConstraint={SpaceReductionConstraintpertRadial[-a,-b]==(1/r[]^2)*RescaledSpaceReductionConstraintpertRadial[-a,-b],SpaceReductionConstraintpertS1[-a,-b]==(1/r[]^2)*RescaledSpaceReductionConstraintpertS1[-a,-b],SpaceReductionConstraintpertS2[-a,-b]==(1/r[]^2)*RescaledSpaceReductionConstraintpertS2[-a,-b]}
ApplyRuleReductionConstraintToRescaledReductionConstraint=Flatten[ApplyRule/@ReductionConstraintToRescaledReductionConstraint];


ParametrisedConstraintAddition;
%/.ApplyRule@GaugeSourceFunctionDecayingSufficientlyFast;
%/.ApplyRule@RulexCobaCovariantSplitShortcutFinal;
%/.ApplyRule@RulexCobaContravariantSplitShortcutFinal;
Series[%,{r[],Infinity,2}];
Normal[%];
ParametrisedConstraintAdditionEffectiveExpression=GenericConstraintAddition[-a,-b]==((\[Beta]*m[c,d]*m[f,h]*CDflat[-a][PerturbationH[-c,-d]]*CDflat[-b][PerturbationH[-f,-h]])/8-(W0*\[Alpha]*L[c]*Lbar[-a]*Lbar[-b]*m[d,f]*CDflat[-c][PerturbationH[-d,-f]])/8-(W3*\[Alpha]*Lbar[c]*m[d,f]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][PerturbationH[-d,-f]])/4-(W3*\[Alpha]*Lbar[c]*m[d,f]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][PerturbationH[-d,-f]])/4+(W1*\[Alpha]*Lbar[-b]*m[d,f]*Scovec1[-a]*Svec1[c]*CDflat[-c][PerturbationH[-d,-f]])/4+(W1*\[Alpha]*Lbar[-a]*m[d,f]*Scovec1[-b]*Svec1[c]*CDflat[-c][PerturbationH[-d,-f]])/4+(W2*\[Alpha]*Lbar[-b]*m[d,f]*Scovec2[-a]*Svec2[c]*CDflat[-c][PerturbationH[-d,-f]])/4+(W2*\[Alpha]*Lbar[-a]*m[d,f]*Scovec2[-b]*Svec2[c]*CDflat[-c][PerturbationH[-d,-f]])/4-(\[Beta]*m[c,d]*m[f,h]*CDflat[-b][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-a,-c]])/4-(\[Beta]*m[c,d]*m[f,h]*CDflat[-a][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-b,-c]])/4+(\[Beta]*m[c,d]*m[f,h]*CDflat[-a][PerturbationH[-b,-c]]*CDflat[-d][PerturbationH[-f,-h]])/4+(\[Beta]*m[c,d]*m[f,h]*CDflat[-b][PerturbationH[-a,-c]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k4*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k6*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k6*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k4*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k0*\[Alpha]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*m[f,h]*m[i,j]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/16-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[f,h]*m[i,j]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/16+(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8+(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8-(k1*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec1[-a]*Svec1[d]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8-(k1*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec1[-b]*Svec1[d]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec1[f]*Svec1[h]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/16-(k2*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec2[-a]*Svec2[d]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8-(k2*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec2[-b]*Svec2[d]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec2[f]*Svec2[h]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/16+(W0*\[Alpha]*L[c]*Lbar[-a]*Lbar[-b]*m[d,f]*CDflat[-f][PerturbationH[-c,-d]])/4+(W3*\[Alpha]*Lbar[c]*m[d,f]*Scovec1[-a]*Scovec1[-b]*CDflat[-f][PerturbationH[-c,-d]])/2+(W3*\[Alpha]*Lbar[c]*m[d,f]*Scovec2[-a]*Scovec2[-b]*CDflat[-f][PerturbationH[-c,-d]])/2-(W1*\[Alpha]*Lbar[-b]*m[d,f]*Scovec1[-a]*Svec1[c]*CDflat[-f][PerturbationH[-c,-d]])/2-(W1*\[Alpha]*Lbar[-a]*m[d,f]*Scovec1[-b]*Svec1[c]*CDflat[-f][PerturbationH[-c,-d]])/2-(W2*\[Alpha]*Lbar[-b]*m[d,f]*Scovec2[-a]*Svec2[c]*CDflat[-f][PerturbationH[-c,-d]])/2-(W2*\[Alpha]*Lbar[-a]*m[d,f]*Scovec2[-b]*Svec2[c]*CDflat[-f][PerturbationH[-c,-d]])/2-(k7*\[Alpha]*L[-b]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec1[-a]*Svec1[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-f][PerturbationH[-d,-h]])/8-(k7*\[Alpha]*L[-a]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec1[-b]*Svec1[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-f][PerturbationH[-d,-h]])/8-(k8*\[Alpha]*L[-b]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec2[-a]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-f][PerturbationH[-d,-h]])/8-(k8*\[Alpha]*L[-a]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec2[-b]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-f][PerturbationH[-d,-h]])/8+(\[Beta]*m[c,d]*m[f,h]*CDflat[-d][PerturbationH[-a,-c]]*CDflat[-h][PerturbationH[-b,-f]])/2+(k5*\[Alpha]*L[-b]*L[c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/16+(k5*\[Alpha]*L[-a]*L[c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/16-(k0*\[Alpha]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*m[f,h]*m[i,j]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[f,h]*m[i,j]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4-(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec1[-a]*Scovec1[-b]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4-(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec2[-a]*Scovec2[-b]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(k1*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec1[-a]*Svec1[d]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(k1*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec1[-b]*Svec1[d]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(k2*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec2[-a]*Svec2[d]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(k2*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec2[-b]*Svec2[d]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4-(\[Beta]*m[c,d]*m[f,h]*CDflat[-a][PerturbationH[-b,-c]]*CDflat[-h][PerturbationH[-d,-f]])/2-(\[Beta]*m[c,d]*m[f,h]*CDflat[-b][PerturbationH[-a,-c]]*CDflat[-h][PerturbationH[-d,-f]])/2+(k9*\[Alpha]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/16+(\[Lambda]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/32-(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4-(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4+(k1*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec1[-a]*Svec1[d]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4+(k1*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec1[-b]*Svec1[d]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4+(k2*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec2[-a]*Svec2[d]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4+(k2*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec2[-b]*Svec2[d]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec1[f]*Svec1[h]*CDflat[-d][PerturbationH[-c,-f]]*CDflat[-h][PerturbationH[-i,-j]])/8-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec2[f]*Svec2[h]*CDflat[-d][PerturbationH[-c,-f]]*CDflat[-h][PerturbationH[-i,-j]])/8+(\[Lambda]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-f][PerturbationH[-c,-d]]*CDflat[-h][PerturbationH[-i,-j]])/16-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec1[f]*Svec1[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/8-(k4*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/2-(k6*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/2-(k6*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/2-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec2[f]*Svec2[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/8-(k4*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/2+(k7*\[Alpha]*L[-b]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec1[-a]*Svec1[h]*CDflat[-f][PerturbationH[-d,-h]]*CDflat[-j][PerturbationH[-c,-i]])/4+(k7*\[Alpha]*L[-a]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec1[-b]*Svec1[h]*CDflat[-f][PerturbationH[-d,-h]]*CDflat[-j][PerturbationH[-c,-i]])/4+(k8*\[Alpha]*L[-b]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec2[-a]*Svec2[h]*CDflat[-f][PerturbationH[-d,-h]]*CDflat[-j][PerturbationH[-c,-i]])/4+(k8*\[Alpha]*L[-a]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec2[-b]*Svec2[h]*CDflat[-f][PerturbationH[-d,-h]]*CDflat[-j][PerturbationH[-c,-i]])/4-(k9*\[Alpha]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-h][PerturbationH[-d,-f]]*CDflat[-j][PerturbationH[-c,-i]])/8-(\[Lambda]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-h][PerturbationH[-d,-f]]*CDflat[-j][PerturbationH[-c,-i]])/16-(k5*\[Alpha]*L[-b]*L[c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/8-(k5*\[Alpha]*L[-a]*L[c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/8+(k0*\[Alpha]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*m[f,h]*m[i,j]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/4-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[f,h]*m[i,j]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/4+(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec1[-a]*Scovec1[-b]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2+(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec2[-a]*Scovec2[-b]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2-(k1*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec1[-a]*Svec1[d]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2-(k1*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec1[-b]*Svec1[d]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2-(k2*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec2[-a]*Svec2[d]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2-(k2*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec2[-b]*Svec2[d]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec1[f]*Svec1[h]*CDflat[-d][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-h,-i]])/4+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec2[f]*Svec2[h]*CDflat[-d][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-h,-i]])/4-(\[Lambda]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-f][PerturbationH[-c,-d]]*CDflat[-j][PerturbationH[-h,-i]])/8)/r[]^2;


(*GenericConstraintAdditionToRescaledGenericConstraintAddition
Flatten[Solve[%,{RescaledGenericConstraintAddition[-a,-b]}]];
%[[1]][[1]]\[Equal]%[[1]][[2]]
%/.ApplyRuleWithoutMovingIndices@ParametrisedConstraintAdditionEffectiveExpression;
Expand[%];*)
ParametrisedConstraintAdditionEffectiveExpressionRescaled=RescaledGenericConstraintAddition[-a,-b]==(\[Beta]*m[c,d]*m[f,h]*CDflat[-a][PerturbationH[-c,-d]]*CDflat[-b][PerturbationH[-f,-h]])/8-(W0*\[Alpha]*L[c]*Lbar[-a]*Lbar[-b]*m[d,f]*CDflat[-c][PerturbationH[-d,-f]])/8-(W3*\[Alpha]*Lbar[c]*m[d,f]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][PerturbationH[-d,-f]])/4-(W3*\[Alpha]*Lbar[c]*m[d,f]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][PerturbationH[-d,-f]])/4+(W1*\[Alpha]*Lbar[-b]*m[d,f]*Scovec1[-a]*Svec1[c]*CDflat[-c][PerturbationH[-d,-f]])/4+(W1*\[Alpha]*Lbar[-a]*m[d,f]*Scovec1[-b]*Svec1[c]*CDflat[-c][PerturbationH[-d,-f]])/4+(W2*\[Alpha]*Lbar[-b]*m[d,f]*Scovec2[-a]*Svec2[c]*CDflat[-c][PerturbationH[-d,-f]])/4+(W2*\[Alpha]*Lbar[-a]*m[d,f]*Scovec2[-b]*Svec2[c]*CDflat[-c][PerturbationH[-d,-f]])/4-(\[Beta]*m[c,d]*m[f,h]*CDflat[-b][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-a,-c]])/4-(\[Beta]*m[c,d]*m[f,h]*CDflat[-a][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-b,-c]])/4+(\[Beta]*m[c,d]*m[f,h]*CDflat[-a][PerturbationH[-b,-c]]*CDflat[-d][PerturbationH[-f,-h]])/4+(\[Beta]*m[c,d]*m[f,h]*CDflat[-b][PerturbationH[-a,-c]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k4*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k6*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k6*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k4*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-d][PerturbationH[-f,-h]])/4+(k0*\[Alpha]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*m[f,h]*m[i,j]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/16-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[f,h]*m[i,j]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/16+(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8+(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8-(k1*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec1[-a]*Svec1[d]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8-(k1*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec1[-b]*Svec1[d]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec1[f]*Svec1[h]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/16-(k2*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec2[-a]*Svec2[d]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8-(k2*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec2[-b]*Svec2[d]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/8+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec2[f]*Svec2[h]*CDflat[-c][PerturbationH[-f,-h]]*CDflat[-d][PerturbationH[-i,-j]])/16+(W0*\[Alpha]*L[c]*Lbar[-a]*Lbar[-b]*m[d,f]*CDflat[-f][PerturbationH[-c,-d]])/4+(W3*\[Alpha]*Lbar[c]*m[d,f]*Scovec1[-a]*Scovec1[-b]*CDflat[-f][PerturbationH[-c,-d]])/2+(W3*\[Alpha]*Lbar[c]*m[d,f]*Scovec2[-a]*Scovec2[-b]*CDflat[-f][PerturbationH[-c,-d]])/2-(W1*\[Alpha]*Lbar[-b]*m[d,f]*Scovec1[-a]*Svec1[c]*CDflat[-f][PerturbationH[-c,-d]])/2-(W1*\[Alpha]*Lbar[-a]*m[d,f]*Scovec1[-b]*Svec1[c]*CDflat[-f][PerturbationH[-c,-d]])/2-(W2*\[Alpha]*Lbar[-b]*m[d,f]*Scovec2[-a]*Svec2[c]*CDflat[-f][PerturbationH[-c,-d]])/2-(W2*\[Alpha]*Lbar[-a]*m[d,f]*Scovec2[-b]*Svec2[c]*CDflat[-f][PerturbationH[-c,-d]])/2-(k7*\[Alpha]*L[-b]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec1[-a]*Svec1[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-f][PerturbationH[-d,-h]])/8-(k7*\[Alpha]*L[-a]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec1[-b]*Svec1[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-f][PerturbationH[-d,-h]])/8-(k8*\[Alpha]*L[-b]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec2[-a]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-f][PerturbationH[-d,-h]])/8-(k8*\[Alpha]*L[-a]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec2[-b]*Svec2[h]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-f][PerturbationH[-d,-h]])/8+(\[Beta]*m[c,d]*m[f,h]*CDflat[-d][PerturbationH[-a,-c]]*CDflat[-h][PerturbationH[-b,-f]])/2+(k5*\[Alpha]*L[-b]*L[c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/16+(k5*\[Alpha]*L[-a]*L[c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/16-(k0*\[Alpha]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*m[f,h]*m[i,j]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[f,h]*m[i,j]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4-(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec1[-a]*Scovec1[-b]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4-(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec2[-a]*Scovec2[-b]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(k1*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec1[-a]*Svec1[d]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(k1*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec1[-b]*Svec1[d]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(k2*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec2[-a]*Svec2[d]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4+(k2*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec2[-b]*Svec2[d]*CDflat[-d][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-c,-f]])/4-(\[Beta]*m[c,d]*m[f,h]*CDflat[-a][PerturbationH[-b,-c]]*CDflat[-h][PerturbationH[-d,-f]])/2-(\[Beta]*m[c,d]*m[f,h]*CDflat[-b][PerturbationH[-a,-c]]*CDflat[-h][PerturbationH[-d,-f]])/2+(k9*\[Alpha]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/16+(\[Lambda]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/32-(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec1[-a]*Scovec1[-b]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4-(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec2[-a]*Scovec2[-b]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4+(k1*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec1[-a]*Svec1[d]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4+(k1*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec1[-b]*Svec1[d]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4+(k2*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec2[-a]*Svec2[d]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4+(k2*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec2[-b]*Svec2[d]*CDflat[-c][PerturbationH[-i,-j]]*CDflat[-h][PerturbationH[-d,-f]])/4-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec1[f]*Svec1[h]*CDflat[-d][PerturbationH[-c,-f]]*CDflat[-h][PerturbationH[-i,-j]])/8-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec2[f]*Svec2[h]*CDflat[-d][PerturbationH[-c,-f]]*CDflat[-h][PerturbationH[-i,-j]])/8+(\[Lambda]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-f][PerturbationH[-c,-d]]*CDflat[-h][PerturbationH[-i,-j]])/16-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec1[f]*Svec1[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/8-(k4*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-a]*Scovec1[-b]*Svec1[f]*Svec1[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/2-(k6*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-b]*Scovec2[-a]*Svec1[f]*Svec2[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/2-(k6*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec1[-a]*Scovec2[-b]*Svec1[f]*Svec2[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/2-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec2[f]*Svec2[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/8-(k4*\[Alpha]*L[c]*Lbar[d]*m[i,j]*Scovec2[-a]*Scovec2[-b]*Svec2[f]*Svec2[h]*CDflat[-d][PerturbationH[-f,-h]]*CDflat[-j][PerturbationH[-c,-i]])/2+(k7*\[Alpha]*L[-b]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec1[-a]*Svec1[h]*CDflat[-f][PerturbationH[-d,-h]]*CDflat[-j][PerturbationH[-c,-i]])/4+(k7*\[Alpha]*L[-a]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec1[-b]*Svec1[h]*CDflat[-f][PerturbationH[-d,-h]]*CDflat[-j][PerturbationH[-c,-i]])/4+(k8*\[Alpha]*L[-b]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec2[-a]*Svec2[h]*CDflat[-f][PerturbationH[-d,-h]]*CDflat[-j][PerturbationH[-c,-i]])/4+(k8*\[Alpha]*L[-a]*L[c]*Lbar[d]*Lbar[f]*m[i,j]*Scovec2[-b]*Svec2[h]*CDflat[-f][PerturbationH[-d,-h]]*CDflat[-j][PerturbationH[-c,-i]])/4-(k9*\[Alpha]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-h][PerturbationH[-d,-f]]*CDflat[-j][PerturbationH[-c,-i]])/8-(\[Lambda]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-h][PerturbationH[-d,-f]]*CDflat[-j][PerturbationH[-c,-i]])/16-(k5*\[Alpha]*L[-b]*L[c]*L[d]*Lbar[-a]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/8-(k5*\[Alpha]*L[-a]*L[c]*L[d]*Lbar[-b]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/8+(k0*\[Alpha]*L[c]*L[d]*Lbar[-a]*Lbar[-b]*m[f,h]*m[i,j]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/4-(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[f,h]*m[i,j]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/4+(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec1[-a]*Scovec1[-b]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2+(k3*\[Alpha]*L[c]*Lbar[d]*m[f,h]*m[i,j]*Scovec2[-a]*Scovec2[-b]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2-(k1*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec1[-a]*Svec1[d]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2-(k1*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec1[-b]*Svec1[d]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2-(k2*\[Alpha]*L[c]*Lbar[-b]*m[f,h]*m[i,j]*Scovec2[-a]*Svec2[d]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2-(k2*\[Alpha]*L[c]*Lbar[-a]*m[f,h]*m[i,j]*Scovec2[-b]*Svec2[d]*CDflat[-h][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-d,-i]])/2+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec1[f]*Svec1[h]*CDflat[-d][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-h,-i]])/4+(\[Lambda]*L[-a]*L[-b]*Lbar[c]*Lbar[d]*m[i,j]*Svec2[f]*Svec2[h]*CDflat[-d][PerturbationH[-c,-f]]*CDflat[-j][PerturbationH[-h,-i]])/4-(\[Lambda]*L[-a]*L[-b]*L[c]*Lbar[d]*Lbar[f]*Lbar[h]*m[i,j]*CDflat[-f][PerturbationH[-c,-d]]*CDflat[-j][PerturbationH[-h,-i]])/8;


(********************************************************************************************************************************)




DefTensor[RadialS[-a],M4,PrintAs->"s"]
DefTensor[projectorq[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"q"]
DefScalarFunction[LengthScalar,PrintAs->"L"]
DefTensor[GradR[-a],M4,PrintAs->"R"]
DefTensor[RadialSbackground[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(s\), \(\[FilledSmallCircle]\)]\)"]
DefTensor[RadialSpert[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(s\), \(\[Breve]\)]\)"]



(*Basis[-a,{0,Sp}]*Basis[-b,{0,Sp}]*g[a,b]\[Equal]-Lapse^(-2)
(*this rule is because now the frozen metric is g, so the contravariant g is written as Invg *)
%/.ApplyRuleWithoutMovingIndices[g[a,b]==Invg[a,b]];
%/.ApplyRuleWithoutMovingIndices@RulexCobaContravariantSplitShortcutFinal;
%/.ApplyRuleBasisSpToFlatNull;
ContractMetric[%];
Flatten[Solve[%,Lapse]];
%[[2]][[1]]==%[[2]][[2]];
ToCanonical[%];
%/.ApplyRuleHcontractedWithLLbarS1S2WithoutExpandingDerivatives;
Series[%,{r[],Infinity,1}]
InputForm[%]*)



LapseToOrderEpsilon=Lapse==SeriesData[r[],Infinity,{1,(-HLbarLbar-HLL-2*HLLbar)/8},0,2,1]



LapseToOrderDelta
%/.ApplyRule[Perturbationh[-a,-b]==(1/r[])*PerturbationH[-a,-b]];
%/.ApplyRuleHcontractedWithLLbarS1S2WithoutExpandingDerivatives;
ToCanonical[%]



(*Split of the Normal covector *)


(*NormalDownToLapseAndFlatNull
%/.ApplyRule@Normal[LapseToOrderEpsilon];
Series[%,{r[],Infinity,1}];
Normal[%];
%[[1]]\[Equal]%[[2]]+(1/r[])^2*higherOrderTensor1index[-a];
Expand[%];*)
NormalDownSplitOrderEpsilon=NormalN[-a]==-L[-a]/2-Lbar[-a]/2+higherOrderTensor1index[-a]/r[]^2+(HLbarLbar*L[-a])/(16*r[])+(HLL*L[-a])/(16*r[])+(HLLbar*L[-a])/(8*r[])+(HLbarLbar*Lbar[-a])/(16*r[])+(HLL*Lbar[-a])/(16*r[])+(HLLbar*Lbar[-a])/(8*r[])



NormalDownSplit
%/.ApplyRule@SubstituteNormalbackground;
%/.ApplyRule@SubstituteNormalpert;
%/.ApplyRule@SubstituteNormalbackground;
%/.ApplyRule[Perturbationh[-a,-b]==(1/r[])*PerturbationH[-a,-b]];
ToCanonical[%];
%/.ApplyRule@RulePerturbationHToLLbarAndS;
ToCanonical[%]



(*NormalN[a]\[Equal]Invg[a,b]NormalN[-b]
%/.ApplyRuleWithoutMovingIndices@RulexCobaContravariantSplitShortcutFinal;
%/.ApplyRuleWithoutMovingIndices@NormalDownSplitOrderEpsilon;
%/.ApplyRuleRulePerturbationHToLLbarAndSContravariant;
Series[%,{r[],Infinity,1}];
Normal[%];
ContractMetric[%];
%[[1]]\[Equal]%[[2]]+(1/r[])^2*higherOrderTensor1index[a];
Simplification[%];
Collect[%,r[]];
Expand[%];*)
NormalUpSplitOrderEpsilon=NormalN[a]==-L[a]/2-Lbar[a]/2+higherOrderTensor1index[a]/r[]^2-(3*HLbarLbar*L[a])/(16*r[])+(HLL*L[a])/(16*r[])-(HLLbar*L[a])/(8*r[])+(HLbarLbar*Lbar[a])/(16*r[])-(3*HLL*Lbar[a])/(16*r[])-(HLLbar*Lbar[a])/(8*r[])+(HLbarS1*Scovec1[a])/(2*r[])+(HLS1*Scovec1[a])/(2*r[])+(HLbarS2*Scovec2[a])/(2*r[])+(HLS2*Scovec2[a])/(2*r[])




NormalUpSplit
%/.ApplyRule@SubstituteNormalbackground;
%/.ApplyRule@SubstituteNormalpert;
%/.ApplyRule@SubstituteNormalbackground;
%/.ApplyRule[Perturbationh[-a,-b]==(1/r[])*PerturbationH[-a,-b]];
ToCanonical[%];
%/.ApplyRule@RulePerturbationHToLLbarAndS;
ToCanonical[%]



(*Basis[-a,{1,Sp}]*Basis[-b,{1,Sp}]*projector[a,b]\[Equal]LengthScalar^(-2)
Basis[-a,{1,Sp}]*Basis[-b,{1,Sp}]*(g[a,b]+NormalN[a]NormalN[b])\[Equal]LengthScalar^(-2);
(*this rule is because now the frozen metric is g, so the contravariant g is written as Invg *)
%/.ApplyRuleWithoutMovingIndices[g[a,b]==Invg[a,b]];
%/.ApplyRuleWithoutMovingIndices@RulexCobaContravariantSplitShortcutFinal;
%/.ApplyRuleBasisSpToFlatNull;
ToCanonical[%];
%/.ApplyRuleWithoutMovingIndices@NormalDownToLapseAndFlatNull;
Expand[%];
Flatten[Solve[%,Scalar[LengthScalar]]];
%[[2]][[1]]==%[[2]][[2]];
ToCanonical[%];
%/.ApplyRuleHcontractedWithLLbarS1S2WithoutExpandingDerivatives;
Series[%,{r[],Infinity,1}]
InputForm[%]*)



LengthScalarToOrderEpsilon=LengthScalar==SeriesData[r[],Infinity,{1,(HLbarLbar+HLL-2*HLLbar)/8},0,2,1]




projectorDownUpsafe=projector[-a,b]==Invg[c,b]projector[-a,-c]



projectorDownDownDefinition=projector[-a,-b]==g[-a,-b]+NormalN[-a]*NormalN[-b]


(*RadialS[-a]==LengthScalar*projector[-a,b]CDflat[-b]@r[]
%/.ApplyRuleBasisSpToFlatNull;
%/.ApplyRule@Normal[LengthScalarToOrderEpsilon];
%/.ApplyRuleWithoutMovingIndices@projectorDownUpsafe;
%/.ApplyRuleWithoutMovingIndices@projectorDownDownDefinition;
%/.ApplyRuleWithoutMovingIndices@RulexCobaContravariantSplitShortcutFinal;
%/.ApplyRuleWithoutMovingIndices@RulexCobaCovariantSplitShortcutFinal;
%/.ApplyRuleWithoutMovingIndices@NormalDownSplitOrderEpsilon;
%/.ApplyRule@RulePerturbationHToLLbarAndS;
ContractMetric[%];
ToCanonical[%];
Series[%,{r[],Infinity,1}]
Normal[%];
%[[1]]==%[[2]]+(1/r[])^2*higherOrderTensor1index[-a];
Expand[%];*)
RadialSToOrderEpsilonDown=RadialS[-a]==L[-a]/2-Lbar[-a]/2+higherOrderTensor1index[-a]/r[]^2+(3*HLbarLbar*L[-a])/(16*r[])-(HLL*L[-a])/(16*r[])-(HLLbar*L[-a])/(8*r[])+(HLbarLbar*Lbar[-a])/(16*r[])-(3*HLL*Lbar[-a])/(16*r[])+(HLLbar*Lbar[-a])/(8*r[])



SubstituteRadialSbackground=RadialSbackground[-a]==RadialCovector[-a]
SubstituteRadialSpert=RadialSpert[-a]==-NormalNbackround[-a]*NormalNbackround[b]*Perturbationh[-b,-c]*RadialCovector[c]+(Perturbationh[-b,-c]*RadialCovector[-a]*RadialCovector[b]*RadialCovector[c])/2



RadialSDownSplit=RadialS[-a]==RadialSbackground[-a]+DeltaCounter*RadialSpert[-a]+higherOrderTensor1index[-a]DeltaCounter^2


RadialSDownSplit
%/.ApplyRule@SubstituteRadialSbackground;
%/.ApplyRule@SubstituteRadialSpert;
%/.ApplyRule@SubstituteRadialCovectorbackground;
%/.ApplyRule@SubstituteNormalbackground ;
ToCanonical[%];
%/.ApplyRule[Perturbationh[-a,-b]==(1/r[])*PerturbationH[-a,-b]];
%/.ApplyRuleHcontractedWithLLbarS1S2WithoutExpandingDerivatives;
ToCanonical[%]



(*RadialS[a]\[Equal]Invg[a,b]RadialS[-b]
%/.ApplyRuleWithoutMovingIndices@RulexCobaContravariantSplitShortcutFinal;
%/.ApplyRuleWithoutMovingIndices@RadialSToOrderEpsilonDown;
ContractMetric[%];
Series[%,{r[],Infinity,1}];
Normal[%];
%[[1]]==%[[2]]+(1/r[])^2*higherOrderTensor1index[a];
%/.ApplyRuleRulePerturbationHToLLbarAndSContravariant;
ContractMetric[%];
Simplification[%];
Collect[%,r[]];
Expand[%];*)
RadialSToOrderEpsilonUp=RadialS[a]==L[a]/2-Lbar[a]/2+higherOrderTensor1index[a]/r[]^2-(HLbarLbar*L[a])/(16*r[])-(HLL*L[a])/(16*r[])+(HLLbar*L[a])/(8*r[])+(HLbarLbar*Lbar[a])/(16*r[])+(HLL*Lbar[a])/(16*r[])-(HLLbar*Lbar[a])/(8*r[])+(HLbarS1*Scovec1[a])/(2*r[])-(HLS1*Scovec1[a])/(2*r[])+(HLbarS2*Scovec2[a])/(2*r[])-(HLS2*Scovec2[a])/(2*r[])



(*RadialS[a]\[Equal]Invg[a,b]RadialS[-b]
%/.ApplyRuleWithoutMovingIndices@RuleMetricDeltaCounterContravariantSplit
%/.ApplyRuleWithoutMovingIndices@RadialSDownSplit;
Expand[%];
Series[%,{DeltaCounter,0,1}];
Normal[%];
%[[1]]==%[[2]]+higherOrderTensor1index[a]*DeltaCounter^2;
Collect[%,DeltaCounter];*)
RadialSUpSplit=RadialS[a]==DeltaCounter^2*higherOrderTensor1index[a]+m[a,b]*RadialSbackground[-b]+DeltaCounter*(-(Perturbationh[a,b]*RadialSbackground[-b])+m[a,b]*RadialSpert[-b])



RadialSUpSplit
%/.ApplyRule@SubstituteRadialSbackground;
%/.ApplyRule@SubstituteRadialSpert;
%/.ApplyRule@SubstituteRadialCovectorbackground;
%/.ApplyRule@SubstituteNormalbackground;
ToCanonical[%];
%/.ApplyRule[Perturbationh[-a,-b]==(1/r[])*PerturbationH[-a,-b]];
%/.ApplyRule@RulePerturbationHToLLbarAndS;
ToCanonical[%]




DefScalarFunction[KBondi,PrintAs->"K"]
DefScalarFunction[KBondiZero,PrintAs->"\!\(\*OverscriptBox[\(K\), \(\[EmptySmallCircle]\)]\)"]
DefTensor[projectorqbackground[-a,-b],M4,Symmetric[{-a,-b}],PrintAs->"\!\(\*OverscriptBox[\(q\), \(\[FilledSmallCircle]\)]\)"]
DefTensor[VectorToIndentifyDivergence1[a],M4,PrintAs->"w"]
DefTensor[VectorToIndentifyDivergence2[a],M4,PrintAs->"\[ScriptW]"]
DefScalarFunction[CL,PrintAs->"\!\(\*SubscriptBox[\(C\), \(L\)]\)"]
DefScalarFunction[CLbar,PrintAs->"\!\(\*SubscriptBox[\(C\), \(\[CapitalLSlash]\)]\)"]
DefScalarFunction[CS1,PrintAs->"\!\(\*SubscriptBox[\(C\), \(LS1\)]\)"]
DefScalarFunction[CS2,PrintAs->"\!\(\*SubscriptBox[\(C\), \(LS2\)]\)"]






SubstituteProjectorqBackground=projectorqbackground[-a,-b]==projectorbackround[-a,-b]-RadialSbackground[-a]RadialSbackground[-b]



LengthScalar*Basis[-a,{2,Sp}]*Basis[-b,{2,Sp}]*g[b,a]*r[]+LengthScalar*Basis[-a,{2,Sp}]*Basis[-b,{2,Sp}]*NormalN[a]*NormalN[b]*r[]-LengthScalar*Basis[-a,{2,Sp}]*Basis[-b,{2,Sp}]*r[]*RadialS[a]*RadialS[b]+LengthScalar*Basis[-a,{3,Sp}]*Basis[-b,{3,Sp}]*g[b,a]*r[]*Sin[\[Theta][]]^2+LengthScalar*Basis[-a,{3,Sp}]*Basis[-b,{3,Sp}]*NormalN[a]*NormalN[b]*r[]*Sin[\[Theta][]]^2-LengthScalar*Basis[-a,{3,Sp}]*Basis[-b,{3,Sp}]*r[]*RadialS[a]*RadialS[b]*Sin[\[Theta][]]^2+(g[b,c]*RadialS[a]*CDflat[-a][g[-b,-c]])/2-NormalN[a]*NormalN[b]*RadialS[c]*CDflat[-b][g[-a,-c]]-g[b,c]*RadialS[a]*CDflat[-c][g[-a,-b]]+(NormalN[a]*NormalN[b]*RadialS[c]*CDflat[-c][g[-a,-b]])/2+(RadialS[a]*RadialS[b]*RadialS[c]*CDflat[-c][g[-a,-b]])/2;
%/.ApplyRuleWithoutMovingIndices[g[a,b]==Invg[a,b]];
TraceExtrinsicCurvatureForBondi=LengthScalar*Basis[-a,{2,Sp}]*Basis[-b,{2,Sp}]*Invg[b,a]*r[]+LengthScalar*Basis[-a,{2,Sp}]*Basis[-b,{2,Sp}]*NormalN[a]*NormalN[b]*r[]-LengthScalar*Basis[-a,{2,Sp}]*Basis[-b,{2,Sp}]*r[]*RadialS[a]*RadialS[b]+LengthScalar*Basis[-a,{3,Sp}]*Basis[-b,{3,Sp}]*Invg[b,a]*r[]*Sin[\[Theta][]]^2+LengthScalar*Basis[-a,{3,Sp}]*Basis[-b,{3,Sp}]*NormalN[a]*NormalN[b]*r[]*Sin[\[Theta][]]^2-LengthScalar*Basis[-a,{3,Sp}]*Basis[-b,{3,Sp}]*r[]*RadialS[a]*RadialS[b]*Sin[\[Theta][]]^2+(Invg[b,c]*RadialS[a]*CDflat[-a][g[-b,-c]])/2-NormalN[a]*NormalN[b]*RadialS[c]*CDflat[-b][g[-a,-c]]-Invg[b,c]*RadialS[a]*CDflat[-c][g[-a,-b]]+(NormalN[a]*NormalN[b]*RadialS[c]*CDflat[-c][g[-a,-b]])/2+(RadialS[a]*RadialS[b]*RadialS[c]*CDflat[-c][g[-a,-b]])/2;






UseAsymtptoticSystemToReplaceDerivativesLbarLbar=CDflat[{1,-Li}][CDflat[{0,-Li}][HLbarLbar]]==(-4*CDflat[{0,-Li}][Hcross]^2+2*k9*CDflat[{0,-Li}][HLbarLbar]*CDflat[{0,-Li}][HLL]-4*CDflat[{0,-Li}][HPlus]^2+HLL*CDflat[{0,-Li}][CDflat[{0,-Li}][HLbarLbar]])/2



(**************************************definitions for Toy Model ***************************************)





DefScalarFunction[PiPhiT, PrintAs->"\[Pi]"]
DefScalarFunction[Phi, PrintAs->"\[Phi]"]
DefScalarFunction[PhiT, PrintAs->"\!\(\*SubscriptBox[\(\[Phi]\), \(T\)]\)"]
DefScalarFunction[PhiR, PrintAs->"\!\(\*SubscriptBox[\(\[Phi]\), \(R\)]\)"]
DefScalarFunction[PhiS1, PrintAs->"\!\(\*SubscriptBox[\(\[Phi]\), \(S1\)]\)"]
DefScalarFunction[PhiS2, PrintAs->"\!\(\*SubscriptBox[\(\[Phi]\), \(S2\)]\)"]
DefScalarFunction[PivarPhiT, PrintAs->"\!\(\*OverscriptBox[\(\[Pi]\), \(~\)]\)"]
DefScalarFunction[varPhi, PrintAs->"\!\(\*OverscriptBox[\(\[Phi]\), \(~\)]\)"]
DefScalarFunction[varPhiT, PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Phi]\), \(~\)], \(T\)]\)"]
DefScalarFunction[varPhiR, PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Phi]\), \(~\)], \(R\)]\)"]
DefScalarFunction[varPhiS1, PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Phi]\), \(~\)], \(S1\)]\)"]
DefScalarFunction[varPhiS2, PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[Phi]\), \(~\)], \(S2\)]\)"]
DefTensor[SpacetimeDerivativePhi[-a],M4,PrintAs->"\[Phi]"]
DefTensor[SpacetimeDerivativevarPhi[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(\[Phi]\), \(~\)]\)"]
DefTensor[ReductionConstraint[-a],M4,PrintAs->"C"]
DefScalarFunction[reductCT,PrintAs->"\!\(\*SubscriptBox[\(C\), \(T\)]\)"]
DefScalarFunction[reductCR,PrintAs->"\!\(\*SubscriptBox[\(C\), \(R\)]\)"]
DefScalarFunction[reductCS1,PrintAs->"\!\(\*SubscriptBox[\(C\), \(S1\)]\)"]
DefScalarFunction[reductCS2,PrintAs->"\!\(\*SubscriptBox[\(C\), \(S2\)]\)"]
DefScalarFunction[DLphi,PrintAs->"\!\(\*SuperscriptBox[\(\[Xi]\), \(+\)]\)"]
DefScalarFunction[DLbarphi,PrintAs->"\!\(\*SuperscriptBox[\(\[Xi]\), \(-\)]\)"]
DefScalarFunction[varDLphi,PrintAs->"\!\(\*SuperscriptBox[OverscriptBox[\(\[Xi]\), \(~\)], \(+\)]\)"]
DefScalarFunction[varDLbarphi,PrintAs->"\!\(\*SuperscriptBox[OverscriptBox[\(\[Xi]\), \(~\)], \(-\)]\)"]
DefScalarFunction[RescDLphi,PrintAs->"\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(+\)]\)"]
DefScalarFunction[RescDLbarphi,PrintAs->"\!\(\*SuperscriptBox[\(\[CapitalSigma]\), \(-\)]\)"]
DefScalarFunction[RescPhiS1,PrintAs->"\!\(\*SubscriptBox[\(\[CapitalPhi]\), \(S1\)]\)"]
DefScalarFunction[RescPhiS2,PrintAs->"\!\(\*SubscriptBox[\(\[CapitalPhi]\), \(S2\)]\)"]
DefScalarFunction[RescPhi,PrintAs->"\[CapitalPhi]"]
DefScalarFunction[varRescDLphi,PrintAs->"\!\(\*SuperscriptBox[OverscriptBox[\(\[CapitalSigma]\), \(~\)], \(+\)]\)"]
DefScalarFunction[varRescDLbarphi,PrintAs->"\!\(\*SuperscriptBox[OverscriptBox[\(\[CapitalSigma]\), \(~\)], \(-\)]\)"]
DefScalarFunction[varRescPhiS1,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[CapitalPhi]\), \(~\)], \(S1\)]\)"]
DefScalarFunction[varRescPhiS2,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[CapitalPhi]\), \(~\)], \(S2\)]\)"]
DefScalarFunction[varRescPhi,PrintAs->"\!\(\*OverscriptBox[\(\[CapitalPhi]\), \(~\)]\)"]
DefScalarFunction[varReductCT,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(C\), \(~\)], \(T\)]\)"]
DefScalarFunction[varReductCR,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(C\), \(~\)], \(R\)]\)"]
DefScalarFunction[varReductCS1,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(C\), \(~\)], \(S1\)]\)"]
DefScalarFunction[varReductCS2,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(C\), \(~\)], \(S2\)]\)"]
DefScalarFunction[RescaledCR,PrintAs->"\!\(\*SubscriptBox[\(\[DoubleStruckCapitalC]\), \(R\)]\)"]
DefScalarFunction[RescaledCS1,PrintAs->"\!\(\*SubscriptBox[\(\[DoubleStruckCapitalC]\), \(S1\)]\)"]
DefScalarFunction[RescaledCS2,PrintAs->"\!\(\*SubscriptBox[\(\[DoubleStruckCapitalC]\), \(S2\)]\)"]
DefScalarFunction[varRescaledCR,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[DoubleStruckCapitalC]\), \(~\)], \(R\)]\)"]
DefScalarFunction[varRescaledCS1,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[DoubleStruckCapitalC]\), \(~\)], \(S1\)]\)"]
DefScalarFunction[varRescaledCS2,PrintAs->"\!\(\*SubscriptBox[OverscriptBox[\(\[DoubleStruckCapitalC]\), \(~\)], \(S2\)]\)"]
DefTensor[varReductionConstraint[-a],M4,PrintAs->"\!\(\*OverscriptBox[\(C\), \(~\)]\)"]


ReductionConstraintInLLbarAndSCompsCRandCT=ReductionConstraint[-a]==(reductCR*L[-a])/2-(reductCT*L[-a])/2-(reductCR*Lbar[-a])/2-(reductCT*Lbar[-a])/2+reductCS1*Scovec1[-a]+reductCS2*Scovec2[-a]
(**)
varReductionConstraintInLLbarAndSCompsCRandCT=varReductionConstraint[-a]==(varReductCR*L[-a])/2-(varReductCT*L[-a])/2-(varReductCR*Lbar[-a])/2-(varReductCT*Lbar[-a])/2+varReductCS1*Scovec1[-a]+varReductCS2*Scovec2[-a]


SubstitutePi=PhiT==-PiPhiT
NicePrintingPhiT=SpacetimeDerivativePhi[{0,-Sp}]==PhiT
NicePrintingvarPhiT=SpacetimeDerivativevarPhi[{0,-Sp}]==varPhiT
SubstitutevarPi=varPhiT==-PivarPhiT
NicePrintingPhiR=SpacetimeDerivativePhi[{1,-Sp}]==PhiR
NicePrintingvarPhiR=SpacetimeDerivativevarPhi[{1,-Sp}]==varPhiR
varNicePrintingCT=varReductionConstraint[{0,-Sp}]==varReductCT
varNicePrintingCR=varReductionConstraint[{1,-Sp}]==varReductCR
NicePrintingCT=ReductionConstraint[{0,-Sp}]==reductCT
NicePrintingCR=ReductionConstraint[{1,-Sp}]==reductCR
varNicePrintingCS1=Svec1[a]varReductionConstraint[-a]==varReductCS1
varNicePrintingCS2=Svec2[a]varReductionConstraint[-a]==varReductCS2
NicePrintingCS1=Svec1[a]ReductionConstraint[-a]==reductCS1
NicePrintingCS2=Svec2[a]ReductionConstraint[-a]==reductCS2


RuleSpacetimeReductionVariable=CDflat[-a]@Phi==SpacetimeDerivativePhi[-a]
RuleSpacetimeReductionVariablevarphi=CDflat[-a]@varPhi==SpacetimeDerivativevarPhi[-a]
ReductionConstraintDefinition=ReductionConstraint[-a]==CDflat[-a]@Phi-SpacetimeDerivativePhi[-a]
varReductionConstraintDefinition=varReductionConstraint[-a]==CDflat[-a]@varPhi-SpacetimeDerivativevarPhi[-a]


RuleSpacetimeReductionVariableToLLbarS=SpacetimeDerivativePhi[-a]==(PhiR*L[-a])/2-(PhiT*L[-a])/2-(PhiR*Lbar[-a])/2-(PhiT*Lbar[-a])/2+PhiS1*Scovec1[-a]+PhiS2*Scovec2[-a]
RulevarphiSpacetimeReductionVariableToLLbarS=SpacetimeDerivativevarPhi[-a]==(varPhiR*L[-a])/2-(varPhiT*L[-a])/2-(varPhiR*Lbar[-a])/2-(varPhiT*Lbar[-a])/2+varPhiS1*Scovec1[-a]+varPhiS2*Scovec2[-a]





DefTensor[EndOfSetUpFile[],M4,PrintAs->"END-OF-SET-UP-FILE"]


EndOfSetUpFile[]
